#
# spec file
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2012 RedHat
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor %{nil}

%bcond_with ringdisabled
%bcond_with for_chroot

%if "%flavor" == "testsuite"
%if %{with ringdisabled}
ExclusiveArch:  do_not_build
%endif
%if 0%{?qemu_user_space_build}
# In a qemu_user_space_build ptrace is not supported, so we can't test gdb.
ExclusiveArch:  do_not_build
%endif

# Disable big-endian ppc testing.
ExcludeArch:    ppc ppc64

%define build_main 0
%define build_testsuite 1
%else
%define build_main 1
%define build_testsuite 0
%endif

%if %{build_testsuite}
%define debug_package %{nil}
%endif

%if %{build_main}
%define name_suffix %{nil}
%else
%if %{build_testsuite}
%define name_suffix -testresults
%else
%define name_suffix -%{flavor}
%endif
%endif

%bcond_without fpc

%if %{build_main}
Summary:        A GNU source-level debugger for C, C++, Fortran and other languages
License:        GPL-3.0-only WITH GCC-exception-3.1 AND GPL-3.0-or-later AND LGPL-2.1-or-later AND LGPL-3.0-or-later
Group:          Development/Languages/C and C++
%endif
%if %{build_testsuite}
Summary:        GDB testsuite results
License:        SUSE-Public-Domain
Group:          Development/Languages/C and C++
%endif
Name:           gdb%{name_suffix}

Version:        15.2
Release:        1.2

# The release always contains a leading reserved number, start it at 1.
# `upstream' is not a part of `name' to stay fully rpm dependencies compatible for the testing.

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Do not provide URL for snapshots as the file lasts there only for 2 days.
# ftp://sourceware.org/pub/gdb/releases/gdb-%%{version}.tar.gz
Source:         gdb-%{version}.tar.bz2
URL:            http://gnu.org/software/gdb/

%if "%{scl}" == "devtoolset-1.1"
Obsoletes:      devtoolset-1.0-%{pkg_name}
%endif

# For our convenience
%global gdb_src gdb-%{version}
%global gdb_build build-%{_target_platform}
%global gdb_docdir %{_docdir}/gdb-doc

%global have_inproctrace 0
%ifarch %{ix86} x86_64
%global have_inproctrace 1
%endif # %%{ix86} x86_64

# Choose python version
%if 0%{?suse_version} >= 1200
%define python python3
%else
# Skip for SLE-11 due to lack of python3.
%define _without_python 1
%endif

# GDB patches have the format `gdb-<version>-bz<red-hat-bz-#>-<desc>.patch'.
# They should be created using patch level 1: diff -up ./gdb (or gdb-6.3/gdb).

#=
#push=Should be pushed upstream.
#maybepush=Should be pushed upstream unless it got obsoleted there.
#fedora=Should stay as a Fedora patch.
#ia64=Drop after RHEL-5 rebases and rebuilds are no longer meaningful.
#fedoratest=Keep it in Fedora only as a regression test safety.
#+ppc=Specific for ppc32/ppc64/ppc*
#+work=Requires some nontrivial work.

# Cleanup any leftover testsuite processes as it may stuck mock(1) builds.
#=push
Source2:        gdb-orphanripper.c

# Man page for gstack(1).
#=push
Source3:        gdb-gstack.man

# /etc/gdbinit (from Debian but with Fedora compliant location).
#=fedora
Source4:        gdbinit
Source5:        gdbinit.without-python

# libipt: Intel Processor Trace Decoder Library
%global libipt_version 2.0.5
Source7:        v%{libipt_version}.tar.gz

# Infrastructure to sync patches from the Fedora rpm
Source10:       patchlist.pl
Source11:       patchname_get.sh
Source12:       baselibs.conf
Source13:       gdb-rpmlintrc

# Infrastructure to maintain package.
Source14:       clean.sh
Source15:       import-patches.sh
Source16:       qa.sh
Source17:       qa-local.sh
Source18:       qa-remote.sh
Source19:       README.qa
Source20:       import-fedora.sh

%if %{build_testsuite}
NoSource:       0
NoSource:       2
NoSource:       3
NoSource:       4
NoSource:       5
NoSource:       7
NoSource:       10
NoSource:       11
NoSource:       12
NoSource:       13
NoSource:       14
NoSource:       15
NoSource:       16
NoSource:       17
NoSource:       18
NoSource:       19
NoSource:       20
%endif

# Fedora import from branch f38, commit 82cc8e0.

#Fedora Packages begin
Patch2:         gdb-6.3-gstack-20050411.patch
Patch3:         gdb-6.5-bz218379-ppc-solib-trampoline-test.patch
Patch4:         gdb-6.6-bz237572-ppc-atomic-sequence-test.patch
Patch5:         gdb-6.6-buildid-locate.patch
Patch6:         gdb-6.6-buildid-locate-solib-missing-ids.patch
Patch7:         gdb-6.5-gcore-buffer-limit-test.patch
Patch8:         gdb-6.3-mapping-zero-inode-test.patch
Patch10:        gdb-archer-next-over-throw-cxx-exec.patch
Patch12:        gdb-rhbz-818343-set-solib-absolute-prefix-testcase.patch
Patch15:        gdb-rhbz1149205-catch-syscall-after-fork-test.patch
Patch16:        gdb-rhbz1084404-ppc64-s390x-wrong-prologue-skip-O2-g-3of3.patch
Patch20:        gdb-add-rpm-suggestion-script.patch
Patch21:        gdb-catchpoint-re-set.patch
#Fedora Packages end

# Fedora patches fixup
# These need a number with at least four digits, otherwise patchlist.pl removes
# them when upgrading.

Patch1000:      fixup-gdb-6.5-gcore-buffer-limit-test.patch

# openSUSE specific

# Hardcodes /bin/bash, given that path is known.
Patch1100:      gdb-gcore-bash.patch
# Make gdb emit zypper install hints, rather than debuginfo-install hints.
Patch1101:      gdb-6.6-buildid-locate-rpm-suse.patch

# openSUSE specific -- testsuite

# Silences ada pie compilation FAILs.  Todo: Fix ada pie compilation.
Patch1200:      gdb-testsuite-ada-pie.patch
# Tests the zypper install hints.
Patch1203:      gdb-testsuite-add-gdb.suse-zypper-hint.exp.patch
# Tests that no branding is leaked from sourcing the fedora package.
Patch1204:      gdb-testsuite-add-gdb.suse-debranding.exp.patch

# Patches to upstream

# https://sourceware.org/bugzilla/show_bug.cgi?id=25703
Patch1500:      gdb-symtab-set-default-dwarf-max-cache-age-1000.patch
# https://bugzilla.suse.com/show_bug.cgi?id=1179210
Patch1501:      gdb-tui-enable-work-around-libncurses-segfault.patch
# Fixes: gdb.x86_64: W: potential-bashisms /usr/bin/gdb-add-index
Patch1503:      gdb-add-index.sh-fix-bashism.patch
# Fixes:
# FAIL: gdb.mi/new-ui-mi-sync.exp: sync-command=run: add-inferior (timeout)
Patch1504:      fix-gdb.mi-new-ui-mi-sync.exp.patch
# Fixes:
# FAIL: gdb.base/step-over-syscall.exp: fork: displaced=off: \
# pc after stepi matches insn addr after syscall
Patch1505:      gdb-testsuite-fix-gdb.base-step-over-syscall.exp-with-m32-amd-case.patch
# https://sourceware.org/bugzilla/show_bug.cgi?id=32590
Patch1506:      gdb-cli-print-at_hwcap3-and-at_hwcap4.patch
# Work around SCM_UNPACK Werror=sequence-point in libguile v2.0.9 (SLE-12).
Patch1507:      gdb-guile-use-scm_debug_typing_strictness-0.patch
# SLE-12 specific fix, hard to reproduce with trunk.
Patch1508:      gdb-testsuite-fix-gdb_py_module_available-for-python.patch

# Backports from master, available in GDB 16.

Patch2000:      gdb-testsuite-fix-gdb.fortran-array-bounds.exp-on-ar.patch
Patch2001:      gdb-symtab-return-correct-reader-for-top-level-cu-in.patch
Patch2002:      gdb-tdep-s390-add-arch15-record-replay-support.patch
Patch2003:      gdb-testsuite-avoid-intermittent-failures-on-a-debug.patch
Patch2004:      gdb-python-avoid-depending-on-the-curses-library.patch
Patch2005:      gdb-testsuite-fix-gdb.threads-leader-exit-attach.exp.patch
Patch2006:      gdb-testsuite-fix-gdb.python-py-format-string.exp-wi.patch
Patch2007:      gdb-testsuite-fix-gdb.python-py-mi-cmd.exp-with-pyth.patch
Patch2008:      gdb-testsuite-fix-gdb.ada-mi_task_arg.exp-on-arm-lin.patch
Patch2009:      gdb-testsuite-fix-regexp-in-gdb.ada-mi_var_access.ex.patch
Patch2010:      gdb-testsuite-fix-gdb.arch-arm-pseudo-unwind.exp-wit.patch
Patch2011:      gdb-symtab-fix-target-type-of-complex-long-double-on.patch
Patch2012:      gdb-testsuite-don-t-use-set-auto-solib-add-off.patch
Patch2013:      gdb-tdep-fix-arm-thumb2-hw-breakpoint.patch
Patch2014:      gdb-testsuite-fix-gdb.cp-m-static.exp-on-arm.patch
Patch2015:      gdb-testsuite-fix-gdb.dwarf2-dw2-fixed-point.exp-on-.patch
Patch2016:      gdb-testsuite-fix-gdb.dwarf2-dw2-lines.exp-on-arm-li.patch
Patch2017:      gdb-exp-fix-gdb.fortran-intrinsics.exp-fail-on-arm.patch
Patch2018:      gdb-tdep-handle-sycall-statx-for-arm-linux.patch
Patch2019:      gdb-tdep-fix-recording-of-t1-push.patch
Patch2020:      gdb-tdep-handle-syscall-clock_gettime64-for-arm-linu.patch
Patch2021:      fix-gdb.dwarf2-shortpiece.exp-on-s390x.patch
Patch2022:      handle-address-class-annotation-for-s390x-in-some-te.patch
Patch2023:      fix-gdb.dap-step-out.exp-on-s390x.patch
Patch2024:      use-setvariable-in-gdb.dap-scopes.exp.patch
Patch2025:      gdb-testsuite-fix-regexp-in-gdb.arch-i386-disp-step-.patch
Patch2026:      gdb-testsuite-fix-gdb.arch-arm-single-step-kernel-he.patch
Patch2027:      gdb-testsuite-fix-gdb.python-py-format-address.exp-o.patch
Patch2028:      gdb-testsuite-fix-gdb.arch-riscv-tdesc-regs.exp.patch
Patch2029:      gdb-testsuite-fix-gdb.base-list-dot-nodebug-and-make.patch
Patch2030:      gdb-testsuite-fix-gdb.base-empty-host-env-vars.exp.patch
Patch2031:      gdb-prune-inferior-after-switching-inferior.patch
Patch2032:      gdb-testsuite-fix-timeout-in-gdb.mi-mi-multi-command.patch
Patch2033:      gdb-testsuite-fix-regexp-in-gdb.threads-stepi-over-c.patch

# Backports from master, available in GDB 17.

Patch2100:      gdb-testsuite-record-less-in-gdb.reverse-time-revers.patch
Patch2101:      gdb-doc-fix-gdb.unwinder-docs.patch
Patch2102:      gdb-doc-fix-qisaddresstagged-anchor.patch
Patch2103:      gdb-testsuite-fix-another-regexp-in-gdb.threads-step.patch
Patch2104:      gdb-testsuite-fix-timeouts-in-gdb.threads-step-over-.patch
Patch2105:      gdb-testsuite-handle-unordered-dict-in-gdb.python-py.patch
Patch2106:      gdb-testsuite-check-gnatmake-version-in-gdb.ada-scal.patch
Patch2107:      fix-gdb.base-finish-pretty.exp-on-s390x.patch
Patch2108:      fix-gdb.base-readnever.exp-on-s390x.patch
Patch2109:      add-dwarf_expr_piece.op.patch
Patch2110:      add-gdbarch_dwarf2_reg_piece_offset-hook.patch
Patch2111:      fix-gdb.base-store.exp-on-s390x.patch
Patch2112:      fix-gdb.ada-o2_float_param.exp-on-s390x-linux.patch
Patch2113:      gdb-testsuite-fix-gdb.base-branch-to-self.exp-on-arm.patch
Patch2114:      gdb-tdep-fix-gdb.cp-non-trivial-retval.exp-on-riscv6.patch
Patch2115:      gdb-testsuite-fix-gdb.cp-non-trivial-retval.exp-on-a.patch
Patch2116:      gdb-testsuite-fix-gdb.rust-completion.exp-timeout-on.patch
Patch2117:      gdb-testsuite-require-supports_process_record-in-gdb.patch
Patch2118:      gdb-testsuite-fix-gdb.base-list-dot-nodebug.exp-on-o.patch
Patch2119:      gdb-testsuite-use-nostdlib-in-gdb.base-list-dot-node.patch
Patch2120:      gdb-testsuite-require-can_spawn_for_attach-in-gdb.ba.patch
Patch2121:      gdb-testsuite-fix-gdb.ada-big_packed_array.exp-on-s3.patch
Patch2122:      gdb-testsuite-fix-gdb.ada-convvar_comp.exp-on-s390x-.patch

# Backport from gdb-patches

# https://sourceware.org/pipermail/gdb-patches/2021-September/182226.html
Patch3000:      gdb-python-finishbreakpoint-update.patch
# https://sourceware.org/pipermail/gdb-patches/2021-October/182444.html
Patch3001:      gdb-testsuite-prevent-compilation-fails-with-unix-fpie-pie.patch
# https://sourceware.org/pipermail/gdb-patches/2021-May/178990.html
Patch3002:      gdb-cli-add-ignore-errors-command.patch
# https://sourceware.org/pipermail/gdb-patches/2024-May/209469.html
Patch3003:      gdb-testsuite-fix-error-in-gdb.server-server-kill-py.patch
# https://sourceware.org/pipermail/gdb-patches/2024-May/209504.html
Patch3004:      gdb-testsuite-fix-timeout-in-gdb.tui-resize-2.exp.patch
# https://sourceware.org/pipermail/gdb-patches/2025-January/214982.html
Patch3005:      gdb-doc-fix-standard-replies-xref.patch
# https://sourceware.org/pipermail/gdb-patches/2023-December/205054.html
Patch3006:      gdb-symtab-recurse-into-c-dw_tag_subprogram-dies-for.patch
# https://sourceware.org/bugzilla/show_bug.cgi?id=30380#c1
Patch3007:      gdb-testsuite-use-c-flag-in-c-test-cases.patch

# Debug patches.

#

# Other.  Needs comment for each patch.

#

# End of patches.

%if 0%{?suse_version} >= 1600
# Disable ptrace_scope on tumbleweed.
BuildRequires:  aaa_base-yama-enable-ptrace
%endif

BuildRequires:  bison
BuildRequires:  flex
%if 0%{suse_version} > 1315
BuildRequires:  gcc-c++
%else
# SLE-12.
BuildRequires:  gcc11
BuildRequires:  gcc11-c++
%endif
BuildRequires:  gettext
BuildRequires:  glibc-devel
%if 0%{suse_version} > 1110 && 0%{suse_version} < 1330
# GDB supports guile 2.0, but not guile 2.2 (swo#21104).  Disable guile
# support for newer distro versions in anticipation of a move to guile 2.2.
BuildRequires:  guile-devel
%endif
BuildRequires:  libexpat-devel
%if 0%{suse_version} >= 1200
BuildRequires:  makeinfo
%else
BuildRequires:  texinfo
%endif
BuildRequires:  expect

# Dependency is there for SLE-11, but configure test fails.
BuildRequires:  mpfr-devel

BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  readline-devel

# SLE-10 doesn't have xz-devel.
%if 0%{suse_version} >= 1110
BuildRequires:  xz-devel
%endif
BuildRequires:  zlib-devel

%if 0%{!?_without_python:1}
%if %{build_testsuite}
BuildRequires:  %{python}-base
BuildRequires:  python3-rpm
%else
Requires:       %{python}-base
Requires:       python3-rpm
%endif
BuildRequires:  %{python}-devel
%endif	# 0%{!?_without_python:1}

%global have_libdebuginfod 0
# Enable for SLE15-SP4/Leap-15.4, ALP/Factory.
%if 0%{?sle_version} >= 150400 || 0%{?suse_version} >= 1600
%global have_libdebuginfod 1
%endif

%if 0%{have_libdebuginfod}
BuildRequires:  libdebuginfod-devel
# Indicate that we prefer libdebuginfod1 over libdebuginfod1-dummy.
BuildRequires:  libdebuginfod1
%endif

%global have_libipt 0
%if 0%{suse_version} > 1110
%ifarch %{ix86} x86_64
%global have_libipt 1
BuildRequires:  cmake
%endif
%endif

# BuildArch would break RHEL-5 by overriding arch and not building noarch.
%if 0%{?el5:1}
ExclusiveArch:  noarch i386 x86_64 ppc ppc64 ia64 s390 s390x
%endif # 0%{?el5:1}

%ifarch s390x
%if %{suse_version} > 1500
BuildRequires:  babeltrace-devel
%endif
%endif

%ifarch i386 x86_64 ppc64 ppc64le aarch64 riscv64
%if %{suse_version} >= 1500
BuildRequires:  babeltrace-devel
%endif
%endif

%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_regex-devel
BuildRequires:  libsource-highlight-devel
%endif

%if 0%{?suse_version} >= 1500
BuildRequires:  libzstd-devel
%endif

%if %{build_testsuite}

# Copied from gcc9/gcc.spec.in
# Ada currently fails to build on a few platforms, enable it only
# on those that work
%if %{suse_version} >= 1310
%if %{suse_version} >= 1330
%define ada_arch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x ia64 aarch64 riscv64
%else
%define ada_arch %ix86 x86_64 ppc ppc64 s390 ia64
%endif
%else
%define ada_arch %ix86 x86_64 ppc s390 ia64
%endif

# Ensure the devel libraries are installed for both multilib arches.
%global bits_local %{?_isa}
%global bits_other %{?_isa}
%if 0%{!?el5:1}
%ifarch s390x
%global bits_other (%{__isa_name}-32)
%else #!s390x
%ifarch ppc
%global bits_other (%{__isa_name}-64)
%else #!ppc
%ifarch sparc64 ppc64 s390x x86_64
%global bits_other (%{__isa_name}-32)
%endif #sparc64 ppc64 s390x x86_64
%endif #!ppc
%endif #!s390x
%endif #!el5

BuildRequires:  dejagnu
BuildRequires:  sharutils
# gcc-objc++ is not covered by the GDB testsuite.

BuildRequires:  gcc-fortran
BuildRequires:  gcc-objc
%ifarch %ada_arch
BuildRequires:  gcc-ada
%endif

%define supported_32bit_arch x86_64 ppc64

%if 0%{!?disable_32bit:1}
%ifarch %{supported_32bit_arch}

%if 0%{suse_version} >= 1330
# Older distros miss this pseudo package, the Ada
# testsuite won't work completely
BuildRequires:  gcc-ada-32bit
%endif

%if 0%{suse_version} > 1110
BuildRequires:  gcc-c++-32bit
%endif

# Use system g++ for testing SLE-12.
BuildRequires:  gcc-c++

%if 0%{suse_version} >= 1210 && 0%{suse_version} != 1315
BuildRequires:  glibc-devel-static-32bit
%endif

%endif # supported_32bit_arch
%endif # !disable_32bit

%if 0%{suse_version} >= 1210
BuildRequires:  glibc-devel-static
%endif

%if 0%{?suse_version} > 1500
# The gccgo command is used by make check for some gdb.go test-cases, so we
# need the gcc-go package.  However, the gccgo command was missing from the
# gcc-go package (bsc#1096677), so we only require it for known fixed
# versions.
BuildRequires:  gcc-go

%if 0%{?suse_version} > 1600
# Fix: unresolvable:
# have choice for libgo.so.23()(64bit) needed by gcc14-go: libgo23 libgo23-gcc14
# have choice for libgo23 >= 14.2.1+git10750-37.2 needed by gcc14-go: libgo23 libgo23-gcc14
BuildRequires:  libgo23
%endif
%endif

%if %{with fpc} && 0%{?is_opensuse}
%ifarch x86_64 aarch64 armv7l
# Tumbleweed and Leap 15.x.
%if 0%{?suse_version} >= 1500
BuildRequires:  fpc
%endif
%ifarch %{ix86}
# Tumbleweed and Leap 15.{0,1,2}.
# fpc seems to be unavailable for Leap 15.{3,4}/i586.
%if 0%{?suse_version} > 1500 || (0%{?sle_version} >= 150000 && 0%{?sle_version} <= 150200)
BuildRequires:  fpc
%endif
%endif
%endif
%endif

%if 0%{?suse_version} >= 1200
%ifnarch s390
# s390 (for SLE12) doesn't have valgrind
BuildRequires:  valgrind
%endif
%endif

%if 0%{?suse_version} >= 1200
BuildRequires:  systemtap-sdt-devel
%endif

%if 0%{have_libdebuginfod}
BuildRequires:  curl
BuildRequires:  elfutils-debuginfod
# Fix: unresolvable: have choice for debuginfod-client needed by
# elfutils-debuginfod: debuginfod-client debuginfod-dummy-client.
BuildRequires:  debuginfod-client
%endif

# SLE-10 doesn't have xz.
%if 0%{suse_version} >= 1110
# Missing on SLE-11
BuildRequires:  xz
%endif

%if 0%{!?_without_python:1}
# Provide python package xml.etree.ElementTree, used by test-case
# gdb.python/py-send-packet.exp.
BuildRequires:  %{python}-xml
%endif

%endif # %%{build_testsuite}

%ifarch ia64
BuildRequires:  libunwind-devel
Requires:       libunwind
%endif

%if %{build_main}

%if 0%{!?_without_python:1}
%if 0%{?suse_version} >= 1500
# For SLE-15 and later, we use source-highlight by default, and
# pygments as fallback.  So, suggests rather than recommends is what we want.
# Don't bother older releases with this.
Suggests:       %{python}-Pygments
%endif
%endif

%description
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

%package -n gdbserver
Summary:        A standalone server for GDB (the GNU source-level debugger)
License:        GPL-3.0-only WITH GCC-exception-3.1 AND GPL-3.0-or-later AND LGPL-2.1-or-later AND LGPL-3.0-or-later
Group:          Development/Tools/Debuggers

%description -n gdbserver
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

This package provides a program that allows you to run GDB on a different
machine than the one which is running the program being debugged.

%package doc
Summary:        Documentation for GDB (the GNU source-level debugger)
License:        GFDL-1.3-only
Group:          Documentation/Other
PreReq:         %{install_info_prereq}

%if "%{scl}" == "devtoolset-1.1"
Obsoletes:      devtoolset-1.0-%{pkg_name}-doc
%endif

%description doc
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

This package provides INFO, HTML and PDF user manual for GDB.
%endif

%if %{build_testsuite}
%description
Results from running the GDB testsuite.
%endif

%prep
%setup -q -n %{gdb_src}

%if 0%{?rhel:1} && 0%{?rhel} <= 6
# libstdc++ pretty printers.
tar xjf %{SOURCE5}
%endif # 0%{?rhel:1} && 0%{?rhel} <= 6

# Files have `# <number> <file>' statements breaking VPATH / find-debuginfo.sh .
rm -f gdb/ada-exp.c gdb/ada-lex.c gdb/c-exp.c gdb/cp-name-parser.c gdb/f-exp.c
rm -f gdb/jv-exp.c gdb/m2-exp.c gdb/objc-exp.c gdb/p-exp.c gdb/go-exp.c

# *.info* is needlessly split in the distro tar; also it would not get used as
# we build in %%{gdb_build}, just to be sure.
find -name "*.info*"|xargs rm -f

#Fedora patching start
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 10 -p1
%patch -P 12 -p1
%patch -P 15 -p1
%patch -P 16 -p1
%patch -P 20 -p1
%patch -P 21 -p1
#Fedora patching end

%patch -P 1000 -p1

%patch -P 1100 -p1
%patch -P 1101 -p1

%patch -P 1200 -p1
%patch -P 1203 -p1
%patch -P 1204 -p1

%patch -P 1500 -p1
%patch -P 1501 -p1
%patch -P 1503 -p1
%patch -P 1504 -p1
%patch -P 1505 -p1
%patch -P 1506 -p1
%patch -P 1507 -p1
%patch -P 1508 -p1

%patch -P 2000 -p1
%patch -P 2001 -p1
%patch -P 2002 -p1
%patch -P 2003 -p1
%patch -P 2004 -p1
%patch -P 2005 -p1
%patch -P 2006 -p1
%patch -P 2007 -p1
%patch -P 2008 -p1
%patch -P 2009 -p1
%patch -P 2010 -p1
%patch -P 2011 -p1
%patch -P 2012 -p1
%patch -P 2013 -p1
%patch -P 2014 -p1
%patch -P 2015 -p1
%patch -P 2016 -p1
%patch -P 2017 -p1
%patch -P 2018 -p1
%patch -P 2019 -p1
%patch -P 2020 -p1
%patch -P 2021 -p1
%patch -P 2022 -p1
%patch -P 2023 -p1
%patch -P 2024 -p1
%patch -P 2025 -p1
%patch -P 2026 -p1
%patch -P 2027 -p1
%patch -P 2028 -p1
%patch -P 2029 -p1
%patch -P 2030 -p1
%patch -P 2031 -p1
%patch -P 2032 -p1
%patch -P 2033 -p1

%patch -P 2100 -p1
%patch -P 2101 -p1
%patch -P 2102 -p1
%patch -P 2103 -p1
%patch -P 2104 -p1
%patch -P 2105 -p1
%patch -P 2106 -p1
%patch -P 2107 -p1
%patch -P 2108 -p1
%patch -P 2109 -p1
%patch -P 2110 -p1
%patch -P 2111 -p1
%patch -P 2112 -p1
%patch -P 2113 -p1
%patch -P 2114 -p1
%patch -P 2115 -p1
%patch -P 2116 -p1
%patch -P 2117 -p1
%patch -P 2118 -p1
%patch -P 2119 -p1
%patch -P 2120 -p1
%patch -P 2121 -p1
%patch -P 2122 -p1

%patch -P 3000 -p1
%patch -P 3001 -p1
%patch -P 3002 -p1
%patch -P 3003 -p1
%patch -P 3004 -p1
%patch -P 3005 -p1
%patch -P 3006 -p1
%patch -P 3007 -p1

#unpack libipt
%if 0%{have_libipt}
tar xzf %{SOURCE7}
mv libipt-%{libipt_version} processor-trace-%{libipt_version}
%endif

find -name "*.orig" | xargs rm -f
! find -name "*.rej" # Should not happen.

# Remove the info and other generated files added by the FSF release
# process.
rm -f libdecnumber/gstdint.h
rm -f bfd/doc/*.info
rm -f bfd/doc/*.info-*
rm -f gdb/doc/*.info
rm -f gdb/doc/*.info-*

# Fixes problem building release tarball with --with-system-readline.
# Reported here:
# - https://sourceware.org/pipermail/gdb/2021-July/049552.html
# - https://sourceware.org/bugzilla/show_bug.cgi?id=27808
rm -f gdb/doc/GDBvn.texi

%build

# Identify the build directory with the version of gdb as well as the
# architecture, to allow for mutliple versions to be installed and
# built.
# Initially we're in the %%{gdb_src} directory.

for fprofile in %{?_with_profile:-fprofile} ""
do

mkdir %{gdb_build}$fprofile
cd %{gdb_build}$fprofile

%if 0%{suse_version} > 1315
CC=gcc
CXX=g++
%else
# SLE-12.
CC=gcc-11
CXX=g++-11
%endif
export CC
export CXX
export CFLAGS="$RPM_OPT_FLAGS"

# Add your -Wno-x/-Wno-error=y options here:
for opt in -Wno-error=odr -Wno-error=enum-int-mismatch; do
  # checking for acceptance of -Wno-foo is a bit wieldy: GCC doesn't
  # warn about unknown -Wno- flags, _except_ if there are other
  # diagnostics as well, so let's force an uninitialized use warning
  # and grep for the diagnostic about the -Wno flag:
  if ! echo "int foo(void) { int a; return a;} " | \
     $CC  -x c -c - -o /dev/null -W ${opt} 2>&1 | \
     grep -E "Wno|no option" >/dev/null; then
    CFLAGS="$CFLAGS ${opt}"
  fi
done
%if %{have_libipt}
CFLAGS="$CFLAGS -DPERF_ATTR_SIZE_VER5_BUNDLE"
(
 mkdir processor-trace-%{libipt_version}-root
 mkdir processor-trace-%{libipt_version}-build
 cd    processor-trace-%{libipt_version}-build
 # -DPTUNIT:BOOL=ON has no effect on ctest.
 cmake -DCMAKE_INSTALL_PREFIX=/usr -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DBUILD_SHARED_LIBS=OFF \
        -DPTUNIT:BOOL=OFF \
        -DDEVBUILD:BOOL=ON \
        ../../processor-trace-%{libipt_version}
 make VERBOSE=1 %{?_smp_mflags}
 ctest -V %{?_smp_mflags}
 make install DESTDIR=../processor-trace-%{libipt_version}-root
)
# There is also: --with-libipt-prefix
CFLAGS="$CFLAGS -I$PWD/processor-trace-%{libipt_version}-root%{_includedir}"
LDFLAGS="$LDFLAGS -L$PWD/processor-trace-%{libipt_version}-root%{_libdir}"
%endif

export CXXFLAGS="$CFLAGS"

%ifarch %ix86 ia64 ppc ppc64 ppc64le s390 s390x x86_64 aarch64 riscv64
%define build_multitarget 1
%else
%define build_multitarget 0
%endif

%define extra_target_list_common i686 powerpc64le s390x x86_64 aarch64
%if 0%{?is_opensuse}
%define extra_target_list %{extra_target_list_common} powerpc powerpc64 s390 arm m68k ia64 riscv64
%define have_elf_extra_target_list 1
%define elf_extra_target_list avr pru spu
%else
%define extra_target_list %{extra_target_list_common}
%define have_elf_extra_target_list 0
%endif

%define DIST %(echo '%distribution' | sed 's, /.*,,')

%if %build_multitarget
EXTRA_TARGETS="%(printf ,%%s-suse-linux %{extra_target_list})"
%if %{have_elf_extra_target_list}
EXTRA_TARGETS="$EXTRA_TARGETS%(printf ,%%s-elf %{elf_extra_target_list})"
%endif
%else
EXTRA_TARGETS=
%endif

# Reenable enable-werror on tumbleweed when upgrading to 13.1 (bsc#1211052)
../configure							\
	--prefix=%{_prefix}					\
	--libdir=%{_libdir}					\
	--sysconfdir=%{_sysconfdir}				\
	--mandir=%{_mandir}					\
	--infodir=%{_infodir}					\
	--htmldir=%{gdb_docdir}					\
	--pdfdir=%{gdb_docdir}					\
	--with-system-gdbinit=%{_sysconfdir}/gdbinit		\
	--with-gdb-datadir=%{_datadir}/gdb			\
	--enable-gdb-build-warnings=,-Wno-unused		\
%ifnarch %{ix86} alpha ia64 ppc s390 s390x x86_64 ppc64 ppc64le sparc sparcv9 sparc64 riscv64 aarch64
	--disable-werror					\
%else
%if %{suse_version} <= 1110 || %{suse_version} > 1500
	--disable-werror					\
%else
	--enable-werror						\
%endif
%endif
	--with-separate-debug-dir=/usr/lib/debug		\
%if 0%{have_libdebuginfod}
	--with-debuginfod=yes                                   \
%endif
	--disable-sim						\
	--disable-rpath						\
	--with-system-zlib					\
%if %{suse_version} >= 1500
	--with-system-readline					\
%else
	--without-system-readline				\
%endif
	--with-expat						\
$(: ppc64 host build crashes on ppc variant of libexpat.so )	\
	--without-libexpat-prefix				\
	--enable-tui						\
%if 0%{!?_without_python:1}
	--with-python=%{_bindir}/%{python}			\
%else
	--without-python					\
%endif
%ifarch ia64
	--with-libunwind-ia64					\
%else
	--without-libunwind					\
%endif
%ifarch sparc sparcv9 sparc64
	--without-mmap						\
%endif
	--enable-64-bit-bfd					\
%if %{have_inproctrace}
	--enable-inprocess-agent				\
%else
	--disable-inprocess-agent				\
%endif
%if %{have_libipt}
        --with-intel-pt                                         \
%else
        --without-intel-pt                                      \
%endif
	--with-bugurl=http://bugs.opensuse.org/ \
	--with-pkgversion="GDB; %{DIST}" \
$(: ia64 is obsolete. )                                         \
	--enable-obsolete                                       \
	${EXTRA_TARGETS:+--enable-targets="${EXTRA_TARGETS#,}"} \
%ifarch sparc sparcv9
	--build=sparc-%{_vendor}-%{_target_os}%{?_gnu}
%else
$(: It breaks RHEL-5 by %{_target_platform} being noarch-redhat-linux-gnu ) \
%ifarch noarch
	$(:)
%else
	--build=%{_target_platform}
%endif
%endif

if [ -z "%{!?_with_profile:no}" ]
then
  # Run all the configure tests being incompatible with $FPROFILE_CFLAGS.
  make %{?_smp_mflags} configure-host configure-target
  make %{?_smp_mflags} clean

  # Workaround -fprofile-use:
  # linux-x86-low.c:2225: Error: symbol `start_i386_goto' is already defined
  make %{?_smp_mflags} -C gdb/gdbserver linux-x86-low.o
fi

# Global CFLAGS would fail on:
# conftest.c:1:1: error: coverage mismatch for function 'main' while reading counter 'arcs'
if [ "$fprofile" = "-fprofile" ]
then
  FPROFILE_CFLAGS='-fprofile-generate'
elif [ -z "%{!?_with_profile:no}" ]
then
  FPROFILE_CFLAGS='-fprofile-use'
  # We cannot use -fprofile-dir as the bare filenames clash.
  (cd ../%{gdb_build}-fprofile;
   # It was 333 on x86_64.
   test $(find -name "*.gcda"|wc -l) -gt 300
   find -name "*.gcda" | while read -r i
   do
     ln $i ../%{gdb_build}/$i
   done
  )
else
  FPROFILE_CFLAGS=""
fi

# Prepare gdb/config.h first.
make %{?_smp_mflags} V=1 CFLAGS="$CFLAGS $FPROFILE_CFLAGS" LDFLAGS="$LDFLAGS $FPROFILE_CFLAGS" maybe-configure-gdb
perl -i.relocatable -pe 's/^(D\[".*_RELOCATABLE"\]=" )1(")$/${1}0$2/' gdb/config.status

make %{?_smp_mflags} V=1 CFLAGS="$CFLAGS $FPROFILE_CFLAGS" LDFLAGS="$LDFLAGS $FPROFILE_CFLAGS"

! grep '_RELOCATABLE.*1' gdb/config.h

if [ "$fprofile" = "-fprofile" ]
then
  cd gdb
  cp -p gdb gdb-withindex
  PATH="$PWD:$PATH" sh ../../gdb/gdb-add-index $PWD/gdb-withindex
  ./gdb -nx -ex q ./gdb-withindex
  ./gdb -nx -readnow -ex q ./gdb-withindex
  cd ..
fi

cd ..

done	# fprofile

cd %{gdb_build}

#make %{?_smp_mflags} -C gdb/doc {gdb,annotate}{.info,/index.html,.pdf} MAKEHTMLFLAGS=--no-split

# Copy the <sourcetree>/gdb/NEWS file to the directory above it.
cp $RPM_BUILD_DIR/%{gdb_src}/gdb/NEWS $RPM_BUILD_DIR/%{gdb_src}

%check
# Initially we're in the %%{gdb_src} directory.
cd %{gdb_build}

%if !%{build_testsuite}
echo ====================TESTSUITE DISABLED=========================
%else
echo ====================TESTING=========================
cd gdb
CC=gcc
CXX=g++
export CC
export CXX
$CC -o ./orphanripper %{SOURCE2} -Wall -lutil -ggdb2
# Need to use a single --ignore option, second use overrides first.
# No `%{?_smp_mflags}' here as it may race.
# WARNING: can't generate a core file - core tests suppressed - check ulimit
# "readline-overflow.exp" - Testcase is broken, functionality is OK.
(
  # ULIMIT required for `gdb.base/auxv.exp'.
  ulimit -H -c
  ulimit -c unlimited || :

  # Setup $CHECK as `check//unix/' or `check//unix/-m64' for explicit bitsize.
  # Never use two different bitsizes as it fails on ppc64.
  echo 'int main (void) { return 0; }' >biarch.c
  CHECK=""
  for BI in -m64 -m32 -m31 ""
  do
    # Do not use size-less options if any of the sizes works.
    # On ia64 there is no -m64 flag while we must not leave a bare `check' here
    # as it would switch over some testing scripts to the backward compatibility
    # mode: when `make check' was executed from inside the testsuite/ directory.
    if [ -z "$BI" -a -n "$CHECK" ];then
      continue
    fi
    # Do not use $RPM_OPT_FLAGS as the other non-size options will not be used
    # in the real run of the testsuite.
    if ! $CC $BI -o biarch biarch.c
    then
      continue
    fi
    CHECK="$CHECK check//unix/$BI"
  done
  # Do not try -m64 inferiors for -m32 GDB as it cannot handle inferiors larger
  # than itself.
  # s390 -m31 still uses the standard ELF32 binary format.
  $CC $RPM_OPT_FLAGS -o biarch biarch.c
  RPM_SIZE="$(file ./biarch|sed -n 's/^.*: ELF \(32\|64\)-bit .*$/\1/p')"
  if [ "$RPM_SIZE" != "64" ]
  then
    CHECK="$(echo " $CHECK "|sed 's# check//unix/-m64 # #')"
  fi

  # Disable some problematic testcases.
  # RUNTESTFLAGS='--ignore ...' is not used below as it gets separated by the
  # `check//...' target spawn and too much escaping there would be dense.
  DISABLE_TESTS=
  DISABLE_TESTS="$DISABLE_TESTS gdb.base/bigcore.exp"
  DISABLE_TESTS="$DISABLE_TESTS gdb.threads/attach-many-short-lived-threads.exp"
  %if 0%{suse_version} == 1110
  DISABLE_TESTS="$DISABLE_TESTS gdb.base/break-interp.exp"
  %endif
  for test in $DISABLE_TESTS; do
    mv -f ../../gdb/testsuite/$test ../../gdb/testsuite/$test-DISABLED || :
  done

  # Run all the scheduled testsuite runs also in the PIE mode.
  # See also: gdb-runtest-pie-override.exp
  if rpm -q gcc-PIE; then
      CHECK="$(echo $CHECK | sed 's#check//unix/[^ ]*#& &/-fno-PIE/-no-pie#g')"
  else
      CHECK="$(echo $CHECK | sed 's#check//unix/[^ ]*#& &/-fPIE/-pie#g')"
  fi

%if %{with for_chroot}
  # When we want to chroot into a local osc build and run a test-case, we
  # need -M testsuite to add all the buildrequires, but there's no need
  # to run the testsuite.  Instead, fail %check to make sure %clean doesn't
  # remove buildroot.
  false
%else
  ./orphanripper make %{?_smp_mflags} -k $CHECK || :
%endif
)
for t in sum log
do
  for file in testsuite*/gdb.$t
  do
    suffix="${file#testsuite.unix.}"
    suffix="${suffix%/gdb.$t}"
    ln $file gdb-%{_target_platform}$suffix.$t || :
  done
done
# `tar | bzip2 | uuencode' may have some piping problems in Brew.
#tar cjf gdb-%%{_target_platform}.tar.bz2 gdb-%%{_target_platform}*.{sum,log}
#uuencode gdb-%%{_target_platform}.tar.bz2 gdb-%%{_target_platform}.tar.bz2
# Strip dates and completion times from the log to make build-compare happy
sed -i -e '/Test Run By abuild on/d' -e 's/completed in [0-9]* seconds//' *.{sum,log}
cd ../..
echo ====================TESTING END=====================
%endif

%install
# Initially we're in the %%{gdb_src} directory.
cd %{gdb_build}

# It would break RHEL-5 by leaving excessive files for the doc subpackage.
%ifnarch noarch

make %{?_smp_mflags} install DESTDIR=$RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d
touch -r %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d

%if 0%{!?_without_python:1}
sed 's#%%{_sysconfdir}#%{_sysconfdir}#g' <%{SOURCE4} >$RPM_BUILD_ROOT%{_sysconfdir}/gdbinit
touch -r %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit
%else
sed 's#%%{_sysconfdir}#%{_sysconfdir}#g' <%{SOURCE5} >$RPM_BUILD_ROOT%{_sysconfdir}/gdbinit
touch -r %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit
%endif

for i in `find $RPM_BUILD_ROOT%{_datadir}/gdb/python/gdb -name "*.py"`
do
  # Files could be also patched getting the current time.
  touch -r $RPM_BUILD_DIR/%{gdb_src}/gdb/version.in $i
done

%if 0%{?_enable_debug_packages:1} && 0%{!?_without_python:1}
mkdir -p $RPM_BUILD_ROOT/usr/lib/debug%{_bindir}
cp -p $RPM_BUILD_DIR/%{gdb_src}/gdb/gdb-gdb.py $RPM_BUILD_ROOT/usr/lib/debug%{_bindir}/
for pyo in "" "-O";do
  # RHEL-5: AttributeError: 'module' object has no attribute 'compile_file'
  %{python} $pyo -c 'import compileall, re, sys; sys.exit (not compileall.compile_dir("'"$RPM_BUILD_ROOT/usr/lib/debug%{_bindir}"'", 1, "'"/usr/lib/debug%{_bindir}"'"))'
done
%endif # 0%{?_enable_debug_packages:1} && 0%{!?_without_python:1}

mkdir $RPM_BUILD_ROOT%{_datadir}/gdb/auto-load
%if 0%{?rhel:1} && 0%{?rhel} <= 6
%if 0%{!?_without_python:1}
# Temporarily now:
for LIB in lib lib64;do
  LIBPATH="$RPM_BUILD_ROOT%{_datadir}/gdb/auto-load%{_root_prefix}/$LIB"
  mkdir -p $LIBPATH
  # basename is being run only for the native (non-biarch) file.
  sed -e 's,@pythondir@,%{_datadir}/gdb/python,'		\
      -e 's,@toolexeclibdir@,%{_root_prefix}/'"$LIB,"		\
      < $RPM_BUILD_DIR/%{gdb_src}/%{libstdcxxpython}/hook.in	\
      > $LIBPATH/$(basename %{_root_prefix}/%{_lib}/libstdc++.so.6.*)-gdb.py
  # Test the filename 'libstdc++.so.6.*' has matched.
  test -f $LIBPATH/libstdc++.so.6.[0-9]*-gdb.py
done
test ! -e $RPM_BUILD_ROOT%{_datadir}/gdb/python/libstdcxx
cp -a $RPM_BUILD_DIR/%{gdb_src}/%{libstdcxxpython}/libstdcxx	\
      $RPM_BUILD_ROOT%{_datadir}/gdb/python/libstdcxx
for i in `find $RPM_BUILD_ROOT%{_datadir}/gdb/python -name "*.py"` \
         `find $RPM_BUILD_ROOT%{_datadir}/gdb/auto-load%{_prefix} -name "*.py"` \
; do
  # Files come from gdb-archer.patch and can be also further patched.
  touch -r $RPM_BUILD_DIR/%{gdb_src}/gdb/version.in $i
done
%endif # 0%{!?_without_python:1}
%endif # 0%{?rhel:1} && 0%{?rhel} <= 6

# Remove the files that are part of a gdb build but that are owned and
# provided by other packages.
# These are part of binutils

rm -rf $RPM_BUILD_ROOT%{_datadir}/locale/
rm -f $RPM_BUILD_ROOT%{_infodir}/bfd*
rm -f $RPM_BUILD_ROOT%{_infodir}/standard*
rm -f $RPM_BUILD_ROOT%{_infodir}/configure*
rm -f $RPM_BUILD_ROOT%{_infodir}/sframe-spec*
rm -rf $RPM_BUILD_ROOT%{_includedir}
rm -rf $RPM_BUILD_ROOT/%{_libdir}/lib{bfd*,opcodes*,iberty*,ctf*,sframe*}

%if %{build_testsuite}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit
rm -rf $RPM_BUILD_ROOT%{_bindir}
rm -rf $RPM_BUILD_ROOT%{_libdir}
rm -rf $RPM_BUILD_ROOT%{_datadir}/gdb
rm -rf $RPM_BUILD_ROOT%{_infodir}
rm -rf $RPM_BUILD_ROOT%{_mandir}
rm -rf $RPM_BUILD_ROOT/usr/src
%endif

# pstack obsoletion

%if %{build_main}
cp -p %{SOURCE3} $RPM_BUILD_ROOT%{_mandir}/man1/gstack.1
%endif
%endif	# 0%{!?_with_upstream:1}

%if %{build_main}
# Packaged GDB is not a cross-target one.
(cd $RPM_BUILD_ROOT%{_datadir}/gdb/syscalls
 rm -f mips*.xml
%ifnarch sparc sparcv9 sparc64
 rm -f sparc*.xml
%endif
%ifnarch x86_64
 rm -f amd64-linux.xml
%endif
%ifnarch %{ix86} x86_64
 rm -f i386-linux.xml
%endif
%ifnarch ppc ppc64
 rm -f ppc{,64}-linux.xml
%endif
%ifnarch ppc64le
 rm -f ppc64le-linux.xml
%endif
)

# It would break RHEL-5 by leaving excessive files for the doc subpackage.
%if 0%{?el5:1}
rm -f $RPM_BUILD_ROOT%{_infodir}/annotate.info*
rm -f $RPM_BUILD_ROOT%{_infodir}/gdb.info*
%endif # 0%{?el5:1}
# -j1: There is some race resulting in:
# /usr/bin/texi2dvi: texinfo.tex appears to be broken, quitting.
make -j1 -C gdb/doc install DESTDIR=$RPM_BUILD_ROOT

# Documentation only for development; keep 'rm's here after "noarch" above.
rm -f $RPM_BUILD_ROOT%{_infodir}/gdbint*
rm -f $RPM_BUILD_ROOT%{_infodir}/stabs*
rm -f $RPM_BUILD_ROOT%{_infodir}/ctf-spec*

# Delete this too because the dir file will be updated at rpm install time.
# We don't want a gdb specific one overwriting the system wide one.

rm -f $RPM_BUILD_ROOT%{_infodir}/dir

%endif

%post
# This step is part of the installation of the RPM. Not to be confused
# with the 'make install ' of the build (rpmbuild) process.

# For --excludedocs:
if [ -e %{_infodir}/gdb.info.gz ]
then
  %install_info --info-dir=%{_infodir} %{_infodir}/annotate.info.gz
  %install_info --info-dir=%{_infodir} %{_infodir}/gdb.info.gz
fi

%preun
if [ $1 = 0 ]
then
  # For --excludedocs:
  if [ -e %{_infodir}/gdb.info.gz ]
  then
    %install_info_delete --delete --info-dir=%{_infodir} %{_infodir}/annotate.info.gz
    %install_info_delete --delete --info-dir=%{_infodir} %{_infodir}/gdb.info.gz
  fi
fi

%if %{build_main}
%files
%defattr(-,root,root)
%doc README NEWS
%if 0%{suse_version} >= 1320
%license COPYING3 COPYING COPYING.LIB
%else
%doc COPYING3 COPYING COPYING.LIB
%endif
%{_bindir}/gcore
%{_mandir}/*/gcore.1*
%{_bindir}/gdb
%config(noreplace) %{_sysconfdir}/gdbinit
%{_sysconfdir}/gdbinit.d
%{_mandir}/*/gdb.1*
%{_bindir}/gstack
%{_mandir}/*/gstack.1*
%{_bindir}/gdb-add-index
%{_mandir}/*/gdb-add-index.1*
%{_mandir}/*/gdbinit.5*
%{_datadir}/gdb
%{_infodir}/annotate.info*
%{_infodir}/gdb.info*
%endif

%if %{build_testsuite}
%files
%defattr(-,root,root)
%doc %{gdb_build}/gdb/gdb-*.sum
%doc %{gdb_build}/gdb/gdb-*.log
%endif

# don't include the files in include, they are part of binutils

%if %{build_main}
%ifnarch sparcv9 hppa
%files -n gdbserver
%defattr(-,root,root)
%{_bindir}/gdbserver
%{_mandir}/*/gdbserver.1*
%if %{have_inproctrace}
%{_libdir}/libinproctrace.so
%endif # %%{have_inproctrace}
%endif
%endif

%if %{build_main}
%post doc
# This step is part of the installation of the RPM. Not to be confused
# with the 'make install ' of the build (rpmbuild) process.

# For --excludedocs:
if [ -e %{_infodir}/gdb.info.gz ]
then
  /sbin/install-info --info-dir=%{_infodir} %{_infodir}/annotate.info.gz || :
  /sbin/install-info --info-dir=%{_infodir} %{_infodir}/gdb.info.gz || :
fi

%preun doc
if [ $1 = 0 ]
then
  # For --excludedocs:
  if [ -e %{_infodir}/gdb.info.gz ]
  then
    /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/annotate.info.gz || :
    /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/gdb.info.gz || :
  fi
fi
%endif

%changelog
* Tue Feb 18 2025 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR32712 kfail.
* Thu Feb 13 2025 Tom de Vries <tdevries@suse.com>
- Mention changes in GDB 15:
  * The MPX commands "show/set mpx bound" have been deprecated, as
  Intel listed MPX as removed in 2019.
  * GDB index now contains information about the main function.
  * This speeds up startup when it is being used for some large
    binaries.
  * On hosts where threading is available, DWARF reading is now
    done in the background, resulting in faster startup.  This can
    be controlled using "maint set dwarf synchronous".
  * Changed commands:
  * disassemble:
    Attempting to use both the 'r' and 'b' flags with the
    disassemble command will now give an error.  Previously the
    'b' flag would always override the 'r' flag.
  * gcore, generate-core-file:
    GDB now generates sparse core files, on systems that support
    it.
  * maintenance info line-table:
    Add an EPILOGUE-BEGIN column to the output of the command.
    It indicates if the line is considered the start of the
    epilogue, and thus a point at which the frame can be
    considered destroyed.
  * set unwindonsignal on|off, show unwindonsignal:
    These commands are now aliases for the new
    set/show unwind-on-signal.
  * target record-full:
    This command now gives an error if any unexpected arguments
    are found after the command.
  * list .:
    When using the command "list ." in a location that has no
    debug information or no file loaded, GDB now says that there
    is no debug information to print lines.  This makes it more
    obvious that there is no information, as opposed to implying
    there is no inferior loaded.
  * New commands:
  * info missing-debug-handler:
    List all the registered missing debug handlers.
  * enable missing-debug-handler LOCUS HANDLER,
    disable missing-debug-handler LOCUS HANDLER:
    Enable or disable a missing debug handler with a name
    matching the regular expression HANDLER, in LOCUS.
    LOCUS can be 'global' to operate on global missing debug
    handler, 'progspace' to operate on handlers within the
    current program space, or can be a regular expression which
    is matched against the filename of the primary executable in
    each program space.
  * maintenance info linux-lwps:
    List all LWPs under control of the linux-nat target.
  * set remote thread-options-packet,
    show remote thread-options-packet:
    Set/show the use of the thread options packet.
  * set direct-call-timeout SECONDS, show direct-call-timeout,
    set indirect-call-timeout SECONDS,
    show indirect-call-timeout:
    These new settings can be used to limit how long GDB will
    wait for an inferior function call to complete.  The direct
    timeout is used for inferior function calls from e.g. 'call'
    and 'print' commands, while the indirect timeout is used for
    inferior function calls from within a conditional breakpoint
    expression.
    The default for the direct timeout is unlimited, while the
    default for the indirect timeout is 30 seconds.
    These timeouts will only have an effect for targets that are
    operating in async mode.  For non-async targets the timeouts
    are ignored, GDB will wait indefinitely for an inferior
    function to complete, unless interrupted by the user using
    Ctrl-C.
  * set unwind-on-timeout on|off, show unwind-on-timeout:
    These commands control whether GDB should unwind the stack
    when a timeout occurs during an inferior function call.  The
    default is off, in which case the inferior will remain in
    the frame where the timeout occurred.  When on, GDB will
    unwind the stack removing the dummy frame that was added for
    the inferior call, and restoring the inferior state to how
    it was before the inferior call started.
  * set unwind-on-signal on|off, show unwind-on-signal:
    These new commands replaces the existing set/show
    unwindonsignal.  The old command is maintained as an alias.
  * New features in the GDB remote stub, GDBserver:
  * The --remote-debug and --event-loop-debug command line
    options have been removed.
  * The --debug command line option now takes an optional comma
    separated list of components to emit debug for.  The
    currently supported components are: all, threads,
    event-loop, and remote.  If no components are given then
    threads is assumed.
  * The 'monitor set remote-debug' and 'monitor set
    event-loop-debug' command have been removed.
  * The 'monitor set debug 0|1' command has been extended to
    take a component name, e.g.: 'monitor set debug COMPONENT
    off|on'.  Possible component names are: all, threads,
    event-loop, and remote.
  * Python API:
  * New function gdb.notify_mi(NAME, DATA), that emits custom
    GDB/MI async notification.
  * New read/write attribute gdb.Value.bytes that contains a
    bytes object holding the contents of this value.
  * New module gdb.missing_debug that facilitates dealing with
    objfiles that are missing any debug information.
  * New function gdb.missing_debug.register_handler that can
    register an instance of a sub-class of
    gdb.missing_debug.MissingDebugInfo as a handler for objfiles
    that are missing debug information.
  * New class gdb.missing_debug.MissingDebugInfo which can be
    sub-classed to create handlers for objfiles with missing
    debug information.
  * Stop events now have a "details" attribute that holds a
    dictionary that carries the same information as an MI
    "*stopped" event.
  * New function gdb.interrupt(), that interrupts GDB as if the
    user typed control-c.
  * New gdb.InferiorThread.ptid_string attribute.  This
    read-only attribute contains the string that appears in the
    'Target Id' column of the 'info threads' command output.
  * It is no longer possible to create new gdb.Progspace object
    using 'gdb.Progspace()', this will result in a TypeError.
    Progspace objects can still be obtained through calling
    other API functions, for example 'gdb.current_progspace()'.
  * User defined attributes can be added to a gdb.Inferior
    object, these will be stored in the object's new
    Inferior.__dict__ attribute.
  * User defined attributes can be added to a gdb.InferiorThread
    object, these will be stored in the object's new
    InferiorThread.__dict__ attribute.
  * New constants gdb.SYMBOL_TYPE_DOMAIN,
    gdb.SYMBOL_FUNCTION_DOMAIN, and gdb.SEARCH_*_DOMAIN
    corresponding to all the existing symbol domains.  Symbol
    lookup can now search in multiple domains at once, and can
    also narrowly search for just a type or function.
  * Debugger Adapter Protocol changes:
  * GDB now emits the "process" event.
  * GDB now supports the "cancel" request.
  * The "attach" request now supports specifying the program.
  * New command "set debug dap-log-level" controls DAP logging.
  * The "set debug dap-log-file" command is now documented.
    This command was available in GDB 14 but not documented.
  * Guile API:
  * New constants SYMBOL_TYPE_DOMAIN, SYMBOL_FUNCTION_DOMAIN,
    and SEARCH_*_DOMAIN corresponding to all the existing symbol
    domains.  Symbol lookup can now search in multiple domains
    at once, and can also narrowly search for just a type or
    function.
  * Remote packets:
  * New stop reason clone:
    Indicates that a clone system call was executed.
  * New remote packets:
  * QThreadOptions:
    Enable/disable optional event reporting, on a per-thread
    basis.  Currently supported options are
    GDB_THREAD_OPTION_CLONE, to enable clone event reporting,
    and GDB_THREAD_OPTION_EXIT to enable thread exit event
    reporting.
  * QThreadOptions in qSupported:
  * The qSupported packet allows GDB to inform the stub it
    supports the QThreadOptions packet, and the qSupported
    response can contain the set of thread options the remote
    stub supports.
  * qIsAddressTagged:
    This new packet allows GDB to query the stub about a given
    address to check if it is tagged or not.  Many memory
    tagging-related GDB commands need to perform this check
    before they read/write the allocation tag related to an
    address.  Currently, however, this is done through a 'vFile'
    request to read the file /proc/<PID>/smaps and check if the
    address is in a region reported as memory tagged.  Since not
    all targets have a notion of what the smaps file is about,
    this new packet provides a more generic way to perform such
    a check.
* Wed Feb 12 2025 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Fix 16.0 handling.
- Patches added:
  * gdb-testsuite-fix-gdb.python-py-format-string.exp-wi.patch
  * gdb-testsuite-fix-gdb.python-py-mi-cmd.exp-with-pyth.patch
  * gdb-testsuite-fix-gdb.ada-mi_task_arg.exp-on-arm-lin.patch
  * gdb-testsuite-fix-regexp-in-gdb.ada-mi_var_access.ex.patch
  * gdb-testsuite-check-gnatmake-version-in-gdb.ada-scal.patch
  * gdb-testsuite-fix-gdb.arch-arm-pseudo-unwind.exp-wit.patch
  * gdb-symtab-fix-target-type-of-complex-long-double-on.patch
  * gdb-testsuite-don-t-use-set-auto-solib-add-off.patch
  * gdb-tdep-fix-arm-thumb2-hw-breakpoint.patch
  * gdb-testsuite-fix-gdb.cp-m-static.exp-on-arm.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-fixed-point.exp-on-.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-lines.exp-on-arm-li.patch
  * gdb-exp-fix-gdb.fortran-intrinsics.exp-fail-on-arm.patch
  * gdb-tdep-handle-sycall-statx-for-arm-linux.patch
  * gdb-tdep-fix-recording-of-t1-push.patch
  * gdb-tdep-handle-syscall-clock_gettime64-for-arm-linu.patch
  * fix-gdb.dwarf2-shortpiece.exp-on-s390x.patch
  * handle-address-class-annotation-for-s390x-in-some-te.patch
  * fix-gdb.dap-step-out.exp-on-s390x.patch
  * use-setvariable-in-gdb.dap-scopes.exp.patch
  * fix-gdb.base-finish-pretty.exp-on-s390x.patch
  * fix-gdb.base-readnever.exp-on-s390x.patch
  * add-dwarf_expr_piece.op.patch
  * add-gdbarch_dwarf2_reg_piece_offset-hook.patch
  * fix-gdb.base-store.exp-on-s390x.patch
  * fix-gdb.ada-o2_float_param.exp-on-s390x-linux.patch
  * gdb-testsuite-fix-gdb.base-branch-to-self.exp-on-arm.patch
  * gdb-tdep-fix-gdb.cp-non-trivial-retval.exp-on-riscv6.patch
  * gdb-testsuite-fix-gdb.cp-non-trivial-retval.exp-on-a.patch
  * gdb-testsuite-fix-gdb.rust-completion.exp-timeout-on.patch
  * gdb-testsuite-require-supports_process_record-in-gdb.patch
  * gdb-testsuite-fix-regexp-in-gdb.arch-i386-disp-step-.patch
  * gdb-testsuite-fix-gdb.arch-arm-single-step-kernel-he.patch
  * gdb-testsuite-fix-gdb.python-py-format-address.exp-o.patch
  * gdb-testsuite-fix-gdb.arch-riscv-tdesc-regs.exp.patch
  * gdb-testsuite-fix-gdb.base-list-dot-nodebug-and-make.patch
  * gdb-testsuite-fix-gdb.base-list-dot-nodebug.exp-on-o.patch
  * gdb-testsuite-fix-gdb.base-empty-host-env-vars.exp.patch
  * gdb-prune-inferior-after-switching-inferior.patch
  * gdb-testsuite-use-nostdlib-in-gdb.base-list-dot-node.patch
  * gdb-testsuite-fix-timeout-in-gdb.mi-mi-multi-command.patch
  * gdb-testsuite-require-can_spawn_for_attach-in-gdb.ba.patch
  * fixup-gdb-6.5-gcore-buffer-limit-test.patch
  * gdb-testsuite-fix-gdb.ada-big_packed_array.exp-on-s3.patch
  * gdb-testsuite-fix-gdb.ada-convvar_comp.exp-on-s390x-.patch
  * gdb-testsuite-fix-regexp-in-gdb.threads-stepi-over-c.patch
* Tue Feb 11 2025 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add kfail for PR32678.
  * Add kfail for missing g++ on SLE-12.
  * Drop Leap 15.5, add 16.0.
  * Move PR32167 kfail from kfail_sle12 to kfail, and extend
    pattern.
- Use gcc 11 instead gcc 9 for SLE-12.
- Maintenance script qa-local.sh:
  * Drop Leap 15.5, add 16.0.
* Thu Feb  6 2025 Tom de Vries <tdevries@suse.com>
- Patches dropped:
  * gdb-rhbz1261564-aarch64-hw-watchpoint-test.patch
  * gdb-test-bt-cfi-without-die.patch
  * fixup-gdb-rhbz1261564-aarch64-hw-watchpoint-test.pat.patch
  * fixup-gdb-test-bt-cfi-without-die.patch
- Maintenance script import-fedora.sh:
  * Add gdb-rhbz1261564-aarch64-hw-watchpoint-test.patch and
    gdb-test-bt-cfi-without-die.patch to skip_patches.
* Thu Feb  6 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ a2f2e9e.
- Patches dropped:
  * gdb-6.5-bz243845-stale-testing-zombie-test.patch
  * fixup-gdb-6.5-bz243845-stale-testing-zombie-test.patch
* Thu Feb  6 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 1116b36.
- Patches dropped:
  * gdb-test-dw2-aranges.patch
  * fixup-gdb-test-dw2-aranges.patch
* Thu Feb  6 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 7c66c1c.
- Patches dropped:
  * gdb-6.6-testsuite-timeouts.patch
* Thu Feb  6 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 2294280.
- Patches dropped:
  * gdb-simultaneous-step-resume-breakpoint-test.patch
* Fri Jan 31 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 926c064 (gdb 15.2).
- Patches dropped:
  * gdb-6.5-section-num-fixup-test.patch
  * gdb-rhbz1007614-memleak-infpy_read_memory-test.patch
- Maintenance script qa-local.sh:
  * Update version to 15.2.
* Thu Jan 30 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 4b0a2e1.
- Patches added:
  * gdb-catchpoint-re-set.patch
* Thu Jan 30 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ d8b64d9.
- Patches dropped:
  * gdb-6.6-bz229517-gcore-without-terminal.patch
* Thu Jan 30 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ a93b826.
- Patches dropped:
  * gdb-rhbz947564-findvar-assertion-frame-failed-testcase.patch
- Maintenance script import-fedora.sh:
  * Add gdb-remove-use-of-py-isascii to skip_patches.
  * Remove gdb-6.7-ppc-clobbered-registers-O2-test.patch from
    skip_patches.
* Thu Jan 30 2025 Tom de Vries <tdevries@suse.com>
- Always BuildRequire gcc-c++ to fix missing testing compiler on
  SLE-12.
- Patches added:
  * gdb-testsuite-handle-unordered-dict-in-gdb.python-py.patch
- Maintenance script qa.sh:
  * Add PR32167 kfail.
* Wed Jan 29 2025 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Extend SLE-12 -static unix/-fPIE/-fpie kfails.
  * Extend ppc64le watchpoint kfail.
  * Extend PR29405 kfail.
- Patches added:
  * gdb-testsuite-fix-gdb.threads-leader-exit-attach.exp.patch
  * gdb-testsuite-use-c-flag-in-c-test-cases.patch
* Mon Jan 27 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ a8e0b3d (gdb 15.1).
- Use gcc-9 for SLE-12 (default gcc 4.8.5 doesn't support C++17).
- Maintenance script qa-local.sh:
  * Update version to 15.1.
- Maintenance script qa.sh:
  * Add kfails due to gcc 4.8.5 DW_TAG_lexical_block oddity.
  * Extend PR24845 kfails.
  * Add PR31721 and PR32608 kfails.
- Patches added:
  * gdb-guile-use-scm_debug_typing_strictness-0.patch
  * gdb-doc-fix-gdb.unwinder-docs.patch
  * gdb-doc-fix-qisaddresstagged-anchor.patch
  * gdb-doc-fix-standard-replies-xref.patch
  * gdb-testsuite-fix-gdb_py_module_available-for-python.patch
  * gdb-testsuite-fix-another-regexp-in-gdb.threads-step.patch
  * gdb-testsuite-fix-timeouts-in-gdb.threads-step-over-.patch
- Patches updated:
  * gdb-6.3-gstack-20050411.patch
  * gdb-6.6-buildid-locate-solib-missing-ids.patch
  * gdb-6.6-buildid-locate.patch
  * gdb-add-rpm-suggestion-script.patch
  * gdb-gcore-bash.patch
  * gdb-python-avoid-depending-on-the-curses-library.patch
  * gdb-python-finishbreakpoint-update.patch
- Patches dropped:
  * gdb-add-missing-debug-ext-lang-hook.patch
  * gdb-add-missing-debug-info-python-hook.patch
  * gdb-do-not-import-py-curses-ascii-module.patch
  * gdb-ftbs-swapped-calloc-args.patch
  * gdb-handle-no-python-gdb-module.patch
  * gdb-merge-debug-symbol-lookup.patch
  * gdb-refactor-find-and-add-separate-symbol-file.patch
  * gdb-reformat-missing-debug-py-file.patch
  * gdb-remove-path-in-test-name.patch
  * gdb-rhbz-2232086-cpp-ify-mapped-symtab.patch
  * gdb-rhbz-2232086-generate-dwarf-5-index-consistently.patch
  * gdb-rhbz-2232086-generate-gdb-index-consistently.patch
  * gdb-rhbz-2232086-reduce-size-of-gdb-index.patch
  * gdb-rhbz2232086-refactor-selftest-support.patch
  * gdb-rhbz2250652-avoid-PyOS_ReadlineTState.patch
  * gdb-rhbz2250652-gdbpy_gil.patch
  * gdb-rhbz2261580-intrusive_list-assertion-fix.patch
  * gdb-rhbz2277160-apx-disasm.patch
  * gdb-rhel2295897-pre-read-DWZ-file-in-DWARF-reader.patch
  * gdb-sync-coffread-with-elfread.patch
  * gdb-remove-use-of-py-isascii
  * change-gdb.base-examine-backwards.exp-for-aix.patch
  * fix-regression-on-aarch64-linux-gdbserver.patch
  * fix-the-gdb.ada-inline-section-gc.exp-test.patch
  * fixup-powerpc-and-aarch64-fix-reverse-stepping-failu.patch
  * gdb-arm-fix-epilogue-frame-id.patch
  * gdb-arm-remove-thumb-bit-in-arm_adjust_breakpoint_ad.patch
  * gdb-arm-remove-tpidruro-register-from-non-freebsd-ta.patch
  * gdb-build-fix-gdbserver-linux-aarch64-low.cc-build.patch
  * gdb-exp-fix-cast-handling-for-indirection.patch
  * gdb-exp-fix-printing-of-out-of-bounds-struct-members.patch
  * gdb-exp-redo-cast-handling-for-indirection.patch
  * gdb-fix-heap-use-after-free-in-select_event_lwp.patch
  * gdb-fix-segfault-in-for_each_block-part-1.patch
  * gdb-fix-segfault-in-for_each_block-part-2.patch
  * gdb-python-fix-gdb.python-py-disasm.exp-on-arm-linux.patch
  * gdb-python-make-gdb.unwindinfo.add_saved_register-mo-fixup.patch
  * gdb-python-make-gdb.unwindinfo.add_saved_register-mo.patch
  * gdb-remote-fix-abort-on-remote_close_error.patch
  * gdb-s390-add-arch14-record-replay-support.patch
  * gdb-symtab-add-producer_is_gas.patch
  * gdb-symtab-don-t-defer-backward-refs-inter-cu-intra-.patch
  * gdb-symtab-factor-out-m_deferred_entries-usage.patch
  * gdb-symtab-factor-out-m_die_range_map-usage.patch
  * gdb-symtab-fix-dw_tag_inlined_subroutine-entries-in-.patch
  * gdb-symtab-handle-nullptr-parent-in-parent_map-set_p.patch
  * gdb-symtab-keep-track-of-all-parents-for-cooked-inde.patch
  * gdb-symtab-keep-track-of-processed-dies-in-shard.patch
  * gdb-symtab-refactor-condition-in-scan_attributes.patch
  * gdb-symtab-resolve-deferred-entries-inter-shard-case.patch
  * gdb-symtab-resolve-deferred-entries-intra-shard-case.patch
  * gdb-symtab-work-around-gas-pr28629.patch
  * gdb-symtab-work-around-pr-gas-29517-dwarf2-case.patch
  * gdb-symtab-work-around-pr-gas-29517.patch
  * gdb-symtab-workaround-pr-gas-31115.patch
  * gdb-tdep-fix-catching-syscall-execve-exit-for-arm.patch
  * gdb-tdep-fix-gdb.base-watch-bitfields.exp-on-aarch64.patch
  * gdb-tdep-fix-gdb.base-watchpoint-running-on-arm-ppc6.patch
  * gdb-tdep-fix-gdb.base-watchpoint-unaligned.exp-on-aa.patch
  * gdb-tdep-fix-nr-array-elements-in-ppc64_aggregate_ca.patch
  * gdb-tdep-fix-reverse-execution-of-ldr-immediate-t4.patch
  * gdb-testsuite-add-gdb.dwarf2-backward-spec-inter-cu..patch
  * gdb-testsuite-add-gdb.dwarf2-forward-spec-inter-cu.e.patch
  * gdb-testsuite-add-missing-include-in-gdb.base-ctf-pt.patch
  * gdb-testsuite-add-missing-include-in-gdb.base-rtld-s.patch
  * gdb-testsuite-add-missing-includes-in-gdb.trace-coll.patch
  * gdb-testsuite-add-missing-no-prompt-anchor-in-gdb.ba.patch
  * gdb-testsuite-add-pr-gdb-26967-kfail-in-two-more-tes.patch
  * gdb-testsuite-call-ldd-version-in-gdb.testsuite-dump.patch
  * gdb-testsuite-factor-out-proc-get_portnum.patch
  * gdb-testsuite-factor-out-proc-lock_dir.patch
  * gdb-testsuite-factor-out-proc-with_lock.patch
  * gdb-testsuite-fix-gdb.ada-verylong.exp-on-32-bit-tar.patch
  * gdb-testsuite-fix-gdb.base-eh_return.exp.patch
  * gdb-testsuite-fix-gdb.base-ending-run.exp-on-manjaro.patch
  * gdb-testsuite-fix-gdb.base-list-no-debug.exp-on-debi.patch
  * gdb-testsuite-fix-gdb.cp-namespace.exp-with-read1.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-gas-workaround.exp.patch
  * gdb-testsuite-fix-gdb.mi-mi-dprintf.exp-with-read1.patch
  * gdb-testsuite-fix-gdbserver-pid-in-gdb.server-server.patch
  * gdb-testsuite-fix-gdb.server-server-connect.exp-for-.patch
  * gdb-testsuite-fix-license-text-in-gdb.reverse-map-to.patch
  * gdb-testsuite-fix-missing-return-type-in-gdb.linespe.patch
  * gdb-testsuite-fix-regexp-in-vgdb_start.patch
  * gdb-testsuite-fix-spurious-fails-with-examine-backwa.patch
  * gdb-testsuite-fix-test-case-gdb.threads-attach-stopp.patch
  * gdb-testsuite-fix-test-in-gdb.python-py-finish-break.patch
  * gdb-testsuite-fix-typo-in-gdb.base-catch-syscall.exp.patch
  * gdb-testsuite-fix-valgrind-tests-on-debian.patch
  * gdb-testsuite-further-handle-long-filenames-in-gdb.b.patch
  * gdb-testsuite-handle-core-without-build-id-in-gdb.ba.patch
  * gdb-testsuite-handle-pac-marker.patch
  * gdb-testsuite-make-gdb.base-solib-search.exp-more-ro.patch
  * gdb-testsuite-make-portnum-a-persistent-global.patch
  * gdb-testsuite-move-gpu-parallel.lock-to-cache-dir.patch
  * gdb-testsuite-remove-spurious-in-save_vars.patch
  * gdb-testsuite-reset-errcnt-and-warncnt-in-default_gd.patch
  * gdb-testsuite-simplify-gdb.server-server-kill-python.patch
  * gdb-testsuite-use-find_gnatmake-instead-of-gdb_find_.patch
  * gdb-testsuite-use-more-progbits-for-arm.patch
  * gdb-testsuite-use-unique-portnum-in-parallel-testing-check-slash-slash-case.patch
  * gdb-testsuite-use-unique-portnum-in-parallel-testing.patch
  * gdb-tui-allow-command-window-of-1-or-2-lines.patch
  * gdb-tui-fix-resizing-of-terminal-to-1-or-2-lines.patch
  * gdb-tui-fix-wmaybe-uninitialized-in-tui_find_disasse.patch
  * make-pascal_language-print_type-handle-varstring-nul.patch
  * powerpc-and-aarch64-fix-reverse-stepping-failure.patch
  * powerpc-fix-test-gdb.ada-finish-large.exp.patch
  * riscv-lrsc.patch
  * rs6000-unwind-on-each-instruction-fix.patch
  * s390-provide-ibm-z16-arch14-instruction-descriptions.patch
* Sat Jan 25 2025 Tom de Vries <tdevries@suse.com>
- Patches added:
  * gdb-testsuite-record-less-in-gdb.reverse-time-revers.patch
  * gdb-cli-print-at_hwcap3-and-at_hwcap4.patch
* Fri Jan 24 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ a455470.
- Patches added:
  * gdb-rhel2295897-pre-read-DWZ-file-in-DWARF-reader.patch
* Fri Jan 24 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 62add57.
- Patches updated:
  * gdb-add-rpm-suggestion-script.patch
* Fri Jan 24 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 199e8a4.
- Patches dropped:
  * fixup-gdb-glibc-strstr-workaround.patch
  * gdb-glibc-strstr-workaround.patch
* Fri Jan 24 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ a247406.
- Patches dropped:
  * gdb-core-open-vdso-warning.patch
* Fri Jan 24 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 485076c.
- Patches updated:
  * gdb-add-rpm-suggestion-script.patch
* Fri Jan 24 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 1672291.
- Patches updated:
  * gdb-6.6-buildid-locate-rpm-suse.patch
  * gdb-add-rpm-suggestion-script.patch
* Fri Jan 24 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ f9386b1.
- Patches dropped:
  * gdb-fedora-libncursesw.patch
* Fri Jan 24 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 93db514.
- Patches added:
  * gdb-rhbz2277160-apx-disasm.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ deb8227.
- Patches dropped:
  * fixup-gdb-linux_perf-bundle.patch
  * gdb-linux_perf-bundle.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 7b0d0c4.
- Patches dropped:
  * gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch
- Patches updated:
  * gdb-6.6-buildid-locate.patch
  * gdb-add-missing-debug-info-python-hook.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 94829f0.
- Patches dropped:
  * fixup-gdb-bz634108-solib_address.patch
  * gdb-bz634108-solib_address.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 2024966.
- Maintenance script import-fedora.sh:
  * Remove gdb-container-rh-pkg.patch from skip_patches.
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Patches dropped (unused):
  * fixup-gdb-6.3-attach-see-vdso-test.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ a54b5ef.
- Patches dropped:
  * gdb-6.3-attach-see-vdso-test.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ 08bfd0a.
- Patches dropped:
  * fixup-gdb-6.3-gstack-20050411.patch
  * fixup-skip-tests.patch
  * gdb-6.6-buildid-locate-rpm-librpm-workaround.patch
  * gdb-6.6-buildid-locate-rpm.patch
- Patches added:
  * gdb-add-missing-debug-ext-lang-hook.patch
  * gdb-add-missing-debug-info-python-hook.patch
  * gdb-add-rpm-suggestion-script.patch
  * gdb-do-not-import-py-curses-ascii-module.patch
  * gdb-handle-no-python-gdb-module.patch
  * gdb-merge-debug-symbol-lookup.patch
  * gdb-python-avoid-depending-on-the-curses-library.patch
  * gdb-refactor-find-and-add-separate-symbol-file.patch
  * gdb-reformat-missing-debug-py-file.patch
  * gdb-remove-path-in-test-name.patch
  * gdb-remove-use-of-py-isascii
  * gdb-sync-coffread-with-elfread.patch
- Patches updated:
  * fixup-gdb-bz634108-solib_address.patch
  * gdb-6.3-gstack-20050411.patch
  * gdb-6.6-buildid-locate-rpm-suse.patch
  * gdb-6.6-buildid-locate-solib-missing-ids.patch
  * gdb-6.6-buildid-locate.patch
  * gdb-archer-next-over-throw-cxx-exec.patch
  * gdb-bz634108-solib_address.patch
  * gdb-fedora-libncursesw.patch
  * gdb-glibc-strstr-workaround.patch
  * gdb-rhbz1007614-memleak-infpy_read_memory-test.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ f379362.
- Patches modified:
  * gdb-6.6-buildid-locate.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Update to fedora rawhide @ e27fd6f.
- Patches modified:
  * gdb-6.6-buildid-locate-rpm.patch
  * gdb-6.6-buildid-locate.patch
* Thu Jan 23 2025 Tom de Vries <tdevries@suse.com>
- Add "BuildRequires: libgo23" to fix unresolved for factory.
* Mon Jan 20 2025 Andreas Schwab <schwab@suse.de>
- riscv-lrsc.patch: Fix stepping over atomic sequences
* Tue Dec 17 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR29770 xfail (glibc).
  * Add PR31229 kfail.
* Wed Dec 11 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR32446 kfail.
  * Add to be investigated FAILs on Leap 15.6 ppc64le.
* Tue Dec 10 2024 Tom de Vries <tdevries@suse.com>
- Patches added:
  * gdb-testsuite-avoid-intermittent-failures-on-a-debug.patch
- Maintenance script qa.sh:
  * Add PR32439 kfail.
* Mon Dec  9 2024 Tom de Vries <tdevries@suse.com>
- Patches added (jsc#PED-10258):
  * gdb-tdep-s390-add-arch15-record-replay-support.patch
* Mon Dec  2 2024 Tom de Vries <tdevries@suse.com>
- Patches added (jsc#PED-10751):
  * s390-provide-ibm-z16-arch14-instruction-descriptions.patch
  * gdb-s390-add-arch14-record-replay-support.patch
- Maintenance script qa.sh:
  * Add PR32407 kfail.
* Thu Aug 29 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Move PR26867 kfail from kfail_factory to kfail.
  * Merge PR28468 kfail with PR26867 kfail.
* Wed Aug 28 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Restore yama ptrace_scope == 1 kfails,
    aaa_base-yama-enable-ptrace doesn't work.
  * Enable yama ptrace_scope == 1 kfails for SLFO.
  * Add PR32121 kfail.
  * Drop Leap 15.3 and 15.4, add Leap 15.6.
  * Replace ALP with SLFO.
  * Move PR28468 kfail from kfail_factory to kfail.
* Wed Jun 19 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Remove python2 related PR29245 kfail.
  * Remove PR30518 kfail.
  * Remove yama ptrace_scope == 1 kfails.
  * Remove PR28065 kfail.
- Patches added (swo#32081):
  * gdb-symtab-return-correct-reader-for-top-level-cu-in.patch
- Add "BuildRequires: aaa_base-yama-enable-ptrace" on tumbleweed.
- Maintenance script qa-local.sh:
  * Add SLFO and Leap 15.6, drop Leap 15.3 and 15.4 and ALP.
* Wed Jun 19 2024 Tom de Vries <tdevries@suse.com>
- Mention changes in GDB 14:
  * GDB now supports the AArch64 Scalable Matrix Extension 2
    (SME2), which includes a new 512 bit lookup table register
    named ZT0.
  * GDB now supports the AArch64 Scalable Matrix Extension (SME),
    which includes a new matrix register named ZA, a new thread
    register TPIDR2 and a new vector length register SVG
    (streaming vector granule).  GDB also supports tracking ZA
    state across signal frames.  Some features are still under
    development or are dependent on ABI specs that are still in
    alpha stage.  For example, manual function calls with ZA state
    don't have any special handling, and tracking of SVG changes
    based on DWARF information is still not implemented, but there
    are plans to do so in the future.
  * GDB now recognizes the NO_COLOR environment variable and
    disables styling according to the spec.  See
    https://no-color.org/.  Styling can be re-enabled with
    "set style enabled on".
  * The AArch64 'org.gnu.gdb.aarch64.pauth' Pointer Authentication
    feature string has been deprecated in favor of the
    'org.gnu.gdb.aarch64.pauth_v2' feature string.
  * GDB now has some support for integer types larger than 64 bits.
  * Multi-target feature configuration.
    GDB now supports the individual configuration of remote
    targets' feature sets.  Based on the current selection of a
    target, the commands 'set remote <name>-packet (on|off|auto)'
    and 'show remote <name>-packet' can be used to configure a
    target's feature packet and to display its configuration,
    respectively.
  * GDB has initial built-in support for the Debugger Adapter
    Protocol.
  * For the break command, multiple uses of the 'thread' or 'task'
    keywords will now give an error instead of just using the
    thread or task id from the last instance of the keyword.  E.g.:
    break foo thread 1 thread 2
    will now give an error rather than using 'thread 2'.
  * For the watch command, multiple uses of the 'task' keyword will
    now give an error instead of just using the task id from the
    last instance of the keyword.  E.g.:
    watch my_var task 1 task 2
    will now give an error rather than using 'task 2'.  The
    'thread' keyword already gave an error when used multiple times
    with the watch command, this remains unchanged.
  * The 'set print elements' setting now helps when printing large
    arrays.  If an array would otherwise exceed max-value-size, but
    'print elements' is set such that the size of elements to print
    is less than or equal to 'max-value-size', GDB will now still
    print the array, however only 'max-value-size' worth of data
    will be added into the value history.
  * For both the break and watch commands, it is now invalid to use
    both the 'thread' and 'task' keywords within the same command.
    For example the following commnds will now give an error:
    break foo thread 1 task 1
    watch var thread 2 task 3
  * The printf command now accepts a '%%V' output format which will
    format an expression just as the 'print' command would.  Print
    options can be placed withing '[...]' after the '%%V' to modify
    how the value is printed.  E.g:
    printf "%%V", some_array
    printf "%%V[-array-indexes on]", some_array
    will print the array without, or with array indexes included,
    just as the array would be printed by the 'print' command.
    This functionality is also available for dprintf when
    dprintf-style is 'gdb'.
  * When the printf command requires a string to be fetched from
    the	inferior, GDB now uses the existing 'max-value-size'
    setting to the limit the memory allocated within GDB.  The
    default 'max-value-size' is 64k.  To print longer strings you
    should increase 'max-value-size'.
  * The Ada 2022 Enum_Rep and Enum_Val attributes are now
    supported.
  * The Ada 2022 target name symbol ('@') is now supported by the
    Ada expression parser.
  * The 'list' command now accepts '.' as an argument, which tells
    GDB to print the location around the point of execution within
    the current frame.  If the inferior hasn't started yet, the
    command will print around the beginning of the 'main' function.
  * Using the 'list' command with no arguments in a situation where
    the command would attempt to list past the end of the file now
    warns the user that the end of file has been reached, refers
    the user to the newly added '.' argument
  * Breakpoints can now be inferior-specific.  This is similar to
    the	existing thread-specific breakpoint support.  Breakpoint
    conditions can include the 'inferior' keyword followed by an
    inferior id (as displayed in the 'info inferiors' output).
    It is invalid to use the 'inferior' keyword with either the
    'thread' or 'task' keywords when creating a breakpoint.
  * New convenience function "$_shell", to execute a shell command
    and return the result.  This lets you run shell commands in
    expressions.  Some examples:
    (gdb) p $_shell("true")
    $1 = 0
    (gdb) p $_shell("false")
    $2 = 1
    (gdb) break func if $_shell("some command") == 0
  * New commands:
  * set debug breakpoint on|off
    show debug breakpoint
    Print additional debug messages about breakpoint insertion
    and removal.
  * maintenance print record-instruction [ N ]
    Print the recorded information for a given instruction.  If N
    is not given prints how GDB would undo the last instruction
    executed.  If N is negative, prints how GDB would undo the
    N-th previous instruction, and if N is positive, it prints
    how GDB will redo the N-th following instruction.
  * maintenance info frame-unwinders
    List the frame unwinders currently in effect, starting with
    the highest priority.
  * maintenance wait-for-index-cache
    Wait until all pending writes to the index cache have
    completed.
  * set always-read-ctf on|off
    show always-read-ctf
    When off, CTF is only read if DWARF is not present.  When on,
    CTF is read regardless of whether DWARF is present.  Off by
    default.
  * info main
    Get main symbol to identify entry point into program.
  * set tui mouse-events [on|off]
    show tui mouse-events
    When on (default), mouse clicks control the TUI and can be
    accessed by Python extensions.  When off, mouse clicks are
    handled by the terminal, enabling terminal-native text
    selection.
  * MI changes:
  * MI version 1 has been removed.
  * mi now reports 'no-history' as a stop reason when hitting the
    end of the reverse execution history.
  * When creating a thread-specific breakpoint using the '-p'
    option, the -break-insert command would report the 'thread'
    field twice in the reply.  The content of both fields was
    always identical.  This has now been fixed; the 'thread'
    field will be reported just once for thread-specific
    breakpoints, or not at all for breakpoints without a thread
    restriction.  The same is also true for the 'task' field of
    an Ada task-specific breakpoint.
  * It is no longer possible to create a thread-specific
    breakpoint for a thread that doesn't exist using
    '-break-insert -p ID'.  Creating breakpoints for
    non-existent threads is not allowed when using the CLI, that
    the MI allowed it was a long standing bug, which has now
    been fixed.
  * The '--simple-values' argument to the
    '-stack-list-arguments','-stack-list-locals',
    '-stack-list-variables', and '-var-list-children' commands now
    takes reference types into account: that is, a value is now
    considered simple if it is neither an array, structure, or
    union, nor a reference to an array, structure, or union.
    (Previously all references were considered simple.)  Support
    for this feature can be verified by using the
    '-list-features' command, which should contain
    "simple-values-ref-types".
  * The -break-insert command now accepts a '-g thread-group-id'
    option to allow for the creation of inferior-specific
    breakpoints.
  * The bkpt tuple, which appears in breakpoint-created
    notifications, and in the result of the -break-insert
    command can now include an optional 'inferior' field for both
    the main breakpoint, and each location, when the breakpoint
    is inferior-specific.
  * Python API:
  * gdb.ThreadExitedEvent added.  Emits a ThreadEvent.
  * The gdb.unwinder.Unwinder.name attribute is now read-only.
  * The name argument passed to gdb.unwinder.Unwinder.__init__
    must now be of type 'str' otherwise a TypeError will be
    raised.
  * The gdb.unwinder.Unwinder.enabled attribute can now only
    accept values of type 'bool'.  Changing this attribute will
    now invalidate GDB's frame-cache, which means GDB will need
    to rebuild its frame-cache when next required - either with,
    or without the particular unwinder, depending on how
    'enabled' was changed.
  * New methods added to the gdb.PendingFrame class.  These
    methods have the same behaviour as the corresponding
    methods on gdb.Frame.  The new methods are:
  * gdb.PendingFrame.name: Return the name for the frame's
    function, or None.
  * gdb.PendingFrame.is_valid: Return True if the pending
    frame object is valid.
  * gdb.PendingFrame.pc: Return the $pc register value for
    this frame.
  * gdb.PendingFrame.language: Return a string containing the
    language for this frame, or None.
  * gdb.PendingFrame.find_sal: Return a gdb.Symtab_and_line
    object for the current location within the pending frame,
  or None.
  * gdb.PendingFrame.block: Return a gdb.Block for the current
    pending frame, or None.
  * gdb.PendingFrame.function: Return a gdb.Symbol for the
    current pending frame, or None.
  * The frame-id passed to gdb.PendingFrame.create_unwind_info
    can now use either an integer or a gdb.Value object for each
    of its 'sp', 'pc', and 'special' attributes.
  * A new class gdb.unwinder.FrameId has been added.  Instances
    of this class are constructed with 'sp' (stack-pointer) and
    'pc' (program-counter) values, and can be used as the
    frame-id when calling gdb.PendingFrame.create_unwind_info.
  * It is now no longer possible to sub-class the
    gdb.disassembler.DisassemblerResult type.
  * The Disassembler API from the gdb.disassembler module has
    been extended to include styling support:
  * The DisassemblerResult class can now be initialized with a
    list of parts.  Each part represents part of the
  disassembled instruction along with the associated style
  information.  This list of parts can be accessed with the
  new DisassemblerResult.parts property.
  * New constants gdb.disassembler.STYLE_* representing all the
    different styles part of an instruction might have.
  * New methods DisassembleInfo.text_part and
    DisassembleInfo.address_part which are used to create the
  new styled parts of a disassembled instruction.
  * Changes are backwards compatible, the older API can still
    be used to disassemble instructions without styling.
  * New function gdb.execute_mi(COMMAND, [ARG]...), that invokes
    a GDB/MI command and returns the output as a Python
    dictionary.
  * New function gdb.block_signals().  This returns a context
    manager that blocks any signals that GDB needs to handle
    itself.
  * New class gdb.Thread.  This is a subclass of threading.Thread
    that calls gdb.block_signals in its "start" method.
  * gdb.parse_and_eval now has a new "global_context" parameter.
    This can be used to request that the parse only examine
    global symbols.
  * gdb.Inferior now has a new "arguments" attribute.  This holds
    the command-line arguments to the inferior, if known.
  * gdb.Inferior now has a new "main_name" attribute.  This holds
    the name of the inferior's "main", if known.
  * gdb.Inferior now has new methods "clear_env", "set_env", and
    "unset_env".  These can be used to modify the inferior's
    environment before it is started.
  * gdb.Value now has the 'assign' method.
  * gdb.Value now has the 'to_array' method.  This converts an
    array-like Value to an array.
  * gdb.Progspace now has the new method "objfile_for_address".
    This returns the gdb.Objfile, if any, that covers a given
    address.
  * gdb.Breakpoint now has an "inferior" attribute.  If the
    Breakpoint object is inferior specific then this attribute
    holds the inferior-id (an integer).  If the Breakpoint
    object is not inferior specific, then this field contains
    None.  This field can be written too.
  * gdb.Type now has the "is_array_like" and "is_string_like"
    methods.  These reflect GDB's internal idea of whether a
    type might be array- or string-like, even if they do not
    have the corresponding type code.
  * gdb.ValuePrinter is a new class that can be used as the base
    class for the result of applying a pretty-printer.  As a
    base class, it signals to gdb that the printer may implement
    new pretty-printer methods.
  * New attribute Progspace.symbol_file.  This attribute holds
    the gdb.Objfile that corresponds to Progspace.filename (when
    Progspace.filename is not None), otherwise, this attribute is
    itself None.
  * New attribute Progspace.executable_filename.  This attribute
    holds a string containing a file name set by the "exec-file"
    or "file" commands, or None if no executable file is set.
    This isn't the exact string passed by the user to these
    commands; the file name will have been partially resolved to
    an absolute file name.
  * A new executable_changed event registry is available.  This
    event emits ExecutableChangedEvent objects, which have
    'progspace' (a gdb.Progspace) and 'reload' (a Boolean)
    attributes.  This event is emitted when
    gdb.Progspace.executable_filename changes.
  * New event registries gdb.events.new_progspace and
    gdb.events.free_progspace, these emit NewProgspaceEvent and
    FreeProgspaceEvent event types respectively.  Both of these
    event types have a single 'progspace' attribute, which is
    the gdb.Progspace that is either being added to GDB, or
    removed from GDB.
  * gdb.LazyString now implements the __str__ method.
  * New method gdb.Frame.static_link that returns the outer
    frame of a nested function frame.
* Tue Jun 18 2024 Tom de Vries <tdevries@suse.com>
- Fix mention of gdb-exp-redo-cast-handling-for-indirection.patch.
* Thu Jun 13 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa-remote.sh:
  * Filter out SLE-11.
- Maintenance script qa.sh:
  * Add gdb.guile/scm-breakpoint.exp kfail.
  * Fix kfail_powerpc64le_sle12 selection.
* Thu Jun 13 2024 Tom de Vries <tdevries@suse.com>
- Patches dropped:
  * fix-gdb.threads-threads-after-exec.exp-race.patch
  * add-maint-info-linux-lwps-command.patch
- Patches added:
  * gdb-python-fix-gdb.python-py-disasm.exp-on-arm-linux.patch
  * gdb-testsuite-fix-gdb.fortran-array-bounds.exp-on-ar.patch
  * gdb-python-make-gdb.unwindinfo.add_saved_register-mo-fixup.patch
  * gdb-exp-redo-cast-handling-for-indirection.patch
  * gdb-tdep-fix-gdb.base-watchpoint-running-on-arm-ppc6.patch
* Sat Jun  1 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR31831 kfail.
  * Expand PR28617 kfail.
  * Expand PR28561 kfail.
  * Expand PR19675 kfail.
- Patches dropped:
  * gdb-linux-delete-all-other-lwps-immediately-on-ptrac.patch
* Fri May 31 2024 Tom de Vries <tdevries@suse.com>
- Patches added:
  * gdb-build-fix-gdbserver-linux-aarch64-low.cc-build.patch
  * powerpc-fix-test-gdb.ada-finish-large.exp.patch
  * gdb-testsuite-fix-timeout-in-gdb.tui-resize-2.exp.patch
- Maintenance script qa.sh:
  * Remove PR26761 kfail.
  * Add PR31061, PR31823, PR31825, PR31826, PR31827 and PR31564
    kfail.
  * Remove PKRU-related kfails.
  * Improve report format for known clean configs.
  * Add more configs as known clean.
  * Expand scope of PR29253 kfail.
* Wed May  1 2024 Tom de Vries <tdevries@suse.com>
- Rebase to 14.2 release (fedora rawhide @ 779f05e).
  * Replace gdb-13.2.tar.bz2 with gdb-14.2.tar.bz2.
- Maintenance script import-fedora.sh:
  * Drop patch skips:
  * gdb-6.5-BEA-testsuite.patch
- Maintenance script qa-local.sh:
  * Drop SLE-11.  GDB 14.2 requires MPFR, and the SLE-11 version
    (2.3.2) is older than required (3.1.0+).
  * Add ALP.
  * Update version to 14.2.
- Maintenance script qa.sh:
  * Add PR30480, PR31440, PR31806 kfail.
  * Add PR31810, PR31809, PR31811 kfail.
  * Expand gdb.base/rtld-step.exp kfail.
  * Add gdb.threads/thread-specific-bp.exp kfail.
- Fedora patches updated:
  * gdb-6.3-gstack-20050411.patch
  * gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch
  * gdb-6.6-buildid-locate-rpm.patch
  * gdb-6.6-buildid-locate-solib-missing-ids.patch
  * gdb-6.6-buildid-locate.patch
  * gdb-6.6-testsuite-timeouts.patch
  * gdb-core-open-vdso-warning.patch
  * gdb-fedora-libncursesw.patch
  * gdb-linux_perf-bundle.patch
  * gdb-rhbz-2232086-cpp-ify-mapped-symtab.patch
  * gdb-rhbz-2232086-generate-dwarf-5-index-consistently.patch
  * gdb-rhbz-2232086-generate-gdb-index-consistently.patch
- Fedora patches removed:
  * gdb-binutils29988-read_indexed_address.patch
  * gdb-bz2196395-debuginfod-legacy-openssl-crash.patch
  * gdb-bz2237392-dwarf-obstack-allocation.patch
  * gdb-bz2237515-debuginfod-double-free.patch
  * gdb-rhbz1773651-gdb-index-internal-error.patch
  * gdb-rhbz2160211-excessive-core-file-warnings.patch
  * gdb-rhbz2192105-ftbs-dangling-pointer
  * gdb-rhbz2233961-CVE-2022-4806.patch
  * gdb-rhbz2233965-memory-leak.patch
- Fedora patches added:
  * gdb-ftbs-swapped-calloc-args.patch
  * gdb-rhbz2250652-avoid-PyOS_ReadlineTState.patch
  * gdb-rhbz2250652-gdbpy_gil.patch
  * gdb-rhbz2261580-intrusive_list-assertion-fix.patch
- Fedora fixup patches added:
  * fixup-skip-tests.patch
- Fedora fixup patches updated:
  * fixup-gdb-linux_perf-bundle.patch
- Patches updated:
  * gdb-symtab-work-around-pr-gas-29517.patch
  * gdb-symtab-work-around-gas-pr28629.patch
  * gdb-testsuite-ada-pie.patch
  * gdb-python-finishbreakpoint-update.patch
  * gdb-testsuite-prevent-compilation-fails-with-unix-fpie-pie.patch
  * gdb-fix-segfault-in-for_each_block-part-1.patch
  * gdb-fix-segfault-in-for_each_block-part-2.patch
  * gdb-symtab-don-t-defer-backward-refs-inter-cu-intra-.patch
  * gdb-symtab-factor-out-m_deferred_entries-usage.patch
  * gdb-symtab-factor-out-m_die_range_map-usage.patch
  * gdb-symtab-fix-dw_tag_inlined_subroutine-entries-in-.patch
  * gdb-symtab-handle-nullptr-parent-in-parent_map-set_p.patch
  * gdb-symtab-keep-track-of-all-parents-for-cooked-inde.patch
  * gdb-symtab-keep-track-of-processed-dies-in-shard.patch
  * gdb-symtab-recurse-into-c-dw_tag_subprogram-dies-for.patch
  * gdb-symtab-refactor-condition-in-scan_attributes.patch
  * gdb-symtab-resolve-deferred-entries-inter-shard-case.patch
  * gdb-symtab-resolve-deferred-entries-intra-shard-case.patch
- Patches added:
  * gdb-symtab-work-around-pr-gas-29517-dwarf2-case.patch
  * fix-the-gdb.ada-inline-section-gc.exp-test.patch
  * gdb-testsuite-handle-pac-marker.patch
  * change-gdb.base-examine-backwards.exp-for-aix.patch
  * gdb-testsuite-fix-spurious-fails-with-examine-backwa.patch
  * gdb-testsuite-make-gdb.base-solib-search.exp-more-ro.patch
  * gdb-testsuite-fix-regexp-in-vgdb_start.patch
  * powerpc-and-aarch64-fix-reverse-stepping-failure.patch
  * gdb-tdep-fix-gdb.base-watch-bitfields.exp-on-aarch64.patch
  * gdb-tdep-fix-gdb.base-watchpoint-unaligned.exp-on-aa.patch
  * gdb-testsuite-add-pr-gdb-26967-kfail-in-two-more-tes.patch
  * gdb-testsuite-fix-gdb.base-eh_return.exp.patch
  * fixup-powerpc-and-aarch64-fix-reverse-stepping-failu.patch
  * gdb-exp-fix-printing-of-out-of-bounds-struct-members.patch
  * gdb-fix-heap-use-after-free-in-select_event_lwp.patch
  * fix-regression-on-aarch64-linux-gdbserver.patch
  * gdb-testsuite-factor-out-proc-get_portnum.patch
  * gdb-testsuite-make-portnum-a-persistent-global.patch
  * gdb-testsuite-factor-out-proc-with_lock.patch
  * gdb-testsuite-factor-out-proc-lock_dir.patch
  * gdb-testsuite-move-gpu-parallel.lock-to-cache-dir.patch
  * gdb-testsuite-use-unique-portnum-in-parallel-testing.patch
  * gdb-testsuite-use-unique-portnum-in-parallel-testing-check-slash-slash-case.patch
  * gdb-tdep-fix-reverse-execution-of-ldr-immediate-t4.patch
  * gdb-exp-fix-cast-handling-for-indirection.patch
  * gdb-remote-fix-abort-on-remote_close_error.patch
  * gdb-testsuite-use-find_gnatmake-instead-of-gdb_find_.patch
  * gdb-testsuite-simplify-gdb.server-server-kill-python.patch
  * gdb-testsuite-fix-gdbserver-pid-in-gdb.server-server.patch
  * gdb-testsuite-add-missing-include-in-gdb.base-ctf-pt.patch
  * gdb-testsuite-fix-gdb.ada-verylong.exp-on-32-bit-tar.patch
  * gdb-testsuite-add-missing-includes-in-gdb.trace-coll.patch
  * gdb-testsuite-fix-missing-return-type-in-gdb.linespe.patch
  * gdb-testsuite-fix-gdb.base-ending-run.exp-on-manjaro.patch
  * gdb-testsuite-fix-test-case-gdb.threads-attach-stopp.patch
  * gdb-testsuite-add-missing-include-in-gdb.base-rtld-s.patch
  * gdb-testsuite-fix-valgrind-tests-on-debian.patch
  * gdb-testsuite-fix-gdb.server-server-connect.exp-for-.patch
  * gdb-testsuite-handle-core-without-build-id-in-gdb.ba.patch
  * gdb-testsuite-fix-gdb.base-list-no-debug.exp-on-debi.patch
  * gdb-testsuite-reset-errcnt-and-warncnt-in-default_gd.patch
  * gdb-testsuite-fix-test-in-gdb.python-py-finish-break.patch
  * gdb-testsuite-further-handle-long-filenames-in-gdb.b.patch
  * gdb-testsuite-fix-license-text-in-gdb.reverse-map-to.patch
  * gdb-testsuite-call-ldd-version-in-gdb.testsuite-dump.patch
  * gdb-testsuite-fix-gdb.mi-mi-dprintf.exp-with-read1.patch
  * gdb-testsuite-fix-gdb.cp-namespace.exp-with-read1.patch
  * gdb-testsuite-fix-typo-in-gdb.base-catch-syscall.exp.patch
  * gdb-testsuite-use-more-progbits-for-arm.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-gas-workaround.exp.patch
  * gdb-testsuite-add-gdb.dwarf2-backward-spec-inter-cu..patch
  * gdb-testsuite-add-gdb.dwarf2-forward-spec-inter-cu.e.patch
  * gdb-symtab-workaround-pr-gas-31115.patch
  * gdb-arm-remove-tpidruro-register-from-non-freebsd-ta.patch
  * gdb-tdep-fix-catching-syscall-execve-exit-for-arm.patch
  * gdb-arm-fix-epilogue-frame-id.patch
  * gdb-linux-delete-all-other-lwps-immediately-on-ptrac.patch
  * add-maint-info-linux-lwps-command.patch
  * fix-gdb.threads-threads-after-exec.exp-race.patch
  * rs6000-unwind-on-each-instruction-fix.patch
  * gdb-python-make-gdb.unwindinfo.add_saved_register-mo.patch
  * gdb-arm-remove-thumb-bit-in-arm_adjust_breakpoint_ad.patch
  * gdb-testsuite-fix-error-in-gdb.server-server-kill-py.patch
- Patches dropped:
  * remove-some-unnecessary-includes-from-exp.y.patch
  * gdb-testsuite-fix-gdb.gdb-python-helper.exp-with-o2-.patch
  * gdb-testsuite-simplify-gdb.base-unwind-on-each-insn..patch
  * gdb-testsuite-handle-output-after-prompt-in-gdb.thre.patch
  * gdb-testsuite-add-xfail-in-gdb.arch-i386-pkru.exp.patch
  * gdb-testsuite-factor-out-proc-linux_kernel_version.patch
  * gdb-testsuite-add-xfail-in-gdb.python-py-record-btra.patch
  * gdb-testsuite-fix-gdb.threads-schedlock.exp-on-fast-.patch
  * gdb-testsuite-simplify-gdb.arch-amd64-disp-step-avx..patch
  * gdb-testsuite-fix-gdb.threads-schedlock.exp-for-gcc-.patch
  * gdb-testsuite-add-xfail-case-in-gdb.python-py-record.patch
  * aarch64-avoid-initializers-for-vlas.patch
  * gdb-tdep-aarch64-fix-frame-address-of-last-insn.patch
  * fix-pr30369-regression-on-aarch64-arm-pr30506.patch
  * gdb-testsuite-fix-breakpoint-regexp-in-gdb.ada-out_o.patch
  * gdb-testsuite-relax-breakpoint-count-check-in-gdb.py.patch
  * gdb-testsuite-fix-buffer-overflow-in-gdb.base-signed.patch
  * gdb-testsuite-require-syscall-time-in-gdb.reverse-ti.patch
  * gdb-testsuite-handle-missing-gdc-in-gdb.dlang-dlang-.patch
  * gdb-testsuite-add-basic-lmap-for-tcl-8.6.patch
  * gdb-testsuite-fix-gdb.rust-watch.exp-on-ppc64le.patch
  * gdb-testsuite-fix-gdb.python-py-breakpoint.exp-timeo.patch
  * powerpc-fix-for-gdb.reverse-finish-precsave.exp-and-.patch
  * powerpc-regression-fix-for-reverse-finish-command.patch
  * gdb-testsuite-don-t-use-string-cat-in-gdb.dwarf2-dw2.patch
  * move-step_until-procedure.patch
  * gdb-testsuite-fix-gdb.arch-i386-signal.exp-on-x86_64.patch
  * gdb-testsuite-fix-regexps-in-gdb.base-step-over-sysc.patch
  * gdb-testsuite-add-kfail-for-pr-ada-30908.patch
  * gdb-testsuite-fix-gdb.ada-mi_task_arg.exp-with-newer.patch
  * gdb-testsuite-fix-gdb.cp-m-static.exp-regression-on-.patch
  * gdb-symtab-fix-line-number-of-static-const-class-mem.patch
  * gdb-symtab-handle-pu-in-iterate_over_some_symtabs.patch
  * gdb-testsuite-fix-gdb.dwarf2-nullptr_t.exp-with-cc-w.patch
  * gdb-symtab-fix-too-many-symbols-in-gdbpy_lookup_stat.patch
  * gdb-support-rseq-auxvs.patch
  * gdb-testsuite-add-xfail-for-gdb-29965-in-gdb.threads.patch
  * gdb-cli-handle-pending-c-after-rl_callback_read_char.patch
  * gdb-testsuite-add-have_host_locale.patch
  * gdb-symtab-find-main-language-without-symtab-expansi.patch
  * gdb-symtab-don-t-deduplicate-variables-in-gdb-index.patch
  * xcoffread.c-fix-werror-dangling-pointer-issue-with-m.patch
  * avoid-manual-memory-management-in-go-lang.c.patch
  * gdb-go-handle-v3-go_0-mangled-prefix.patch
  * gdb-symtab-handle-self-reference-die.patch
  * gdb-symtab-handle-self-reference-in-inherit_abstract.patch
  * gdb-symtab-add-optimized-out-static-var-to-cooked-in.patch
  * gdb-testsuite-fix-gdb.python-py-breakpoint.exp-with-.patch
  * gdb-tui-fix-segfault-in-tui_find_disassembly_address.patch
  * gdb-testsuite-add-wait_for_msg-arg-to-term-resize-fi.patch
  * gdb-testsuite-fix-gdb-server-ext-run-exp-for-obs.patch
  * gdb-testsuite-work-around-skip_prologue-problems-in-gdb.threads-process-dies-while-detaching.exp.patch
* Wed Apr 24 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR31671 unresolved.
  * Add unresolved for yama ptrace_scope == 1.
  * Limit PR31648 unresolved to SLE-11.
* Thu Apr 18 2024 Tom de Vries <tdevries@suse.com>
- Patch added (swo#31524, bsc#1222188):
  * make-pascal_language-print_type-handle-varstring-nul.patch
- Renable gcc-fortran for SLE-11.
- Use system compiler (gcc 4.3.4) for testing all languages on
  SLE-11.
- Maintenance script qa.sh:
  * Ignore all fails for SLE-11.
- Maintenance script import-fedora.sh:
  * Use %%patch -P N instead of deprecated %%patchN.
  * Drop patch skips:
  * gdb-6.5-readline-long-line-crash-test.patch
  * gdb-6.7-charsign-test.patch
  * gdb-test-ivy-bridge.patch
  * gdb-ppc-power7-test.patch
  * gdb-6.3-bz140532-ppc-unwinding-test.patch
- Patches added (import from fedora rawhide @ a27201b):
  * gdb-bz2196395-debuginfod-legacy-openssl-crash.patch
  * gdb-rhbz-2232086-cpp-ify-mapped-symtab.patch
  * gdb-rhbz-2232086-generate-dwarf-5-index-consistently.patch
  * gdb-rhbz-2232086-generate-gdb-index-consistently.patch
  * gdb-rhbz-2232086-reduce-size-of-gdb-index.patch
  * gdb-rhbz2232086-refactor-selftest-support.patch
- Patches updated (import from fedora rawhide @ a27201b):
  * gdb-6.6-buildid-locate-rpm.patch
  * gdb-6.6-buildid-locate.patch
  * gdb-fedora-libncursesw.patch
  * gdb-rhbz2233961-CVE-2022-4806.patch
  * gdb-rhbz2233965-memory-leak.patch
- Patches updated:
  * gdb-6.6-buildid-locate-rpm-suse.patch
- Patches deleted (import from fedora rawhide @ a27201b):
  * gdb-rhbz1553104-s390x-arch12-test.patch
  * gdb-lineno-makeup-test.patch
  * gdb-6.3-bz202689-exec-from-pthread-test.patch
  * gdb-6.5-bz109921-DW_AT_decl_file-test.patch
  * gdb-6.5-ia64-libunwind-leak-test.patch
  * gdb-6.5-last-address-space-byte-test.patch
  * gdb-6.5-missed-trap-on-step-test.patch
  * gdb-6.5-sharedlibrary-path.patch
  * gdb-6.7-testsuite-stable-results.patch
  * gdb-6.8-bz442765-threaded-exec-test.patch
  * gdb-ccache-workaround.patch
  * gdb-opcodes-clflushopt-test.patch
  * gdb-rhbz1186476-internal-error-unqualified-name-re-set-test.patch
  * gdb-rhbz1350436-type-printers-error.patch
  * gdb-rhbz2196395-debuginfod-legacy-openssl-crash.patch
  * gdb-rhel5.9-testcase-xlf-var-inside-mod.patch
  * gdb-test-pid0-core.patch
- Patches deleted:
  * fixup-gdb-rhbz1553104-s390x-arch12-test.patch
  * fixup-2-gdb-rhbz1553104-s390x-arch12-test.patch
  * fixup-gdb-lineno-makeup-test.patch
  * fixup-gdb-6.6-buildid-locate-rpm.patch
- Remove commented out mention of dropped patch
  gdb-fix-selftest-fails-with-gdb-build-with-O2-flto.patch.
* Thu Apr 18 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR31648 KFAIL.
  * Handle yama ptrace_scope == 1.
* Wed Apr 10 2024 Tom de Vries <tdevries@suse.com>
- Patches added (bsc#1220490):
  * fixup-gdb-6.6-buildid-locate-rpm.patch
* Wed Mar 20 2024 Richard Biener <rguenther@suse.com>
- Avoid using a %%gcc macro to support using gcc 4.8 for building
  on SLE11.  Use the regular language compilers for testing.
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Jan 10 2024 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR31214 kfail.
  * Add kfail for fails in gdb.reverse/solib-precsave.exp /
    gdb.reverse/solib-reverse.exp fixed by commit fe6356def67
    ("PowerPC and aarch64: Fix reverse stepping failure").
  * Extend PR31004 kfail.
- Don't require %%{python}-base for gdb-testresults package.
- Fix debuginfod handling:
  * Enable for sle_version >= 150400 (bsc#1185605, jsc#PED-1149,
    jsc#PED-1138), SLE15-SP4 and later.
  * Enable for suse_version >= 1600, ALP and Tumbleweed.
  * Add back "BuildRequires: libdebuginfod1" to prevent selecting
    dummy variant.
  * Add "BuildRequires: debuginfod-client" to prevent unresolved
    due to conflict with dummy variant.
  * Add --with-debuginfod=yes to prevent silently dropping support.
- Patches added (backport from master):
  * gdb-testsuite-add-missing-no-prompt-anchor-in-gdb.ba.patch
  * gdb-testsuite-remove-spurious-in-save_vars.patch
* Wed Dec 13 2023 Tom de Vries <tdevries@suse.com>
- Patches added (backport from gdb-patches, swo#30728):
  * gdb-symtab-refactor-condition-in-scan_attributes.patch
  * gdb-symtab-factor-out-m_die_range_map-usage.patch
  * gdb-symtab-handle-nullptr-parent-in-parent_map-set_p.patch
  * gdb-symtab-factor-out-m_deferred_entries-usage.patch
  * gdb-symtab-resolve-deferred-entries-inter-shard-case.patch
  * gdb-symtab-keep-track-of-processed-dies-in-shard.patch
  * gdb-symtab-resolve-deferred-entries-intra-shard-case.patch
  * gdb-symtab-don-t-defer-backward-refs-inter-cu-intra-.patch
  * gdb-symtab-recurse-into-c-dw_tag_subprogram-dies-for.patch
  * gdb-symtab-keep-track-of-all-parents-for-cooked-inde.patch
  * gdb-symtab-fix-dw_tag_inlined_subroutine-entries-in-.patch
* Mon Nov 13 2023 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Update PR31004 kfail.
- Patches added (backport from gdb-patches):
  * gdb-fix-segfault-in-for_each_block-part-1.patch
* Tue Oct 31 2023 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Update PR28561 kfail.
  * Remove PR31015 kfail.
  * Remove PR30547 kfail.
- Patches added (backport from master):
  * gdb-symtab-add-producer_is_gas.patch
  * gdb-symtab-work-around-gas-pr28629.patch
  * gdb-tdep-fix-nr-array-elements-in-ppc64_aggregate_ca.patch
  * gdb-testsuite-fix-gdb.python-py-breakpoint.exp-with-.patch
  * gdb-tui-fix-segfault-in-tui_find_disassembly_address.patch
  * gdb-tui-fix-wmaybe-uninitialized-in-tui_find_disasse.patch
  * gdb-testsuite-add-wait_for_msg-arg-to-term-resize-fi.patch
- Patches added (backport from gdb-patches):
  * gdb-fix-segfault-in-for_each_block-part-2.patch
  * gdb-tui-allow-command-window-of-1-or-2-lines.patch
  * gdb-tui-fix-resizing-of-terminal-to-1-or-2-lines.patch
* Tue Oct 31 2023 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Remove PR28467, PR29418, PR29420, PR29814 and PR29408 kfail.
  * Remove gdb.tui/tui-layout-asm-short-prog.exp kfail.
  * Remove commit f68eca29d3b, 29004660c94, 301fe55e9c4,
    4d88ae0c7b5, e7d69e72bfd, 8b272d7671f, 85819864f7c, 167f3beb655
    and a0eda3df5b7 kfails.
  * Add PR31015 kfail.
  * Remove PR29793 kfail.
  * Remove gdb.arch/powerpc-bcl-prologue.exp kfail.
  * Remove PR29813 and PR29816 kfail.
* Sun Oct 29 2023 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Update PR28561 kfail.
  * Update PR29781 kfail.
- Maintenance script qa-local.sh:
  * Add "Verify quilt setup" step.
- Patches added (backport from master):
  * gdb-symtab-handle-self-reference-die.patch
  * gdb-symtab-handle-self-reference-in-inherit_abstract.patch
  * gdb-symtab-add-optimized-out-static-var-to-cooked-in.patch
* Thu Oct 26 2023 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add comment to kfail for PR30528.
  * Add UNRESOLVED kfail for gdb.base/gcore-excessive-memory.exp.
  * Add UNRESOLVED kfail for PR31001.
  * Remove PR27238 kfail.
  * Add powerpc64le hw watchpoint kfails.
  * Add PR31004 kfail.
  * Add PR30531 kfail.
- Patches added (backport from master):
  * xcoffread.c-fix-werror-dangling-pointer-issue-with-m.patch
  * avoid-manual-memory-management-in-go-lang.c.patch
  * gdb-go-handle-v3-go_0-mangled-prefix.patch
* Thu Oct 26 2023 Tom de Vries <tdevries@suse.com>
- Patches added (backport from master):
  * gdb-symtab-don-t-deduplicate-variables-in-gdb-index.patch
- Patches dropped (requires unsupported command):
  * gdb-testsuite-add-wait-for-index-cache-in-gdb.dwarf2.patch
- Maintenance script qa.sh:
  * Added PR30528 kfail.
* Tue Oct 24 2023 Tom de Vries <tdevries@suse.com>
- Patches added (manual import from fedora rawhide @ 52a4dab):
  * gdb-rhbz1773651-gdb-index-internal-error.patch
- Patches added (backport from master):
  * gdb-support-rseq-auxvs.patch
  * gdb-symtab-fix-line-number-of-static-const-class-mem.patch
  * gdb-symtab-fix-too-many-symbols-in-gdbpy_lookup_stat.patch
  * gdb-symtab-handle-pu-in-iterate_over_some_symtabs.patch
  * gdb-symtab-work-around-pr-gas-29517.patch
  * gdb-testsuite-add-kfail-for-pr-ada-30908.patch
  * gdb-testsuite-add-xfail-for-gdb-29965-in-gdb.threads.patch
  * gdb-testsuite-fix-gdb.ada-mi_task_arg.exp-with-newer.patch
  * gdb-testsuite-fix-gdb.arch-i386-signal.exp-on-x86_64.patch
  * gdb-testsuite-fix-gdb.cp-m-static.exp-regression-on-.patch
  * gdb-testsuite-fix-gdb.dwarf2-nullptr_t.exp-with-cc-w.patch
  * gdb-testsuite-fix-regexps-in-gdb.base-step-over-sysc.patch
  * gdb-symtab-find-main-language-without-symtab-expansi.patch
  * gdb-testsuite-add-wait-for-index-cache-in-gdb.dwarf2.patch
- Patches moved (from "Backport from gdb-patches" to
  "Backports from master, available in next release"):
  * gdb-cli-handle-pending-c-after-rl_callback_read_char.patch
  * gdb-testsuite-add-have_host_locale.patch
- Maintenance script qa.sh:
  * Remove PR28463, PR28108, PR29247 and PR29160 kfails.
  * Remove PR30540, PR30908, PR29965 kfails.
  * Remove gdb.ada/mi_task_arg.exp kfail.
- Limit "Suggests: %%{python}-Pygments" to SLE-15 and later.
* Sat Oct 21 2023 Tom de Vries <tdevries@suse.com>
- Mention import-fedora.sh to fix warning.
- Maintenance script qa.sh:
  * Update kfail for PR28561.
* Fri Oct 20 2023 Tom de Vries <tdevries@suse.com>
- Maintenance script import-fedora.sh:
  * New script.  Move skipped patches list from gdb.spec to script.
- Update to fedora 38 @ 82cc8e0.
- Patch renamed:
  * pass-const-frame_info_ptr-reference-for-skip_-langua.patch ->
    gdb-rhbz2192105-ftbs-dangling-pointer
- Patches added:
  * gdb-bz2237392-dwarf-obstack-allocation.patch
  * gdb-bz2237515-debuginfod-double-free.patch
  * gdb-rhbz2160211-excessive-core-file-warnings.patch
  * gdb-rhbz2196395-debuginfod-legacy-openssl-crash.patch
  * gdb-rhbz2233961-CVE-2022-4806.patch
  * gdb-rhbz2233965-memory-leak.patch
- Maintenance script qa-local.sh:
  * Add openSUSE_Leap_15.5 and openSUSE_Factory_LegacyX86.
  * Add "List configs" item.
  * Skip i586 for SLE-11.
- Maintenance script qa.sh:
  * Make sure exit status is 0
* Wed Sep 27 2023 Tom de Vries <tdevries@suse.com>
- Add "Suggests: %%{python}-Pygments".
- Maintenance script qa.sh:
  * Note investigation of some ada test-cases.
  * Update PR30547 kfail.
  * Add PR28561 kfail.
  * Update PKRU-related kfail.
  * Use openSUSE_Factory_LegacyX86.i586 instead of
    openSUSE_Factory.i586.
  * Remove PR27813 kfail and corresponding todo.
* Sun Aug 20 2023 Luciano Santos <luc14n0@opensuse.org>
- Drop libdebuginfod1 BuildRequires/Recommends. The former isn't
  needed because there's a build requirement on libdebuginfod-devel
  already, which will pull the shared library. And the latter,
  because it's bogus since RPM auto generated dependency will take
  care of that requirement.
* Wed Jun 14 2023 Tom de Vries <tdevries@suse.com>
- Patches added (master backports):
  * pass-const-frame_info_ptr-reference-for-skip_-langua.patch
- Maintenance script qa.sh:
  * Add PR30543 kfail.
  * Remove PR29793 kfail.
* Mon Jun 12 2023 Tom de Vries <tdevries@suse.com>
- Patches added (master backports):
  * fix-pr30369-regression-on-aarch64-arm-pr30506.patch
  * gdb-tdep-aarch64-fix-frame-address-of-last-insn.patch
  * gdb-testsuite-fix-breakpoint-regexp-in-gdb.ada-out_o.patch
  * gdb-testsuite-relax-breakpoint-count-check-in-gdb.py.patch
  * gdb-testsuite-fix-buffer-overflow-in-gdb.base-signed.patch
  * gdb-testsuite-require-syscall-time-in-gdb.reverse-ti.patch
  * gdb-testsuite-handle-missing-gdc-in-gdb.dlang-dlang-.patch
  * gdb-testsuite-add-basic-lmap-for-tcl-8.6.patch
  * gdb-testsuite-fix-gdb.rust-watch.exp-on-ppc64le.patch
  * gdb-testsuite-fix-gdb.python-py-breakpoint.exp-timeo.patch
  * powerpc-fix-for-gdb.reverse-finish-precsave.exp-and-.patch
  * powerpc-regression-fix-for-reverse-finish-command.patch
  * gdb-testsuite-don-t-use-string-cat-in-gdb.dwarf2-dw2.patch
  * move-step_until-procedure.patch
- Patches added (gdb-patches backport):
  * gdb-testsuite-add-have_host_locale.patch
- Patches added (fedora patch fixups):
  * fixup-gdb-6.3-gstack-20050411.patch
  * fixup-gdb-6.3-attach-see-vdso-test.patch
  * fixup-gdb-lineno-makeup-test.patch
  * fixup-gdb-rhbz1261564-aarch64-hw-watchpoint-test.pat.patch
- Patches dropped:
  * gdb-ppc-power7-test.patch
  * gdb-rhbz1156192-recursive-dlopen-test.patch
  * gdb-6.3-bz140532-ppc-unwinding-test.patch
- Maintenance script qa.sh:
  * Add PR30540, PR30537, PR30021 and PR30542 KFAILs.
  * Add gdb.base/gcore-excessive-memory.exp internal error.
  * Update gdb.base/inline-frame-cycle-unwind.exp KFAIL comment.
* Fri Jun  9 2023 Tom de Vries <tdevries@suse.com>
- Patches added (master backports):
  * aarch64-avoid-initializers-for-vlas.patch
* Tue Jun  6 2023 Tom de Vries <tdevries@suse.com>
- Rebase to 13.2 release (fedora 38 @ fc4e284)
  * Replace gdb-12.1.tar.bz2 with gdb-13.2.tar.bz2.
- Patches dropped:
  * add-elfcompress_zstd.patch
  * binutils-gdb-support-zstd-compressed-debug-section.patch
  * fix-comparison-of-unsigned-long-int-to-int-in-record_linux_system_call.patch
  * fix-core-file-detach-crash-corefiles-29275.patch
  * fix-for-gdb.base-solib-search.exp-test.patch
  * fix-gdb-build-elf-support-check-lzstd.patch
  * fixup-gdb-rhbz1325795-framefilters-test.patch
  * gdb-6.3-focus-cmd-prev-test.patch
  * gdb-6.3-inheritancetest-20050726.patch
  * gdb-6.3-test-dtorfix-20050121.patch
  * gdb-6.3-test-movedir-20050125.patch
  * gdb-6.3-threaded-watchpoints2-20050225.patch
  * gdb-6.6-buildid-locate-rpm-scl.patch
  * gdb-6.6-bz230000-power6-disassembly-test.patch
  * gdb-add-gdb-syscalls-makefile.patch
  * gdb-add-support-for-readline-8.2.patch
  * gdb-bz601887-dwarf4-rh-test.patch
  * gdb-disable-commit-resumed-in-target_kill.patch
  * gdb-fix-assert-in-handle_jit_event.patch
  * gdb-fix-assert-when-quitting-gdb-while-a-thread-is-stepping.patch
  * gdb-fix-for-gdb.base-eof-exit.exp-test-failures.patch
  * gdb-fix-selftest-fails-with-gdb-build-with-O2-flto.patch
  * gdb-fortran-frame-string.patch
  * gdb-handle-pending-c-after-rl_callback_read_char.patch
  * gdb-improved-eof-handling-when-using-readline-7.patch
  * gdb-physname-pr11734-test.patch
  * gdb-physname-pr12273-test.patch
  * gdb-record-handle-statx-system-call.patch
  * gdb-rhbz1325795-framefilters-test.patch
  * gdb-rhbz1398387-tab-crash-test.patch
  * gdb-runtest-pie-override.patch
  * gdb-symtab-fix-handling-of-dw_tag_unspecified_type.patch
  * gdb-tdep-fix-powerpc-ieee-128-bit-format-arg-passing.patch
  * gdb-tdep-handle-pipe2-syscall-for-amd64.patch
  * gdb-tdep-support-catch-syscall-pipe2-for-i386.patch
  * gdb-tdep-update-syscalls-ppc64-ppc-linux.xml.patch
  * gdb-test-expr-cumulative-archer.patch
  * gdb-testsuite-add-kfail-in-gdb.threads-fork-plus-threads.exp.patch
  * gdb-testsuite-add-new-gdb_attach-to-check-attach-command.patch
  * gdb-testsuite-address-test-failures-in-gdb.mi-mi-multi-commands.exp.patch
  * gdb-testsuite-detect-change-instead-of-init-in-gdb.mi-mi-var-block.exp.patch
  * gdb-testsuite-enable-some-test-cases-for-x86_64-m32.patch
  * gdb-testsuite-fix-fail-in-gdb.threads-fork-and-threads.exp.patch
  * gdb-testsuite-fix-gdb.ada-literals.exp-with-aarch64.patch
  * gdb-testsuite-fix-gdb.base-break-idempotent.exp-on-ppc.patch
  * gdb-testsuite-fix-gdb.base-catch-syscall.exp-with-with-expat-no.patch
  * gdb-testsuite-fix-gdb.base-catch-syscall.exp-without-enable-targets.patch
  * gdb-testsuite-fix-gdb.base-infoline-reloc-main-from-.patch
  * gdb-testsuite-fix-gdb.base-nested-subp-2-3-.exp-with.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-dir-file-name.exp-w.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-out-of-range-end-of-seq.exp-on-aarch64.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-unspecified-type-foo.c-with-m32.patch
  * gdb-testsuite-fix-gdb.mi-mi-sym-info.exp-on-opensuse-tumbleweed.patch
  * gdb-testsuite-fix-gdb.opt-clobbered-registers-o2.exp-with-gcc-12.patch
  * gdb-testsuite-fix-gdb.reverse-i387-env-reverse.exp-for-pie.patch
  * gdb-testsuite-fix-gdb.reverse-test_ioctl_tcsetsw.exp-with-libc-debuginfo.patch
  * gdb-testsuite-fix-gdb.threads-killed-outside.exp-on-aarch64.patch
  * gdb-testsuite-fix-have_mpx-test.patch
  * gdb-testsuite-fix-occasional-failure-in-gdb.mi-mi-multi-commands.exp.patch
  * gdb-testsuite-fix-test-failure-when-building-against-readline-v7.patch
  * gdb-testsuite-handle-init-errors-in-gdb.mi-user-selected-context-sync.exp.patch
  * gdb-testsuite-handle-missing-.note.gnu-stack.patch
  * gdb-testsuite-handle-older-python-in-gdb.python-py-send-packet.py.patch
  * gdb-testsuite-handle-pipe2-syscall-in-gdb.base-catch-syscall.exp.patch
  * gdb-testsuite-handle-quotes-in-gdb_py_module_available.patch
  * gdb-testsuite-handle-unordered-dict-in-gdb.python-py-mi-cmd.exp.patch
  * gdb-testsuite-refactor-gdb.threads-detach-step-over.exp.patch
  * gdb-testsuite-remove-attach-test-from-can_spawn_for_attach.patch
  * gdb-testsuite-remove-global-declarations-in-gdb.threads-detach-step-over.exp.patch
  * gdb-testsuite-remove-target-limits-in-gdb.base-catch-syscall.exp.patch
  * gdb-testsuite-skip-gdb.fortran-namelist.exp-for-gfortran-4.8.patch
  * gdb-testsuite-support-recording-of-getrandom.patch
  * gdb-testsuite-workaround-unnecessary-.s-file-with-gfortran-4.8.patch
  * gdb-update-syscalls-amd64-i386-linux.xml.patch
  * gdbserver-switch-to-right-process-in-find_one_thread.patch
  * make-gdb.ada-float-bits.exp-more-generic.patch
  * powerpc-add-support-for-ieee-128-bit-format.patch
  * powerpc-correct-the-gdb-ioctl-values-for-tcgets-tcsets-tcsetsw-and-tcsetsf.patch
  * powerpc-fix-for-gdb.base-eh_return.exp.patch
  * powerpc-fix-gdb.base-watchpoint.exp-on-power-9.patch
  * powerpc-update-expected-floating-point-output-for-gdb.arch-altivec-regs.exp-and-gdb.arch-vsx-regs.exp.patch
- Patches added:
  * fixup-gdb-bz634108-solib_address.patch
  * gdb-binutils29988-read_indexed_address.patch
  * gdb-cli-handle-pending-c-after-rl_callback_read_char.patch
  * gdb-rhbz2177655-aarch64-pauth-valid-regcache.patch
  * gdb-rhbz2183595-rustc-inside_main.patch
  * gdb-testsuite-fix-gdb.gdb-python-helper.exp-with-o2-.patch
  * gdb-testsuite-handle-output-after-prompt-in-gdb.thre.patch
  * gdb-testsuite-simplify-gdb.base-unwind-on-each-insn..patch
  * remove-some-unnecessary-includes-from-exp.y.patch
  * gdb-testsuite-fix-gdb.rust-main-crash.exp.patch
- Patches modified:
  * gdb-6.3-bz140532-ppc-unwinding-test.patch
  * gdb-6.3-gstack-20050411.patch
  * gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch
  * gdb-6.6-buildid-locate-rpm-suse.patch
  * gdb-6.6-buildid-locate-rpm.patch
  * gdb-6.6-buildid-locate-solib-missing-ids.patch
  * gdb-6.6-buildid-locate.patch
  * gdb-6.7-testsuite-stable-results.patch
  * gdb-ccache-workaround.patch
  * gdb-core-open-vdso-warning.patch
  * gdb-fedora-libncursesw.patch
  * gdb-gcore-bash.patch
  * gdb-linux_perf-bundle.patch
  * gdb-testsuite-ada-pie.patch
  * gdb-testsuite-add-xfail-in-gdb.arch-i386-pkru.exp.patch
  * gdb-testsuite-factor-out-proc-linux_kernel_version.patch
  * gdb-testsuite-prevent-compilation-fails-with-unix-fpie-pie.patch
- Maintenance script qa.sh:
  * Add -i586 and -x86_64.
  * Add KFAILs for PR29040, PR30521, PR30180, PR30518, PR30519.
  * Update some KFAIL patterns.
  * Add some factory KFAILs.
  * Add gdb.base/longjmp-until-in-main.exp in PR26967 KFAILs.
- Maintenance script qa-local.sh:
  * Factor out version variable, update to 13.2.
  * Try to give reason for build failure.
  * Use -$arch as argument to qa.sh.
* Mon May 22 2023 Dirk Müller <dmueller@suse.com>
- disable werror as a workaround for deprecation warnings with
  python 3.11 (bsc#1211052)
* Fri Apr  7 2023 Tom de Vries <tdevries@suse.com>
- Revert to singlespec multibuild.
* Tue Apr  4 2023 Tom de Vries <tdevries@suse.com>
- Add multispec _multibuild.
* Tue Apr  4 2023 Tom de Vries <tdevries@suse.com>
- Don't use multibuild.
* Tue Apr  4 2023 Tom de Vries <tdevries@suse.com>
- Fix license, again (bsc#1210081).
* Fri Mar  3 2023 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Expand kfail pattern for PR29897.
  * Add PR29965 kfail.
* Thu Mar  2 2023 Tom de Vries <tdevries@suse.com>
- Re-enable testing all test-cases, undoing accidental change in
  previous commit.
- Add --with=for_chroot.
* Thu Feb 16 2023 Tom de Vries <tdevries@suse.com>
- Patches dropped (bsc#1207712):
  * gdb-container-rh-pkg.patch
- Patches added (bsc#1207712):
  * gdb-testsuite-add-gdb.suse-debranding.exp.patch
- Patches added (test-case fix):
  * gdb-testsuite-fix-gdb.dwarf2-dw2-dir-file-name.exp-w.patch
- Patches added (fedora patch fixup):
  * fixup-gdb-test-dw2-aranges.patch
- Patches added (master backports):
  * gdb-testsuite-add-xfail-in-gdb.arch-i386-pkru.exp.patch
  * gdb-testsuite-add-xfail-in-gdb.python-py-record-btra.patch
  * gdb-testsuite-factor-out-proc-linux_kernel_version.patch
  * gdb-testsuite-fix-gdb.base-infoline-reloc-main-from-.patch
  * gdb-testsuite-fix-gdb.base-nested-subp-2-3-.exp-with.patch
  * gdb-testsuite-fix-gdb.threads-schedlock.exp-on-fast-.patch
  * gdb-testsuite-handle-missing-.note.gnu-stack.patch
  * gdb-testsuite-simplify-gdb.arch-amd64-disp-step-avx..patch
  * gdb-testsuite-fix-gdb.threads-schedlock.exp-for-gcc-.patch
  * gdb-testsuite-add-xfail-case-in-gdb.python-py-record.patch
  * add-elfcompress_zstd.patch
  * binutils-gdb-support-zstd-compressed-debug-section.patch
  * fix-gdb-build-elf-support-check-lzstd.patch
- Patches removed (dropped by fedora):
  * gdb-test-ivy-bridge.patch
- Disable "BuildRequires: %%{gcc}-fortran" for SLE-11.
- Maintenance script qa-local.sh:
  * Add SLE-11 to configs.
  * Build with --no-verify.
- Maintenance script qa.sh:
  * Add -sle11.
* Tue Dec 13 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Re-enable PR26284 kfails.
  * Remove mention of PR28275.
  * Add PR29897 kfail.
- Mention CVE-2018-7208 and CVE-2017-16829.
* Tue Dec 13 2022 Tom de Vries <tdevries@suse.com>
- Mention SLE-21561, bnc#1081527, and bnc#1068950.
* Thu Dec  1 2022 Tom de Vries <tdevries@suse.com>
- Patches added (gdb 12 release branch backports):
  * gdb-disable-commit-resumed-in-target_kill.patch
  * gdb-fix-assert-when-quitting-gdb-while-a-thread-is-stepping.patch
  * gdb-testsuite-add-new-gdb_attach-to-check-attach-command.patch
  * gdb-testsuite-refactor-gdb.threads-detach-step-over.exp.patch
  * gdb-testsuite-remove-global-declarations-in-gdb.threads-detach-step-over.exp.patch
  * gdbserver-switch-to-right-process-in-find_one_thread.patch
- Patches removed:
  * gdb-testsuite-fix-race-in-gdb.threads-detach-step-over.exp.patch
- Maintenance script qa.sh:
  * Disable PR26284 kfails.
  * Add PR29841 kfails.
  * Add kfail_powerpc64le_sle12, kfail_s390 and kfail_s390x.
  * Add -s390 and -s390x.
  * Add gdb.base/gdb-rhbz1156192-recursive-dlopen.exp kfail.
  * Add PR26967 kfails.
  * Move PR27027 kfails from kfail_factory to kfail.
  * Add -ppc64le alias for -powerpc64le.
  * Add gdb.threads/interrupt-while-step-over.exp kfail.
  * Add gdb.tui/tui-layout-asm-short-prog.exp kfail.
  * Add unix/-fPIE/-fpie overrides -static kfails.
  * Add gdb.guile/scm-disasm.exp kfail.
  * Add gdb.base/gnu_vector.exp to existing kfail.
  * Add gdb.guile/scm-symtab.exp kfail.
  * Add gdb.base/write_mem.exp kfail.
* Tue Nov 22 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  - Add openSUSE Leap 15.4 ppc64le to known clean configs.
* Wed Nov 16 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  - Update PR26363 internal error pattern.
  - Add PR29790 kfail.
  - Add -powerpc64le option.
  - Generalize PR26915 kfail patterns.
  - Move PR28478 patterns from kfail_factory to kfail.
  - Add PR29781 and PR27813 kfails.
  - Add SLE-15 ppc64le to known clean configs.
* Tue Nov 15 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa-remote.sh:
  * Use qa.sh alongside qa-remote.sh.
- Maintenance script qa.sh:
  * Add PR29783 internal error.
- Patch removed (intended effect not observed):
  * gdb-fix-watchpoints-triggered.patch
* Fri Nov 11 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Handle librpm == "" and nolibrpm == "".
- Maintenance script qa-remote.sh:
  * Make "Get remote testsuite results" even more verbose.
  * Make hardcoded pattern gdb-testresults-12.1-*.*.rpm more
    generic.
  * Add missing setting of rpm variable in "Getting rpms" case.
- Patches added (backport from trunk):
  * gdb-testsuite-fix-gdb.base-break-idempotent.exp-on-ppc.patch
  * powerpc-fix-gdb.base-watchpoint.exp-on-power-9.patch
* Fri Oct 21 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa-remote.sh:
  * Make "Get remote testsuite results" more verbose.
* Wed Oct 19 2022 Tom de Vries <tdevries@suse.com>
- Patches added (swo#29277):
  * gdb-fix-assert-in-handle_jit_event.patch
- Maintenance script qa.sh:
  * Add PR29706 and PR28617 kfails.
* Thu Sep 29 2022 Fabian Vogt <fvogt@suse.com>
- Add patch to fix build with readline 8.2:
  * gdb-add-support-for-readline-8.2.patch
* Wed Sep 28 2022 Tom de Vries <tdevries@suse.com>
- Patches added:
  * gdb-testsuite-fix-gdb.mi-mi-sym-info.exp-on-opensuse-tumbleweed.patch
- Maintenance script qa.sh:
  * Add PR26873 kfails.
* Fri Sep 23 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa-remote.sh:
  * Make rpm matching yet more precise.
- Update patch:
  * gdb-tdep-fix-powerpc-ieee-128-bit-format-arg-passing.patch
- Add patches:
  * gdb-handle-pending-c-after-rl_callback_read_char.patch
  * gdb-testsuite-fix-have_mpx-test.patch
  * gdb-symtab-fix-handling-of-dw_tag_unspecified_type.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-unspecified-type-foo.c-with-m32.patch
* Thu Sep 22 2022 Dirk Müller <dmueller@suse.com>
- use python3-xml if python is python3
* Fri Sep  2 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Generalize PR29405 kfails.
- Maintenance script qa-remote.sh:
  * Make rpm matching more precise.
- Patches added:
  * gdb-tdep-fix-powerpc-ieee-128-bit-format-arg-passing.patch
* Mon Aug 22 2022 Martin Liška <mliska@suse.cz>
- Enable debuginfod for all archs as we index all TW RPM files.
- Recommend libdebuginfod1 when one installs gdb so that
  it can utilize debuginfod server by default.
* Tue Aug  2 2022 Tom de Vries <tdevries@suse.com>
- Fix build with gcc 13 by using -Wno-error=enum-int-mismatch.
* Sat Jul 30 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add SLE-12/x86_64 to "known clean configs".
  * Add fail for PR29405.
  * Add fail for PR26915.
* Fri Jul 29 2022 Tom de Vries <tdevries@suse.com>
- Patches added:
  * gdb-testsuite-fix-gdb.threads-killed-outside.exp-on-aarch64.patch
- Maintenance script qa.sh:
  * Remove PR29247 internal-error.
  * Add SLE-15/aarch64 to "known clean configs".
* Thu Jul 28 2022 Tom de Vries <tdevries@suse.com>
- Patches added:
  * gdb-fix-watchpoints-triggered.patch
- Maintenance script qa.sh:
  * Add kfails for PR25038, PR29253, and PR29423.
  * Remove gdb.mi/mi-var-invalidate-shlib.exp kfails.
- Mention qa-local.sh, qa-remote.sh and README.qa as sources.
* Wed Jul 27 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa-local.sh:
  * Use have_combo consistently.
- Maintenance script qa.sh:
  * Add kfail_aarch64.
  * Add PR29419/PR29409 kfails.
  * Update PR29247 kfails.
- Patches added:
  * make-gdb.ada-float-bits.exp-more-generic.patch
  * gdb-testsuite-fix-gdb.ada-literals.exp-with-aarch64.patch
* Tue Jul 26 2022 Tom de Vries <tdevries@suse.com>
- Actually apply fixup-gdb-test-bt-cfi-without-die.patch and
  fixup-2-gdb-rhbz1553104-s390x-arch12-test.patch.
* Mon Jul 25 2022 Tom de Vries <tdevries@suse.com>
- Also remove gdb-6.5-readline-long-line-crash-test.patch from
  patches list in gdb.spec.
* Mon Jul 25 2022 Tom de Vries <tdevries@suse.com>
- Patches added:
  * powerpc-add-support-for-ieee-128-bit-format.patch
  * powerpc-correct-the-gdb-ioctl-values-for-tcgets-tcsets-tcsetsw-and-tcsetsf.patch
  * gdb-testsuite-remove-target-limits-in-gdb.base-catch-syscall.exp.patch
  * powerpc-fix-for-gdb.base-eh_return.exp.patch
  * fix-comparison-of-unsigned-long-int-to-int-in-record_linux_system_call.patch
  * gdb-testsuite-fix-gdb.reverse-test_ioctl_tcsetsw.exp-with-libc-debuginfo.patch
  * fixup-gdb-test-bt-cfi-without-die.patch
  * fix-core-file-detach-crash-corefiles-29275.patch
  * gdb-testsuite-fix-gdb.dwarf2-dw2-out-of-range-end-of-seq.exp-on-aarch64.patch
  * gdb-testsuite-fix-gdb.base-catch-syscall.exp-without-enable-targets.patch
  * gdb-testsuite-fix-gdb.base-catch-syscall.exp-with-with-expat-no.patch
  * fix-for-gdb.base-solib-search.exp-test.patch
- Patch removed:
  * gdb-6.7-ppc-clobbered-registers-O2-test.patch
  * gdb-6.5-readline-long-line-crash-test.patch
- Patches updated:
  * gdb-tdep-update-syscalls-ppc64-ppc-linux.xml.patch
  * gdb-testsuite-handle-pipe2-syscall-in-gdb.base-catch-syscall.exp.patch
* Wed Jun 22 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR28504 KFAILs.
  * Make .sum file matching less complex.
  * Add fedora test-case kfail.
- Maintenance script qa-local.sh:
  * Fix incorrect path name.
- Update comments in gdb.spec.
- Patches added:
  * powerpc-update-expected-floating-point-output-for-gdb.arch-altivec-regs.exp-and-gdb.arch-vsx-regs.exp.patch
* Wed Jun 22 2022 Tom de Vries <tdevries@suse.com>
- Patches updated:
  * gdb-testsuite-support-recording-of-getrandom.patch
    (add aarch64 part)
- Maintenance script qa.sh:
  * Add i586 to known clean configs.
* Tue Jun 21 2022 Tom de Vries <tdevries@suse.com>
- Patches added:
  * gdb-testsuite-enable-some-test-cases-for-x86_64-m32.patch
  * gdb-testsuite-fix-gdb.reverse-i387-env-reverse.exp-for-pie.patch
  * gdb-testsuite-support-recording-of-getrandom.patch
- Patches updated:
  * gdb-record-handle-statx-system-call.patch
- Maintenance script qa.sh:
  * Allow only two summary files, for i586.
  * Add i586 KFAILs.
- Maintenance script qa-local.sh:
  * Add i586.
* Thu Jun 16 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa-local.sh:
  * Fix rpm pathname.
- Maintenance script qa-remote.sh:
  * Skip stale config openSUSE_Leap_15.2.
- Maintenance script qa.sh:
  * Drop known clean config: Leap 15.2 x86_64.
* Mon Jun 13 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa-local.sh:
  * Add cleanup step.
  * Add "build all configs without testsuite" step.
  * For "build all configs with testsuite" step, redirect output
    to log and produce PASS/FAIL line, and make sure buildroot is
    removed also in case of missing rpm.
  * Use "--clean --trust-all-projects" for osc build commands.
  * Drop openSUSE_Leap_15.2.
- Maintenance script qa.sh:
  * Rename argument 6 to -local.
  * Add PR29247 KFAILs.
  * Update internal-error regexps.
- New maintenance script qa-remote.sh.
- Add "build all configs without testsuite" step in README.qa.
- Patches added (backport from trunk):
  * gdb-testsuite-remove-attach-test-from-can_spawn_for_attach.patch
- README.qa:
  * Add remote qa entry.
  * Update local qa entry:
  * Add notes entry.
  * Other updates to match changes in qa-local.sh.
* Mon Jun 13 2022 Tom de Vries <tdevries@suse.com>
- Fix installed but unpackaged /usr/share/info/ctf-spec.info.gz.
* Sat Jun 11 2022 Tom de Vries <tdevries@suse.com>
- Rebase to 12.1 release (as in fedora 36 @ 89947a7):
  * DBX mode is deprecated, and will be removed in GDB 13.
  * GDB 12 is the last release of GDB that will support building against
    Python 2.  From GDB 13, it will only be possible to build GDB itself
    with Python 3 support.
  * Improved C++ template support:
    GDB now treats functions/types involving C++ templates like it does function
    overloads.  Users may omit parameter lists to set breakpoints on families of
    template functions, including types/functions composed of multiple template types:
    (gdb) break template_func(template_1, int)
    The above will set breakpoints at every function `template_func' where
    the first function parameter is any template type named `template_1' and
    the second function parameter is `int'.
    TAB completion also gains similar improvements.
  * New commands:
    maint set backtrace-on-fatal-signal on|off
    maint show backtrace-on-fatal-signal
    This setting is 'on' by default.  When 'on' GDB will print a limited
    backtrace to stderr in the situation where GDB terminates with a
    fatal signal.  This only supported on some platforms where the
    backtrace and backtrace_symbols_fd functions are available.
    set source open on|off
    show source open
    This setting, which is on by default, controls whether GDB will try
    to open source code files.  Switching this off will stop GDB trying
    to open and read source code files, which can be useful if the files
    are located over a slow network connection.
    set varsize-limit
    show varsize-limit
    These are now deprecated aliases for "set max-value-size" and
    "show max-value-size".
    task apply [all | TASK-IDS...] [FLAG]... COMMAND
    Like "thread apply", but applies COMMAND to Ada tasks.
    watch [...] task ID
    Watchpoints can now be restricted to a specific Ada task.
    maint set internal-error backtrace on|off
    maint show internal-error backtrace
    maint set internal-warning backtrace on|off
    maint show internal-warning backtrace
    GDB can now print a backtrace of itself when it encounters either an
    internal-error, or an internal-warning.  This is on by default for
    internal-error and off by default for internal-warning.
    set logging on|off
    Deprecated and replaced by "set logging enabled on|off".
    set logging enabled on|off
    show logging enabled
    These commands set or show whether logging is enabled or disabled.
    exit
    You can now exit GDB by using the new command "exit", in addition to
    the existing "quit" command.
    set debug threads on|off
    show debug threads
    Print additional debug messages about thread creation and deletion.
    set debug linux-nat on|off
    show debug linux-nat
    These new commands replaced the old 'set debug lin-lwp' and 'show
    debug lin-lwp' respectively.  Turning this setting on prints debug
    messages relating to GDB's handling of native Linux inferiors.
    maint flush source-cache
    Flush the contents of the source code cache.
    maint set gnu-source-highlight enabled on|off
    maint show gnu-source-highlight enabled
    Whether GDB should use the GNU Source Highlight library for adding
    styling to source code.  When off, the library will not be used, even
    when available.  When GNU Source Highlight isn't used, or can't add
    styling to a particular source file, then the Python Pygments
    library will be used instead.
    set suppress-cli-notifications (on|off)
    show suppress-cli-notifications
    This controls whether printing the notifications is suppressed for CLI.
    CLI notifications occur when you change the selected context
    (i.e., the current inferior, thread and/or the frame), or when
    the program being debugged stops (e.g., because of hitting a
    breakpoint, completing source-stepping, an interrupt, etc.).
    set style disassembler enabled on|off
    show style disassembler enabled
    If GDB is compiled with Python support, and the Python Pygments
    package is available, then, when this setting is on, disassembler
    output will have styling applied.
    set ada source-charset
    show ada source-charset
    Set the character set encoding that is assumed for Ada symbols.  Valid
    values for this follow the values that can be passed to the GNAT
    compiler via the '-gnati' option.  The default is ISO-8859-1.
  * Changed commands:
    print
    Printing of floating-point values with base-modifying formats like
    /x has been changed to display the underlying bytes of the value in
    the desired base.  This was GDB's documented behavior, but was never
    implemented correctly.
    maint packet
    This command can now print a reply, if the reply includes
    non-printable characters.  Any non-printable characters are printed
    as escaped hex, e.g. \x?? where '??' is replaces with the value of
    the non-printable character.
    clone-inferior
    The clone-inferior command now ensures that the TTY, CMD and ARGS
    settings are copied from the original inferior to the new one.
    All modifications to the environment variables done using the 'set
    environment' or 'unset environment' commands are also copied to the new
    inferior.
    set debug lin-lwp on|off
    show debug lin-lwp
    These commands have been removed from GDB.  The new command 'set
    debug linux-nat' and 'show debug linux-nat' should be used
    instead.
    info win
    This command now includes information about the width of the tui
    windows in its output.
  * GDB's Ada parser now supports an extension for specifying the exact
    byte contents of a floating-point literal.  This can be useful for
    setting floating-point registers to a precise value without loss of
    precision.  The syntax is an extension of the based literal syntax.
    Use, e.g., "16lf#0123abcd#" -- the number of "l"s controls the width
    of the floating-point type, and the "f" is the marker for floating
    point.
  * MI changes:
  * * The '-add-inferior' with no option flags now inherits the
    connection of the current inferior, this restores the behaviour of
    GDB as it was prior to GDB 10.
  * * The '-add-inferior' command now accepts a '--no-connection'
    option, which causes the new inferior to start without a
    connection.
  * Python API:
  * * New function gdb.add_history(), which takes a gdb.Value object
    and adds the value it represents to GDB's history list.  An
    integer, the index of the new item in the history list, is
    returned.
  * * New function gdb.history_count(), which returns the number of
    values in GDB's value history.
  * * New gdb.events.gdb_exiting event.  This event is called with a
    gdb.GdbExitingEvent object which has the read-only attribute
    'exit_code', which contains the value of the GDB exit code.  This
    event is triggered once GDB decides it is going to exit, but
    before GDB starts to clean up its internal state.
  * * New function gdb.architecture_names(), which returns a list
    containing all of the possible Architecture.name() values.  Each
    entry is a string.
  * * New function gdb.Architecture.integer_type(), which returns an
    integer type given a size and a signed-ness.
  * * New gdb.TargetConnection object type that represents a connection
    (as displayed by the 'info connections' command).  A sub-class,
    gdb.RemoteTargetConnection, is used to represent 'remote' and
    'extended-remote' connections.
  * * The gdb.Inferior type now has a 'connection' property which is an
    instance of gdb.TargetConnection, the connection used by this
    inferior.  This can be None if the inferior has no connection.
  * * New 'gdb.events.connection_removed' event registry, which emits a
    'gdb.ConnectionEvent' when a connection is removed from GDB.
    This event has a 'connection' property, a gdb.TargetConnection
    object for the connection being removed.
  * * New gdb.connections() function that returns a list of all
    currently active connections.
  * * New gdb.RemoteTargetConnection.send_packet(PACKET) method.  This
    is equivalent to the existing 'maint packet' CLI command; it
    allows a user specified packet to be sent to the remote target.
  * * New function gdb.host_charset(), returns a string, which is the
    name of the current host charset.
  * * New gdb.set_parameter(NAME, VALUE).  This sets the gdb parameter
    NAME to VALUE.
  * * New gdb.with_parameter(NAME, VALUE).  This returns a context
    manager that temporarily sets the gdb parameter NAME to VALUE,
    then resets it when the context is exited.
  * * The gdb.Value.format_string method now takes a 'styling'
    argument, which is a boolean.  When true, the returned string can
    include escape sequences to apply styling.  The styling will only
    be present if styling is otherwise turned on in GDB (see 'help
    set styling').  When false, which is the default if the argument
    is not given, then no styling is applied to the returned string.
  * * New read-only attribute gdb.InferiorThread.details, which is
    either a string, containing additional, target specific thread
    state information, or None, if there is no such additional
    information.
  * * New read-only attribute gdb.Type.is_scalar, which is True for
    scalar types, and False for all other types.
  * * New read-only attribute gdb.Type.is_signed.  This attribute
    should only be read when Type.is_scalar is True, and will be True
    for signed types, and False for all other types.  Attempting to
    read this attribute for non-scalar types will raise a ValueError.
  * * It is now possible to add GDB/MI commands implemented in Python.
- Update libipt to v2.0.5.
- Patches added:
  * gdb-6.3-rh-testversion-20041202.patch
  * gdb-6.5-BEA-testsuite.patch
  * gdb-6.6-buildid-locate-misleading-warning-missing-debuginfo-rhbz981154.patch
  * gdb-6.7-charsign-test.patch
  * gdb-6.8-bz466901-backtrace-full-prelinked.patch
  * gdb-fix-for-gdb.base-eof-exit.exp-test-failures.patch
  * gdb-improved-eof-handling-when-using-readline-7.patch
  * gdb-libexec-add-index.patch
  * gdb-tdep-detect-get_pc_thunk-call-in-i386-prologue.patch
  * gdb-testsuite-address-test-failures-in-gdb.mi-mi-multi-commands.exp.patch
  * gdb-testsuite-detect-change-instead-of-init-in-gdb.mi-mi-var-block.exp.patch
  * gdb-testsuite-fix-gdb.opt-clobbered-registers-o2.exp-with-gcc-12.patch
  * gdb-testsuite-fix-occasional-failure-in-gdb.mi-mi-multi-commands.exp.patch
  * gdb-testsuite-fix-test-failure-when-building-against-readline-v7.patch
  * gdb-testsuite-handle-older-python-in-gdb.python-py-send-packet.py.patch
  * gdb-testsuite-handle-quotes-in-gdb_py_module_available.patch
  * gdb-testsuite-handle-unordered-dict-in-gdb.python-py-mi-cmd.exp.patch
  * gdb-testsuite-skip-gdb.fortran-namelist.exp-for-gfortran-4.8.patch
  * gdb-testsuite-workaround-unnecessary-.s-file-with-gfortran-4.8.patch
- Patches dropped:
  * aarch64-make-gdbserver-register-set-selection-dynamic.patch
  * fix-build-with-current-gcc-el_explicit-location-always-non-null.patch
  * fix-gdb.base-sigstep.exp-test-for-ppc.patch
  * fix-gdb.multi-multi-term-settings.exp-race.patch
  * fixup-2-gdb-6.6-buildid-locate.patch
  * fixup-gdb-6.6-buildid-locate.patch
  * gdb-6.3-inferior-notification-20050721.patch
  * gdb-ada-fix-assert-in-ada_is_unconstrained_packed_array_type.patch
  * gdb-build-add-cxx_dialect-to-cxx.patch
  * gdb-build-make-c-exp.y-work-with-bison-3.8.patch
  * gdb-doc-fix-print-inferior-events-default.patch
  * gdb-exp-improve-error-reading-variable-message.patch
  * gdb-fortran-handle-dw-at-string-length-with-loclistptr.patch
  * gdb-r_version-check.patch
  * gdb-rhbz1976887-field-location-kind.patch
  * gdb-rhbz2012976-paper-over-fortran-lex-problems.patch
  * gdb-symtab-add-call_site_eq-and-call_site_hash.patch
  * gdb-symtab-c-ify-call_site.patch
  * gdb-symtab-fix-htab_find_slot-call-in-read_call_site_scope.patch
  * gdb-symtab-fix-segfault-in-search_one_symtab.patch
  * gdb-symtab-remove-compunit_call_site_htab.patch
  * gdb-symtab-use-unrelocated-addresses-in-call_site.patch
  * gdb-tdep-fix-avx512-m32-support-in-gdbserver.patch
  * gdb-tdep-rs6000-don-t-skip-system-call-in-skip_prologue.patch
  * gdb-test-for-rhbz1976887.patch
  * gdb-testsuite-add-gdb.arch-ppc64-break-on-_exit.exp.patch
  * gdb-testsuite-add-gdb.opt-break-on-_exit.exp.patch
  * gdb-testsuite-add-gdb.testsuite-dump-system-info.exp.patch
  * gdb-testsuite-add-missing-wait-in-gdb.base-signals-state-child.exp.patch
  * gdb-testsuite-add-nopie-in-two-test-cases.patch
  * gdb-testsuite-detect-no-mpx-support.patch
  * gdb-testsuite-disable-inferior-output-in-gdb.base-foll-vfork.exp.patch
  * gdb-testsuite-don-t-error-when-trying-to-unset-last_spawn_tty_name.patch
  * gdb-testsuite-factor-out-dump_info-in-gdb.testsuite-dump-system-info.exp.patch
  * gdb-testsuite-fix-assembly-comments-in-gdb.dwarf2-clang-debug-names.exp.tcl.patch
  * gdb-testsuite-fix-data-alignment-in-gdb.arch-i386-avx-sse-.exp.patch
  * gdb-testsuite-fix-fail-in-gdb.base-annota1.exp.patch
  * gdb-testsuite-fix-fail-in-gdb.tui-basic.exp.patch
  * gdb-testsuite-fix-fail-in-gdb.tui-corefile-run.exp.patch
  * gdb-testsuite-fix-gdb.ada-big_packed_array.exp-xfail-for-m32.patch
  * gdb-testsuite-fix-gdb.arch-i386-pkru.exp-on-linux.patch
  * gdb-testsuite-fix-gdb.base-annota1.exp-with-pie.patch
  * gdb-testsuite-fix-gdb.base-dcache-flush.exp.patch
  * gdb-testsuite-fix-gdb.gdb-selftest.exp.patch
  * gdb-testsuite-fix-gdb.guile-scm-type.exp-with-gcc-4.8.patch
  * gdb-testsuite-fix-gdb.python-py-events.exp.patch
  * gdb-testsuite-fix-gdb.server-server-kill.exp-with-m32.patch
  * gdb-testsuite-fix-gdb.threads-check-libthread-db.exp-with-glibc-2.34.patch
  * gdb-testsuite-fix-gdb.threads-linux-dp.exp.patch
  * gdb-testsuite-fix-gdb.threads-thread-specific-bp.exp.patch
  * gdb-testsuite-fix-port-detection-in-gdb.debuginfod-fetch_src_and_symbols.exp.patch
  * gdb-testsuite-fix-regexp-in-gdb.base-foll-vfork.exp.patch
  * gdb-testsuite-fix-stepi-test-cases-with-unix-m32-fpie-pie.patch
  * gdb-testsuite-handle-recursive-internal-problem-in-gdb_internal_error_resync.patch
  * gdb-testsuite-handle-runto-fail-in-gdb.mi-mi-var-cp.exp.patch
  * gdb-testsuite-handle-sigill-in-two-gdb.arch-powerpc-test-cases.patch
  * gdb-testsuite-handle-supports_memtag-in-gdb.base-gdb-caching-proc.exp.patch
  * gdb-testsuite-make-gdb.base-annota1.exp-more-robust.patch
  * gdb-testsuite-refactor-regexp-in-gdb.base-annota1.exp.patch
  * gdb-testsuite-support-fpie-fno-pie-pie-no-pie-in-gdb_compile_rust.patch
  * gdb-testsuite-update-test-gdb.base-step-over-syscall.exp.patch
  * gdb-testsuite-use-compiler-generated-instead-of-gas-generated-stabs.patch
  * gdb-tui-fix-breakpoint-display-functionality.patch
  * ibm-z-add-another-arch14-instruction.patch
  * ibm-z-remove-lpswey-parameter.patch
- Patched updated:
  * gdb-6.3-gstack-20050411.patch
  * gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch
  * gdb-6.6-buildid-locate-rpm-librpm-workaround.patch
  * gdb-6.6-buildid-locate-rpm-scl.patch
  * gdb-6.6-buildid-locate-rpm.patch
  * gdb-6.6-buildid-locate-solib-missing-ids.patch
  * gdb-6.6-buildid-locate.patch
  * gdb-cli-add-ignore-errors-command.patch
  * gdb-container-rh-pkg.patch
  * gdb-core-open-vdso-warning.patch
  * gdb-fedora-libncursesw.patch
  * gdb-gcore-bash.patch
  * gdb-linux_perf-bundle.patch
  * gdb-testsuite-handle-init-errors-in-gdb.mi-user-selected-context-sync.exp.patch
- Add BuildRequires python-xml.
- Maintenance script qa.sh:
  * Add -sle-12 and -factory options.
  * Handle *.-fPIE.-pie.sum files.
  * Add KFAILs for PRs 26292, 29238, 25059, 29240, 29241, 29244,
    29245, 29160, 29196.
  * Move PR27539 KFAILs from kfail_factory to kfail.
- New maintenance script qa-local.sh.
- New file README.qa.
* Mon May  9 2022 Tom de Vries <tdevries@suse.com>
- Patches added (trunk backport):
  * gdb-testsuite-detect-no-mpx-support.patch
  * gdb-testsuite-handle-init-errors-in-gdb.mi-user-selected-context-sync.exp.patch
  * gdb-add-gdb-syscalls-makefile.patch
- Patches added (ml backport):
  * gdb-update-syscalls-amd64-i386-linux.xml.patch
  * gdb-record-handle-statx-system-call.patch
- Patches added (to be upstreamed):
  * gdb-tdep-update-syscalls-ppc64-ppc-linux.xml.patch
- Maintenance script qa.sh:
  * Add another KFAIL for PR27027.
  * Remove PR28461 KFAIL.
* Wed May  4 2022 Tom de Vries <tdevries@suse.com>
- patches added (trunk backport):
  * gdb-testsuite-make-gdb.base-annota1.exp-more-robust.patch
  * gdb-testsuite-fix-gdb.base-annota1.exp-with-pie.patch
- patches added (gdb-patches ml backport):
  * gdb-tdep-handle-pipe2-syscall-for-amd64.patch
  * gdb-testsuite-handle-pipe2-syscall-in-gdb.base-catch-syscall.exp.patch
  * gdb-tdep-support-catch-syscall-pipe2-for-i386.patch
- Maintenance script qa.sh:
  * Add Leap 15.4 x86_64 to know good configs.
* Fri Apr 29 2022 Martin Liška <mliska@suse.cz>
- Remove dependency on binutils-gold as the package will be removed
  in the future. Gold linker is unmaintained by the upstream project.
* Thu Apr 14 2022 Tom de Vries <tdevries@suse.com>
- Fix unresolved BuildRequires fpc for Leap 15.4/i586.
* Fri Feb 25 2022 Tom de Vries <tdevries@suse.com>
- Patch added (backport from master):
  * fix-build-with-current-gcc-el_explicit-location-always-non-null.patch
* Fri Feb 11 2022 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add KFAILs for PR28667.
* Mon Feb  7 2022 Tom de Vries <tdevries@suse.com>
- Patches added (jsc#SLE-22287):
  * ibm-z-add-another-arch14-instruction.patch
  * ibm-z-remove-lpswey-parameter.patch
- Fedora fixup patch added:
  * fixup-gdb-6.5-bz243845-stale-testing-zombie-test.patch
* Thu Feb  3 2022 Andreas Schwab <schwab@suse.de>
- gdb-r_version-check.patch: gdb: Don't assume r_ldsomap when r_version >
  1 on Linux
* Mon Dec  6 2021 Tom de Vries <tdevries@suse.com>
- Patches added (swo#28323):
  gdb-ada-fix-assert-in-ada_is_unconstrained_packed_array_type.patch
* Tue Nov 30 2021 Tom de Vries <tdevries@suse.com>
- Patches added (swo#27028, swo#27257):
  * gdb-testsuite-fix-gdb.arch-i386-pkru.exp-on-linux.patch
  * gdb-tdep-fix-avx512-m32-support-in-gdbserver.patch
* Fri Nov 26 2021 Tom de Vries <tdevries@suse.com>
- Patch added (swo#28539, bsc#1192285):
  * gdb-symtab-fix-segfault-in-search_one_symtab.patch
* Mon Nov 22 2021 Tom de Vries <tdevries@suse.com>
- Patches removed:
  * gdb-testsuite-debug-gdb.arch-i386-sse.exp.patch
* Mon Nov 22 2021 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  - Drop openSUSE Leap 15.1.
  - Add KFAILs for PR28617.
* Mon Nov 22 2021 Tom de Vries <tdevries@suse.com>
- Fix SLE-12 x86_64 unresolvable by removing BuildRequire gcc-java.
* Mon Nov 22 2021 Tom de Vries <tdevries@suse.com>
- Fix openSUSE_Factory_ARM armv7l unresolvable by not doing
  BuildRequire babeltrace-devel.
* Mon Nov 22 2021 Tom de Vries <tdevries@suse.com>
- Fix SLE-12 x86_64 unresolvable by not doing BuildRequire
  babeltrace-devel.
* Fri Nov 19 2021 Tom de Vries <tdevries@suse.com>
- Patches added (backport from master):
  * gdb-testsuite-add-missing-wait-in-gdb.base-signals-state-child.exp.patch
- Add BuildRequire libsource-highlight.
* Thu Nov 18 2021 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  - Add KFAIL.
- Patches updated (increase sleep time):
  * gdb-testsuite-fix-race-in-gdb.threads-detach-step-over.exp.patch
- Patches added (debug hard to reproduce failure):
  * gdb-testsuite-debug-gdb.arch-i386-sse.exp.patch
* Thu Nov 18 2021 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  - Add internal-error KFAILs.
  - Rewrite gdb.suse check to distinguish between:
    "zypper hint printed (librpm)" and
    "zypper hint printed (no librpm)".
* Tue Nov 16 2021 Tom de Vries <tdevries@suse.com>
- Patch updated (zypper hint doesn't use librpm on SLE-11):
  * gdb-testsuite-add-gdb.suse-zypper-hint.exp.patch
* Thu Nov 11 2021 Tom de Vries <tdevries@suse.com>
- Patches added (backports from trunk):
  * gdb-testsuite-add-gdb.opt-break-on-_exit.exp.patch
  * gdb-tdep-rs6000-don-t-skip-system-call-in-skip_prologue.patch
  * gdb-testsuite-fix-stepi-test-cases-with-unix-m32-fpie-pie.patch
  * gdb-testsuite-fix-assembly-comments-in-gdb.dwarf2-clang-debug-names.exp.tcl.patch
  * gdb-doc-fix-print-inferior-events-default.patch
  * gdb-testsuite-fix-gdb.guile-scm-type.exp-with-gcc-4.8.patch
  * gdb-testsuite-add-gdb.arch-ppc64-break-on-_exit.exp.patch
  * gdb-testsuite-don-t-error-when-trying-to-unset-last_spawn_tty_name.patch
  * gdb-exp-improve-error-reading-variable-message.patch
  * fix-gdb.base-sigstep.exp-test-for-ppc.patch
  * gdb-testsuite-fix-regexp-in-gdb.base-foll-vfork.exp.patch
- Patches added (backports from ml):
  * gdb-testsuite-disable-inferior-output-in-gdb.base-foll-vfork.exp.patch
- Maintenance script qa.sh:
  - Add -m32/-pie to known clean configs.
  - Add kfail for PR28467.
* Tue Nov  9 2021 Tom de Vries <tdevries@suse.com>
- Fix empty patch:
  * gdb-testsuite-fix-fail-in-gdb.tui-basic.exp.patch
* Tue Nov  9 2021 Tom de Vries <tdevries@suse.com>
- Limit SLE extra targets to SLE targets.
- Add avr-elf and pru-elf to openSUSE extra targets.
* Mon Nov  8 2021 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add note.
  * Add KFAIL, improve KFAIL patterns.
- Patch updated:
  * gdb-testsuite-fix-data-alignment-in-gdb.arch-i386-avx-sse-.exp.patch
  * gdb-testsuite-fix-race-in-gdb.threads-detach-step-over.exp.patch
* Sat Nov  6 2021 Tom de Vries <tdevries@suse.com>
- Replace patch (patch from mailing list, fix SLE-11 apply failure):
  * gdb-tdep-aarch64-make-gdbserver-register-set-selection-dynamic.patch
  with (now backported from release branch):
  * aarch64-make-gdbserver-register-set-selection-dynamic.patch
- Patches added:
  * gdb-testsuite-fix-data-alignment-in-gdb.arch-i386-avx-sse-.exp.patch
  * gdb-testsuite-fix-fail-in-gdb.tui-basic.exp.patch
- Patches dropped:
  * gdb-testsuite-add-checks-to-gdb.arch-i386-sse.exp.patch
- Replace patch:
  * gdb-testsuite-Fix-gdb.threads-thread-specific-bp.exp.patch
  with (updated version, and patchname now generated by
  import-patches.sh):
  * gdb-testsuite-fix-gdb.threads-thread-specific-bp.exp.patch
- Maintenance script import-patches.sh:
  * Improve argument checking.
  * Add usage.
  * Use filterdiff to filter out ChangeLog entries.
- Maintenance script qa.sh:
  * Fix usage.
  * Document todo.
* Fri Nov  5 2021 Tom de Vries <tdevries@suse.com>
- Re-enable big endian powerpc, but keep testing disabled.
- Add KFAIL for PR28553.
* Fri Nov  5 2021 Tom de Vries <tdevries@suse.com>
- Patch added (move zypper hint test to testsuite):
  * gdb-testsuite-add-gdb.suse-zypper-hint.exp.patch
* Fri Nov  5 2021 Tom de Vries <tdevries@suse.com>
- Maintenance script qa.sh:
  * Add PR28551 KFAIL.
  * Add missing quotes for some KFAILs.
  * Remove PR28355 KFAIL.
* Tue Nov  2 2021 Tom de Vries <tdevries@suse.com>
- Patches added (add back ignore-errors command, dropped in
  11.1 update):
  * gdb-cli-add-ignore-errors-command.patch
* Mon Nov  1 2021 Tom de Vries <tdevries@suse.com>
- Patches added [swo#28355]:
  * gdb-tdep-aarch64-make-gdbserver-register-set-selection-dynamic.patch
* Thu Oct 28 2021 Tom de Vries <tdevries@suse.com>
- Mention removed fedora patches:
  * gdb-6.3-test-self-20050110.patch
  * gdb-bz1219747-attach-kills.patch
  * gdb-6.6-buildid-locate-core-as-arg.patch
  * gdb-attach-fail-reasons-5of5.patch
  * gdb-archer-pie-addons.patch
  * gdb-jit-reader-multilib.patch
  * gdb-6.5-bz218379-solib-trampoline-lookup-lock-fix.patch
  * gdb-archer.patch
  * gdb-config.patch
  * gdb-6.8-quit-never-aborts.patch
- Mention removed patches:
  * gdb-breakpoint-fix-assert-in-jit_event_handler.patch
  * gdb-fix-section-matching-in-find_pc_sect_compunit.patch
  * gdb-fortran-fix-print-dynamic-array.patch
  * gdb-build-hardcode-with-included-regex.patch
  * gdb-handle-no-upper-bound-in-value-subscript.patch
  * gdb-fix-internal-error-in-process_event_stop_test.patch
  * gdb-don-t-return-non-existing-path-in-debuginfod-source-query.patch
  * gdb-archer-pie-addons-keep-disabled.patch
  * gdb-fix-filename-in-not-in-executable-format-error.patch
  * gdb-fix-use-of-invalid-pointer-in-remote-async-inferior-event-handler.patch
  * gdb-breakpoints-handle-glibc-with-debuginfo-in-create_exception_master_breakpoint.patch
- Maintenance scripts:
  * Add KFAILs in qa.sh.
  * Add missing '-a' in gdb.log greps in qa.sh.
  * Fix error handling in qa.sh.
- Patches added:
  * gdb-testsuite-handle-sigill-in-two-gdb.arch-powerpc-test-cases.patch
  * gdb-testsuite-work-around-skip_prologue-problems-in-gdb.threads-process-dies-while-detaching.exp.patch
* Fri Oct 22 2021 Tom de Vries <tdevries@suse.com>
- Disable big endian powerpc.
- Maintenance scripts:
  * Fix patch filtering in clean.sh.
  * Add KFAIL in qa.sh.
- Patches added:
  * gdb-testsuite-add-checks-to-gdb.arch-i386-sse.exp.patch
  * gdb-testsuite-add-gdb.testsuite-dump-system-info.exp.patch
  * gdb-testsuite-add-kfail-in-gdb.threads-fork-plus-threads.exp.patch
  * gdb-testsuite-factor-out-dump_info-in-gdb.testsuite-dump-system-info.exp.patch
  * gdb-testsuite-fix-fail-in-gdb.threads-fork-and-threads.exp.patch
  * gdb-testsuite-fix-gdb.threads-linux-dp.exp.patch
  * gdb-testsuite-fix-port-detection-in-gdb.debuginfod-fetch_src_and_symbols.exp.patch
  * gdb-testsuite-handle-recursive-internal-problem-in-gdb_internal_error_resync.patch
  * gdb-testsuite-handle-runto-fail-in-gdb.mi-mi-var-cp.exp.patch
  * gdb-tui-fix-breakpoint-display-functionality.patch
  * gdb-testsuite-Fix-gdb.threads-thread-specific-bp.exp.patch
- Patches dropped:
  * fix-gdb.threads-linux-dp.exp.patch
* Wed Oct 20 2021 Tom de Vries <tdevries@suse.com>
- Added maintenance script:
  * qa.sh
- Drop 32bit packages for s390x.
* Tue Oct 19 2021 Tom de Vries <tdevries@suse.com>
- Fix SLE-15 s390x: unresolvable, nothing provides
  glibc-devel-static-32bit.
- Disable test-case gdb.base/break-interp.exp for SLE-11.
  It causes a
  "glibc detected *** expect: double free or corruption (out)" in
  expect and a subsequent runtest abort.  This might be the cause
  of the package build failure due to
  "Job seems to be stuck here, killed. (after 8hrs of inactivity)"
- Patches added:
  * gdb-testsuite-fix-gdb.base-step-over-syscall.exp-with-m32-amd-case.patch
  * gdb-testsuite-fix-gdb.ada-big_packed_array.exp-xfail-for-m32.patch
  * gdb-testsuite-fix-race-in-gdb.threads-detach-step-over.exp.patch
  * fix-gdb.multi-multi-term-settings.exp-race.patch
  * gdb-testsuite-update-test-gdb.base-step-over-syscall.exp.patch
* Mon Oct 18 2021 Tom de Vries <tdevries@suse.com> - 11.1
- Rebase to 11.1 release (as in fedora 35 @ 9cd9368):
  * Implements SLE-21561.
  * GDB now supports general memory tagging functionality if the
    underlying architecture supports the proper primitives and hooks.
    Currently this is enabled only for AArch64 MTE.
  * GDB will now look for the .gdbinit file in a config directory
    before looking for ~/.gdbinit.  The file is searched for in
    the following locations: $XDG_CONFIG_HOME/gdb/gdbinit,
    $HOME/.config/gdb/gdbinit, $HOME/.gdbinit.
  * GDB will now load and process commands from
    ~/.config/gdb/gdbearlyinit or ~/.gdbearlyinit if these files
    are present.  These files are processed earlier than any of
    the other initialization files and can affect parts of GDB's
    startup that previously had already been completed before the
    initialization files were read, for example styling of the
    initial GDB greeting.
  * GDB now has two new options "--early-init-command" and
    "--early-init-eval-command" with corresponding short options
    "-eix" and "-eiex" that allow options (that would normally
    appear in a gdbearlyinit file) to be passed on the command
    line.
  * set startup-quietly on|off
    show startup-quietly
    When 'on', this causes GDB to act as if "-silent" were passed
    on the command line.  This command needs to be added to an
    early initialization file (e.g. ~/.config/gdb/gdbearlyinit)
    in order to affect GDB.
  * For RISC-V targets, the target feature
    "org.gnu.gdb.riscv.vector" is now understood by GDB, and can
    be used to describe the vector registers of a target.
  * TUI windows now support mouse actions.  The mouse wheel
    scrolls the appropriate window.
  * Key combinations that do not have a specific action on the
    focused window are passed to GDB.  For example, you now can
    use Ctrl-Left/Ctrl-Right to move between words in the command
    window regardless of which window is in focus.  Previously
    you would need to focus on the command window for such key
    combinations to work.
  * set python ignore-environment on|off
    show python ignore-environment
    When 'on', this causes GDB's builtin Python to ignore any
    environment variables that would otherwise affect how Python
    behaves.  This command needs to be added to an early
    initialization file (e.g. ~/.config/gdb/gdbearlyinit) in
    order to affect GDB.
  * set python dont-write-bytecode auto|on|off
    show python dont-write-bytecode
    When 'on', this causes GDB's builtin Python to not write any
    byte-code (.pyc files) to disk.  This command needs to be
    added to an early initialization file
    (e.g. ~/.config/gdb/gdbearlyinit) in order to affect GDB.
    When 'off' byte-code will always be written.
    When set to 'auto' (the default) Python will check the
    PYTHONDONTWRITEBYTECODE environment variable.
  * break [PROBE_MODIFIER] [LOCATION] [thread THREADNUM]
    [-force-condition] [if CONDITION]
    This command would previously refuse setting a breakpoint if
    the CONDITION expression is invalid at a location.  It now
    accepts and defines the breakpoint if there is at least one
    location at which the CONDITION is valid.  The locations
    for which the CONDITION is invalid, are automatically
    disabled.  If CONDITION is invalid at all of the locations,
    setting the breakpoint is still rejected.  However, the
    '-force-condition' flag can be used in this case for forcing
    GDB to define the breakpoint, making all the current
    locations automatically disabled.  This may be useful if the
    user knows the condition will become meaningful at a future
    location, e.g. due to a shared library load.
- Update libipt to v2.0.4.  Dropped obsoleted patch:
  * v1.5-libipt-static.patch
- Obsoleted fedora patches dropped:
  * gdb-moribund-utrace-workaround.patch
  * gdb-save-restore-file-offset-while-reading-notes-in-core-file.patch
  * gdb-vla-intel-fix-print-char-array.patch
  * gdb-vla-intel-fortran-strides.patch
  * gdb-vla-intel-fortran-vla-strings.patch
  * gdb-vla-intel-stringbt-fix.patch
  * gdb-vla-intel-tests.patch
- Obsoleted fedora fixup patches dropped:
  * fixup-2-gdb-archer-vla-tests.patch
  * fixup-2-gdb-rhbz1156192-recursive-dlopen-test.patch
  * fixup-3-gdb-archer-vla-tests.patch
  * fixup-gdb-6.3-test-pie-20050107.patch
  * fixup-gdb-6.3-threaded-watchpoints2-20050225.patch
  * fixup-gdb-6.5-sharedlibrary-path.patch
  * fixup-gdb-6.8-bz442765-threaded-exec-test.patch
  * fixup-gdb-archer-vla-tests.patch
  * fixup-gdb-base-gnu-ifunc-strstr-workaround-exp.patch
  * fixup-gdb-btrobust.patch
  * fixup-gdb-bz634108-solib_address.patch
  * fixup-gdb-dts-rhel6-python-compat.patch
  * fixup-gdb-gnat-dwarf-crash-3of3.patch
  * fixup-gdb-rhbz1156192-recursive-dlopen-test.patch
  * fixup-gdb-test-ivy-bridge.patch
  * fixup-gdb-vla-intel-fortran-vla-strings.patch
  * fixup-gdb-vla-intel-tests.patch
- Obsoleted patches dropped:
  * amd64-linux-siginfo-include-order.patch
  * gdb-powerpc-remove-512-bytes-region-limit-if-2nd-dawr-is-avaliable.patch
  * gdb-support-dw-lle-start-end.patch
  * gdb-symtab-fix-infinite-recursion-in-dwarf2_cu-get_builder-again.patch
  * gdb-symtab-fix-language-of-frame-without-debug-info.patch
  * gdb-symtab-read-cu-base-address-for-enqueued-cu.patch
  * gdb-symtab-use-early-continue-in-find_pc_sect_compunit.patch
  * gdb-testsuite-catch-condition-evaluation-errors-in-gdb-assert.patch
  * gdb-testsuite-detect-gdb-prompt-after-monitor-exit.patch
  * gdb-testsuite-disable-selftests-for-factory.patch
  * gdb-testsuite-fix-control-flow-in-gdb-reverse-insn-reverse-exp.patch
  * gdb-testsuite-fix-failure-in-gdb-base-step-over-no-symbols-exp.patch
  * gdb-testsuite-fix-gdb-dlang-watch-loc-exp-on-ppc64.patch
  * gdb-testsuite-fix-gdb-reverse-insn-reverse-x86-c-for-m32.patch
  * gdb-testsuite-fix-gdb.arch-amd64-stap-three-arg-disp.s.patch
  * gdb-testsuite-fix-unset-of-debuginfod_urls-in-default_gdb_init.patch
  * gdb-testsuite-fix-xfail-handling-in-gdb.threads-gcore-thread.exp.patch
  * gdb-testsuite-gdb-base-morestack-exp-no-clang.patch
  * gdb-testsuite-gdb-tui-new-layout-exp-partly-require-tcl86.patch
  * gdb-testsuite-handle-sigill-in-gdb-reverse-insn-reverse-exp.patch
  * gdb-testsuite-ignore-debuginfod_urls.patch
  * gdb-testsuite-prevent-pagination-in-gdb-internalflags.patch
  * gdb-threads-fix-lin_thread_get_thread_signals-for-glibc-2.28.patch
  * gdb-try-to-load-libthread_db-only-after-reading-all-shared-libraries-when-attaching.patch
  * gdb-tui-fix-len_without_escapes-in-tui-disasm.c.patch
- Fedora patches updated:
  * gdb-6.3-bz140532-ppc-unwinding-test.patch
  * gdb-6.3-bz202689-exec-from-pthread-test.patch
  * gdb-6.3-gstack-20050411.patch
  * gdb-6.3-inheritancetest-20050726.patch
  * gdb-6.3-mapping-zero-inode-test.patch
  * gdb-6.3-test-dtorfix-20050121.patch
  * gdb-6.3-test-movedir-20050125.patch
  * gdb-6.3-threaded-watchpoints2-20050225.patch
  * gdb-6.5-bz109921-DW_AT_decl_file-test.patch
  * gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch
  * gdb-6.5-bz218379-ppc-solib-trampoline-test.patch
  * gdb-6.5-bz243845-stale-testing-zombie-test.patch
  * gdb-6.5-ia64-libunwind-leak-test.patch
  * gdb-6.5-last-address-space-byte-test.patch
  * gdb-6.5-readline-long-line-crash-test.patch
  * gdb-6.5-section-num-fixup-test.patch
  * gdb-6.5-sharedlibrary-path.patch
  * gdb-6.6-buildid-locate-rpm-scl.patch
  * gdb-6.6-buildid-locate-rpm.patch
  * gdb-6.6-buildid-locate-solib-missing-ids.patch
  * gdb-6.6-buildid-locate.patch
  * gdb-6.6-bz229517-gcore-without-terminal.patch
  * gdb-6.6-bz230000-power6-disassembly-test.patch
  * gdb-6.6-bz237572-ppc-atomic-sequence-test.patch
  * gdb-6.8-bz442765-threaded-exec-test.patch
  * gdb-bz601887-dwarf4-rh-test.patch
  * gdb-bz634108-solib_address.patch
  * gdb-ccache-workaround.patch
  * gdb-container-rh-pkg.patch
  * gdb-fedora-libncursesw.patch
  * gdb-fortran-frame-string.patch
  * gdb-glibc-strstr-workaround.patch
  * gdb-lineno-makeup-test.patch
  * gdb-linux_perf-bundle.patch
  * gdb-physname-pr11734-test.patch
  * gdb-ppc-power7-test.patch
  * gdb-rhbz1156192-recursive-dlopen-test.patch
  * gdb-rhbz1261564-aarch64-hw-watchpoint-test.patch
  * gdb-rhbz1350436-type-printers-error.patch
  * gdb-rhbz1398387-tab-crash-test.patch
  * gdb-test-dw2-aranges.patch
  * gdb-test-ivy-bridge.patch
  * gdb-test-pid0-core.patch
- Patches updated:
  * gdb-fix-selftest-fails-with-gdb-build-with-O2-flto.patch
  * gdb-gcore-bash.patch
- Fedora patches added:
  * gdb-6.3-attach-see-vdso-test.patch
  * gdb-6.3-inferior-notification-20050721.patch
  * gdb-6.5-gcore-buffer-limit-test.patch
  * gdb-6.5-missed-trap-on-step-test.patch
  * gdb-rhbz1976887-field-location-kind.patch
  * gdb-rhbz2012976-paper-over-fortran-lex-problems.patch
  * gdb-test-for-rhbz1976887.patch
- Fedora fixup patches added:
  * fixup-2-gdb-6.6-buildid-locate.patch
  * fixup-gdb-glibc-strstr-workaround.patch
  * fixup-gdb-linux_perf-bundle.patch
  * fixup-gdb-rhbz1325795-framefilters-test.patch
  * fixup-gdb-rhbz1553104-s390x-arch12-test.patch
- Patches added:
  * fix-gdb.mi-new-ui-mi-sync.exp.patch
  * fix-gdb.threads-linux-dp.exp.patch
  * gdb-add-index.sh-fix-bashism.patch
  * gdb-build-add-cxx_dialect-to-cxx.patch
  * gdb-build-make-c-exp.y-work-with-bison-3.8.patch
  * gdb-python-finishbreakpoint-update.patch
  * gdb-symtab-add-call_site_eq-and-call_site_hash.patch
  * gdb-symtab-c-ify-call_site.patch
  * gdb-symtab-fix-htab_find_slot-call-in-read_call_site_scope.patch
  * gdb-symtab-remove-compunit_call_site_htab.patch
  * gdb-symtab-use-unrelocated-addresses-in-call_site.patch
  * gdb-testsuite-add-nopie-in-two-test-cases.patch
  * gdb-testsuite-fix-fail-in-gdb.base-annota1.exp.patch
  * gdb-testsuite-fix-fail-in-gdb.tui-corefile-run.exp.patch
  * gdb-testsuite-fix-gdb.base-dcache-flush.exp.patch
  * gdb-testsuite-fix-gdb.gdb-selftest.exp.patch
  * gdb-testsuite-fix-gdb.python-py-events.exp.patch
  * gdb-testsuite-fix-gdb.server-server-kill.exp-with-m32.patch
  * gdb-testsuite-fix-gdb.threads-check-libthread-db.exp-with-glibc-2.34.patch
  * gdb-testsuite-handle-supports_memtag-in-gdb.base-gdb-caching-proc.exp.patch
  * gdb-testsuite-prevent-compilation-fails-with-unix-fpie-pie.patch
  * gdb-testsuite-refactor-regexp-in-gdb.base-annota1.exp.patch
  * gdb-testsuite-support-fpie-fno-pie-pie-no-pie-in-gdb_compile_rust.patch
  * gdb-testsuite-use-compiler-generated-instead-of-gas-generated-stabs.patch
- Fedora patches replaced:
  * fixup-gdb-6.6-buildid-locate.patch
- Added maintenance scripts:
  * import-patches.sh
  * clean.sh
* Tue Jul 20 2021 Andreas Schwab <schwab@suse.de>
- amd64-linux-siginfo-include-order.patch: Adjust include order to avoid
  gnulib error
* Wed Jun 23 2021 Andreas Schwab <schwab@suse.de>
- gdb-support-dw-lle-start-end.patch: Support DW_LLE_start_end
  (bsc#1187044)
* Thu Jun 17 2021 Tom de Vries <tdevries@suse.com>
- Fix Leap 15.3 s390x gdb:testsuite build, by not requiring 32-bit
  packages for openSUSE s390x.
* Thu Jun 17 2021 Tom de Vries <tdevries@suse.com>
- Fix Leap 15.3 s390x gdb:testsuite build, by not requiring
  glibc-devel-static-32bit.
* Thu Jun 17 2021 Tom de Vries <tdevries@suse.com>
- Fix Leap 15.3 i586 gdb:testsuite build, by not requiring fpc.
* Wed Jun 16 2021 Tom de Vries <tdevries@suse.com>
- Backport updated fix from upstream [bsc#1185638, swo#26327]:
  * gdb-symtab-fix-infinite-recursion-in-dwarf2_cu-get_builder-again.patch
* Fri May 21 2021 Tom de Vries <tdevries@suse.com>
- Backport fix for assert [bsc#1186040, swo#27889]:
  * gdb-breakpoint-fix-assert-in-jit_event_handler.patch
* Wed May 12 2021 Tom de Vries <tdevries@suse.com>
- Remove fix due to regressions [bsc#1185638, swo#26327]:
  * gdb-symtab-fix-infinite-recursion-in-dwarf2_cu-get_builder.patch
* Fri May  7 2021 Tom de Vries <tdevries@suse.com>
- Replace tentative fix with upstreamed fix [swo#27681]:
  Remove:
  * gdb-build-workaround-pcre2_posix-linking-problem.patch
  Add:
  * gdb-build-hardcode-with-included-regex.patch
- Backport fix from upstream [bsc#1185638, swo#26327]:
  * gdb-symtab-fix-infinite-recursion-in-dwarf2_cu-get_builder.patch
- Backport fix from upstream [rh#1931344]:
  * gdb-save-restore-file-offset-while-reading-notes-in-core-file.patch
* Sun May  2 2021 Tom de Vries <tdevries@suse.com>
- Backport fix for tui assert [swo#27680]:
  * gdb-tui-fix-len_without_escapes-in-tui-disasm.c.patch
* Wed Apr  7 2021 Tom de Vries <tdevries@suse.com>
- Backport fixes that ignore DEBUGINFOD_URLS during testing:
  * gdb-testsuite-ignore-debuginfod_urls.patch
  * gdb-testsuite-fix-unset-of-debuginfod_urls-in-default_gdb_init.patch
* Tue Apr  6 2021 Tom de Vries <tdevries@suse.com>
- Fix various testsuite fails on Factory using backports:
  * gdb-testsuite-fix-gdb.arch-amd64-stap-three-arg-disp.s.patch
  * gdb-testsuite-fix-xfail-handling-in-gdb.threads-gcore-thread.exp.patch
  * gdb-threads-fix-lin_thread_get_thread_signals-for-glibc-2.28.patch
- Fix libthread_db problem on Factory [swo#27526, boo#1184214]:
  * gdb-try-to-load-libthread_db-only-after-reading-all-shared-libraries-when-attaching.patch
- Workaround libncurses pulling in libpcre2_posix:
  * gdb-build-workaround-pcre2_posix-linking-problem.patch
* Thu Feb 11 2021 Tom de Vries <tdevries@suse.com>
- Replace tentative fix with upstreamed fix [swo#26881]:
  Remove:
  * gdb-fix-assert-in-process-event-stop-test.patch
  Add:
  * gdb-fix-internal-error-in-process_event_stop_test.patch
  * gdb-breakpoints-handle-glibc-with-debuginfo-in-create_exception_master_breakpoint.patch
* Thu Feb 11 2021 Tom de Vries <tdevries@suse.com>
- Fix license [bsc#1180786].
* Wed Dec  9 2020 Tom de Vries <tdevries@suse.com>
- Backport from master [jsc#13656]:
  * gdb-powerpc-remove-512-bytes-region-limit-if-2nd-dawr-is-avaliable.patch
- Require 8GB diskspace for x86_64.
* Mon Nov 30 2020 Tom de Vries <tdevries@suse.com>
- Patches to be upstreamed:
  * gdb-fix-use-of-invalid-pointer-in-remote-async-inferior-event-handler.patch
* Mon Nov 30 2020 Tom de Vries <tdevries@suse.com>
- Mention fedora patch fixups added:
  * fixup-3-gdb-archer-vla-tests.patch
- Mention patch to be upstreamed added:
  * gdb-fix-selftest-fails-with-gdb-build-with-O2-flto.patch
* Fri Nov 27 2020 Tom de Vries <tdevries@suse.com>
- Fedora patch fixups update:
  * fixup-2-gdb-rhbz1156192-recursive-dlopen-test.patch
- Fedora patch fixups added:
  * fixup-gdb-test-ivy-bridge.patch
- Add xz to BuildRequires for testsuite flavour.
- Add note on mpfr-devel for SLE-11.
* Thu Nov 26 2020 Tom de Vries <tdevries@suse.com>
- Backport from master:
  * gdb-testsuite-fix-failure-in-gdb-base-step-over-no-symbols-exp.patch
- Patch to be upstreamed:
  * gdb-testsuite-fix-control-flow-in-gdb-reverse-insn-reverse-exp.patch
* Thu Nov 26 2020 Tom de Vries <tdevries@suse.com>
- Patch updated:
  * gdb-testsuite-gdb-tui-new-layout-exp-partly-require-tcl86.patch
* Wed Nov 25 2020 Tom de Vries <tdevries@suse.com>
- Patch updated:
  * gdb-testsuite-gdb-tui-new-layout-exp-partly-require-tcl86.patch
* Tue Nov 24 2020 Tom de Vries <tdevries@suse.com>
- Patch to be upstreamed:
  * gdb-testsuite-gdb-base-morestack-exp-no-clang.patch
  * gdb-testsuite-handle-sigill-in-gdb-reverse-insn-reverse-exp.patch
  * gdb-testsuite-fix-gdb-reverse-insn-reverse-x86-c-for-m32.patch
  * gdb-testsuite-gdb-tui-new-layout-exp-partly-require-tcl86.patch
  * gdb-tui-enable-work-around-libncurses-segfault.patch
- Backport from master dropped:
  * gdb-testsuite-fix-unbalanced-braces-in-gdb-tui-new-layout-exp.patch
* Wed Nov 18 2020 Tom de Vries <tdevries@suse.com> - 10.1
- Fedora patch fixups updated:
  * fixup-2-gdb-archer-vla-tests.patch
- Fedora patch fixups added:
  * fixup-2-gdb-rhbz1156192-recursive-dlopen-test.patch
- Testsuite patch:
  * gdb-testsuite-disable-selftests-for-factory.patch
- Backport from master:
  * gdb-symtab-read-cu-base-address-for-enqueued-cu.patch
  * gdb-symtab-use-early-continue-in-find_pc_sect_compunit.patch
  * gdb-fix-section-matching-in-find_pc_sect_compunit.patch
  * gdb-symtab-fix-language-of-frame-without-debug-info.patch
- Patch to be upstreamed:
  * gdb-symtab-set-default-dwarf-max-cache-age-1000.patch
* Thu Nov 12 2020 Tom de Vries <tdevries@suse.com>
- BuildRequire curl for debuginfod test-case.
- Patch to be upstreamed:
  * gdb-don-t-return-non-existing-path-in-debuginfod-source-query.patch
  * gdb-fix-assert-in-process-event-stop-test.patch
  * gdb-fix-filename-in-not-in-executable-format-error.patch
  * gdb-handle-no-upper-bound-in-value-subscript.patch
  * gdb-fortran-handle-dw-at-string-length-with-loclistptr.patch
- Testsuite patch:
  * gdb-testsuite-fix-gdb-server-ext-run-exp-for-obs.patch
- Fedora patch fixups added:
  * fixup-gdb-rhbz1156192-recursive-dlopen-test.patch
- Fedora patch fixups updated:
  * fixup-gdb-btrobust.patch
  * fixup-2-gdb-archer-vla-tests.patch
* Thu Nov 12 2020 Tom de Vries <tdevries@suse.com>
- Add missing patch command for:
  * gdb-fortran-fix-print-dynamic-array.patch
* Thu Nov 12 2020 Tom de Vries <tdevries@suse.com>
- Fix patch application on SLE-11:
  * gdb-testsuite-detect-gdb-prompt-after-monitor-exit.patch
* Thu Nov 12 2020 Tom de Vries <tdevries@suse.com>
- Disable xz-devel and binutils-gold for SLE-10.
- More enabling of gdbserver for riscv64.
- Backport from master:
  * gdb-testsuite-fix-unbalanced-braces-in-gdb-tui-new-layout-exp.patch
  * gdb-testsuite-catch-condition-evaluation-errors-in-gdb-assert.patch
  * gdb-testsuite-detect-gdb-prompt-after-monitor-exit.patch
  * gdb-testsuite-fix-gdb-dlang-watch-loc-exp-on-ppc64.patch
- Patch to be upstreamed:
  * gdb-fortran-fix-print-dynamic-array.patch
* Wed Nov 11 2020 Tom de Vries <tdevries@suse.com>
- Enable gdbserver for riscv64.
- Restrict BuildRequires libdebuginfod to Factory and supporting
  archs.
* Tue Nov 10 2020 Tom de Vries <tdevries@suse.com>
- Rebase to 10.1 release (as in fedora 33 @ 6c8ccd6).
  * Debuginfod support.
  * Multi-target debugging support.
  * Multithreaded symbol loading enabled by default.
  * New command set exec-file-mismatch.
  * New command tui new-layout.
  * Alias command can now specify default args for an alias.
- Update libipt to v2.0.2.
- Fedora-specific patches dropped:
  * gdb-6.8-bz466901-backtrace-full-prelinked.patch
- Broken/obsolete fedora patches dropped:
  * gdb-bz533176-fortran-omp-step.patch
  * gdb-6.5-BEA-testsuite.patch
  * gdb-6.7-charsign-test.patch
- Obsoleted fedora patches dropped:
  * gdb-6.3-attach-see-vdso-test.patch
  * gdb-6.3-inferior-notification-20050721.patch
  * gdb-6.5-gcore-buffer-limit-test.patch
  * gdb-6.5-missed-trap-on-step-test.patch
  * gdb-rhbz1818011-bfd-gcc10-error.patch
- Fedora patches updated:
  * gdb-6.3-gstack-20050411.patch
  * gdb-6.3-test-self-20050110.patch
  * gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch
  * gdb-6.5-bz218379-solib-trampoline-lookup-lock-fix.patch
  * gdb-6.6-buildid-locate-core-as-arg.patch
  * gdb-6.6-buildid-locate-rpm-librpm-workaround.patch
  * gdb-6.6-buildid-locate-rpm-scl.patch
  * gdb-6.6-buildid-locate-rpm.patch
  * gdb-6.6-buildid-locate-solib-missing-ids.patch
  * gdb-6.6-buildid-locate.patch
  * gdb-6.7-testsuite-stable-results.patch
  * gdb-6.8-quit-never-aborts.patch
  * gdb-archer-pie-addons-keep-disabled.patch
  * gdb-archer-pie-addons.patch
  * gdb-archer-vla-tests.patch
  * gdb-attach-fail-reasons-5of5.patch
  * gdb-bz1219747-attach-kills.patch
  * gdb-bz533176-fortran-omp-step.patch
  * gdb-container-rh-pkg.patch
  * gdb-fedora-libncursesw.patch
  * gdb-gnat-dwarf-crash-3of3.patch
  * gdb-jit-reader-multilib.patch
  * gdb-linux_perf-bundle.patch
  * gdb-moribund-utrace-workaround.patch
  * gdb-runtest-pie-override.patch
  * gdb-vla-intel-fix-print-char-array.patch
  * gdb-vla-intel-fortran-strides.patch
  * gdb-vla-intel-fortran-vla-strings.patch
  * gdb-vla-intel-stringbt-fix.patch
  * gdb-vla-intel-tests.patch
- Fedora patches added:
  * gdb-config.patch
- Obsoleted patched dropped:
  * gdb-testsuite-avoid-pagination-in-attach-32.exp.patch
  * gdb-fix-toplevel-types-with-fdebug-types-section.patch
  * gdb-fix-range-loop-index-in-find_method.patch
  * gdb-fix-python3.9-related-runtime-problems.patch
  * gdb-fix-unused-function-error.patch
  * gdb-fix-the-thread-pool.c-compilation.patch
  * gdb-aarch64-fix-erroneous-use-of-spu-architecture-bfd.patch
  * gdb-fix-debug-agent-odr-bool-int.patch
  * gdbserver-fix-build-with-make-3.81.patch
  * gdb-threads-fix-hang-in-stop_all_threads-after-killing-inferior.patch
- Fedora patch fixups added:
  * fixup-gdb-6.3-test-pie-20050107.patch
  * fixup-gdb-6.5-sharedlibrary-path.patch
  * fixup-gdb-6.6-buildid-locate.patch
  * fixup-gdb-6.8-bz442765-threaded-exec-test.patch
  * fixup-gdb-archer-vla-tests.patch
  * fixup-gdb-base-gnu-ifunc-strstr-workaround-exp.patch
  * fixup-gdb-btrobust.patch
  * fixup-gdb-bz634108-solib_address.patch
  * fixup-gdb-dts-rhel6-python-compat.patch
  * fixup-gdb-gnat-dwarf-crash-3of3.patch
  * fixup-gdb-vla-intel-fortran-vla-strings.patch
  * fixup-gdb-vla-intel-tests.patch
  * fixup-gdb-6.3-threaded-watchpoints2-20050225.patch
- Patches renamed:
  * gdb-testsuite-fix-perror-in-gdb.opt-fortran-string.exp.patch
    to fixup-2-gdb-archer-vla-tests.patch
- Patches updated:
  * gdb-testsuite-ada-pie.patch
- Backport from master:
  * gdb-testsuite-prevent-pagination-in-gdb-internalflags.patch
* Mon Sep  7 2020 Andreas Schwab <schwab@suse.de>
- Enable CTF support also for riscv64
* Tue Aug 11 2020 Tom de Vries <tdevries@suse.com>
- Restore License/Group.
* Fri Aug  7 2020 Tom de Vries <tdevries@suse.com>
- Don't BuildRequire systemtap-sdt-devel for SLE-11.
* Fri Aug  7 2020 Tom de Vries <tdevries@suse.com>
- Add testsuite BuildRequire systemtap-sdt-devel.
* Tue Aug  4 2020 Tom de Vries <tdevries@suse.com>
- Add BuildRequire babeltrace-devel.  On Factory this adds bdeps
  babeltrace-devel, libuuid-devel, babeltrace, libglib-2_0-0, and
  libgmodule-2_0-0.
* Wed Jul 29 2020 Tom de Vries <tdevries@suse.com>
- Fix internal error on aarch64 [swo#26316].
  gdb-aarch64-fix-erroneous-use-of-spu-architecture-bfd.patch
* Tue Jul 28 2020 Tom de Vries <tdevries@suse.com>
- Change into multibuild package and add flavour gdb-testsuite.
* Fri Jul 24 2020 Tom de Vries <tdevries@suse.com>
- Fix s390 -> s390x typo.
* Fri Jul 24 2020 Tom de Vries <tdevries@suse.com>
- Don't BuildRequire binutils-gold for SLE-12/s390.
* Fri Jul 24 2020 Tom de Vries <tdevries@suse.com>
- BuildRequire binutils-gold for testsuite
* Thu Jul 23 2020 Tom de Vries <tdevries@suse.com>
- Rebase to 9.2 release.
* Tue Jul 14 2020 Tom de Vries <tdevries@suse.com>
- Fix SLE-11 build.  Gdb 9.1 requires make 3.82, but SLE-11 has
  make 3.81:
  * gdbserver-fix-build-with-make-3.81.patch
* Tue Jul 14 2020 Tom de Vries <tdevries@suse.com>
- Fix patch context:
  * gdb-fix-the-thread-pool.c-compilation.patch
* Mon Jul 13 2020 Tom de Vries <tdevries@suse.com>
- Fix build error due to missing DIAGNOSTIC_IGNORE_UNUSED_FUNCTION.
  * gdb-fix-the-thread-pool.c-compilation.patch
* Mon Jul 13 2020 Tom de Vries <tdevries@suse.com>
- Drop ChangeLog part of patch:
  * gdb-fix-unused-function-error.patch
* Mon Jul 13 2020 Tom de Vries <tdevries@suse.com>
- Fix Werror=unused-function with gcc 4.8 (for Leap 42.3).
  * gdb-fix-unused-function-error.patch
* Mon Jul 13 2020 Tom de Vries <tdevries@suse.com>
- Require %%{suse_version} >= 1500 for --with-system-readline.
* Mon Jul 13 2020 Tom de Vries <tdevries@suse.com>
- Rebase to 9.1 release (as in fedora 32 @ 1735910).
  * Breakpoints on nested functions and subroutines in Fortran.
  * Multithreaded symbol loading, disabled by default.  Enable
    using 'maint set worker-threads unlimited'.
  * Multi-target debugging support.
  * New command pipe.
  * New command set logging debugredirect [on|off].
  * New fortran commands info modules, info module functions,
    info module variables.
- Fedora-specific patches dropped:
  * gdb-libexec-add-index.patch
  * gdb-6.3-rh-testversion-20041202.patch
  * gdb-6.6-buildid-locate-misleading-warning-missing-debuginfo-rhbz981154.patch
- Obsoleted fedora patches dropped:
  * gdb-6.5-bz216711-clone-is-outermost.patch
  * gdb-6.6-scheduler_locking-step-is-default.patch
  * gdb-6.8-bz436037-reg-no-longer-active.patch
  * gdb-bz541866-rwatch-before-run.patch
  * gdb-bz568248-oom-is-error.patch
  * gdb-follow-child-stale-parent.patch
  * gdb-readline62-ask-more-rh.patch
  * gdb-rhbz1371380-gcore-elf-headers.patch
  * gdb-rhbz1553086-binutils-warning-loadable-section-outside-elf.patch
  * gdb-rhbz1704406-disable-style-log-output-1of3.patch
  * gdb-rhbz1704406-disable-style-log-output-2of3.patch
  * gdb-rhbz1704406-disable-style-log-output-3of3.patch
  * gdb-rhbz1708192-parse_macro_definition-crash.patch
  * gdb-rhbz1723564-gdb-crash-PYTHONMALLOC-debug.patch
  * gdb-rhbz795424-bitpos-20of25.patch
  * gdb-rhbz795424-bitpos-21of25.patch
  * gdb-rhbz795424-bitpos-22of25.patch
  * gdb-rhbz795424-bitpos-23of25.patch
  * gdb-rhbz795424-bitpos-25of25-test.patch
  * gdb-rhbz795424-bitpos-25of25.patch
  * gdb-rhbz795424-bitpos-arrayview.patch
  * gdb-rhbz795424-bitpos-lazyvalue.patch
  * gdb-testsuite-readline63-sigint.patch
- Fedora patches added:
  * gdb-rhbz1818011-bfd-gcc10-error.patch
- Obsoleted patched dropped:
  * gdb-fix-s390-build.diff
  * gdb-fix-riscv-tdep.patch
  * gdb-testsuite-add-missing-initial-prompt-read-in-multidictionary.exp.patch
  * gdb-testsuite-pie-no-pie.patch
  * gdb-testsuite-read1-fixes.patch
  * gdb-testsuite-i386-pkru-exp.patch
  * gdb-s390-handle-arch13.diff
  * gdb-fix-heap-use-after-free-in-typename-concat.patch
  * gdb-dwarf-reader-reject-sections-with-invalid-sizes.patch
  * gdb-0001-remove-alloca-0-calls.patch
  * gdb-arch13-1.diff
  * gdb-arch13-2.diff
  * gdb-arch13-3.diff
  * bfd-change-num_group-to-unsigned-int.patch
  * gdb-fix-incorrect-use-of-is-operator-for-comparison-in-python-lib-gdb-command-prompt.py.patch
  * gdb-symtab-prefer-var-def-over-decl.patch
  * gdb-only-force-interp_console-ui_out-for-breakpoint-commands-in-mi-mode.patch
  * gdb-testsuite-8.3-kfail-xfail-unsupported.patch
- Backport from master:
  * gdb-fix-debug-agent-odr-bool-int.patch
  * gdb-fix-python3.9-related-runtime-problems.patch
* Wed May  6 2020 Tom de Vries <tdevries@suse.com>
- Fix .debug_types problems [swo#24480, swo#25889, bsc#1168394].
  - gdb-fix-range-loop-index-in-find_method.patch
  - gdb-fix-toplevel-types-with-fdebug-types-section.patch
* Mon Apr 20 2020 Tom de Vries <tdevries@suse.com>
- Fix python 3.8 warning [bsc#1169495].
  * gdb-fix-incorrect-use-of-is-operator-for-comparison-in-python-lib-gdb-command-prompt.py.patch
* Tue Apr 14 2020 Tom de Vries <tdevries@suse.com>
- Fix build with gcc 10 [bsc#1169368, swo#25717].
  * bfd-change-num_group-to-unsigned-int.patch
* Tue Feb  4 2020 Tom de Vries <tdevries@suse.com>
- Fix hang after SIGKILL [swo#25478].
  * gdb-threads-fix-hang-in-stop_all_threads-after-killing-inferior.patch
* Fri Jan 17 2020 matz@suse.com
- Add support for official name of s390 arch13: z15.
  Add descriptions for arch13 instructions.  Adds
  gdb-arch13-1.diff, gdb-arch13-2.diff and gdb-arch13-3.diff.
  [jsc#SLE-7903]
* Fri Dec  6 2019 Tom de Vries <tdevries@suse.com>
- Fix build with gcc 10 [bsc#1158539, swo#24653].
  * gdb-0001-remove-alloca-0-calls.patch
* Mon Nov 11 2019 Ludwig Nussel <lnussel@suse.de>
- make fpc optional (boo#1156284) as fpc requires itself for
  bootstrapping.
* Wed Nov  6 2019 Tom de Vries <tdevries@suse.com>
- Fix for bsc#1146475 [bsc#1146475, swo#24971 ]
  * gdb-symtab-prefer-var-def-over-decl.patch
- Fix for bsc#1146167 [bsc#1146167, swo#24956]
  * gdb-only-force-interp_console-ui_out-for-breakpoint-commands-in-mi-mode.patch
* Tue Oct 29 2019 Tom de Vries <tdevries@suse.com>
- Backport 2nd part of fix for swo#23657.
  [bsc#1142772, swo#23657, CVE-2019-1010180]
  * gdb-dwarf-reader-reject-sections-with-invalid-sizes.patch
* Mon Oct 14 2019 matz@suse.com
- Add gdb-s390-handle-arch13.diff to handle most new s390 arch13
  instructions.  [fate#327369, jsc#ECO-368]
* Mon Sep 30 2019 Tom de Vries <tdevries@suse.com>
- Add gdb-testsuite-8.3-kfail-xfail-unsupported.patch
* Thu Sep 26 2019 Tom de Vries <tdevries@suse.com>
- Drop ChangeLog part of patch:
  * gdb-rhbz1708192-parse_macro_definition-crash.patch
  * gdb-rhbz1704406-disable-style-log-output-1of3.patch
  * gdb-rhbz1704406-disable-style-log-output-2of3.patch
  * gdb-rhbz1704406-disable-style-log-output-3of3.patch
  * gdb-rhbz1723564-gdb-crash-PYTHONMALLOC-debug.patch
  * gdb-rhbz1553086-binutils-warning-loadable-section-outside-elf.patch
- Update to gdb-8.3.1.
  * Drop "Testsuite: Ensure pie is disabled on some tests" part of
    gdb-testsuite-pie-no-pie.patch
  * Drop patches included upstream:
  - gdb-7.10-swo18929.patch
  - gdb-handle-vfork-in-thread-with-follow-fork-mode-child.patch
  - gdb-x86_64-i386-syscall-restart-master.patch
  - gdb-suppress-sigttou-when-handling-errors.patch
  - gdb-fix-breakpoints-on-file-reloads-for-pie-binaries.patch
  - gdb-symtab-fix-symbol-loading-performance-regression.patch
- Fix macro in comment warning
* Wed Sep 25 2019 Tom de Vries <tdevries@suse.com>
- Upgrade libipt from v2.0 to v2.0.1.
  * Use -DBUILD_SHARED_LIBS=OFF to build libipt.a, and drop part
    of v1.5-libipt-static.patch that consequentially has become
    unnecessary.
* Tue Sep 24 2019 Tom de Vries <tdevries@suse.com>
- Sync with f30, merging 1e222a3..8bf40c6.
  * gdb-rhbz1708192-parse_macro_definition-crash.patch
  * gdb-rhbz1704406-disable-style-log-output-1of3.patch
  * gdb-rhbz1704406-disable-style-log-output-2of3.patch
  * gdb-rhbz1704406-disable-style-log-output-3of3.patch
  * gdb-rhbz1723564-gdb-crash-PYTHONMALLOC-debug.patch
  * gdb-rhbz1553086-binutils-warning-loadable-section-outside-elf.patch
* Sun Sep 22 2019 Tom de Vries <tdevries@suse.com>
- Use ldd /usr/bin/rpm instead of ls /usr/%%{_lib}/ to find librpm
* Sat Sep 14 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for PowerPC need more than 3.5GB disk space
  to avoid build failure
* Tue Sep 10 2019 matz@suse.com
- Disable use of valgrind on old s390 (31bit) distros.
* Fri Aug 23 2019 Tom de Vries <tdevries@suse.com>
- Enable librpm for version > librpm.so.3 [bsc#1145692]:
  * Allow any librpm.so.x
  * Fix unused variables in HAVE_LIBRPM code in
    gdb-6.6-buildid-locate-rpm-suse.patch
  * Add %%build test to check for "zypper install <rpm-packagename>"
    message
- Implements jsc#ECO-368, the 2019 toolchain module update
* Tue Aug  6 2019 Tom de Vries <tdevries@suse.de>
- Master backport:
  * gdb-fix-breakpoints-on-file-reloads-for-pie-binaries.patch
- Master backports testsuite:
  * gdb-testsuite-i386-pkru-exp.patch
  * gdb-testsuite-read1-fixes.patch
  * gdb-testsuite-pie-no-pie.patch
  * gdb-testsuite-add-missing-initial-prompt-read-in-multidictionary.exp.patch
- Work around bsc#1115034:
  * gdb-testsuite-ada-pie.patch
- Fixes for fedora patches:
  * gdb-testsuite-fix-perror-in-gdb.opt-fortran-string.exp.patch
  * gdb-testsuite-avoid-pagination-in-attach-32.exp.patch
* Thu Jul 25 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove some conditionals for SLE-10 (build is disabled/unresolvable).
- BuildRequire makeinfo instead of full texinfo (requiring texlive)
  where available (SLE >= 12).
* Mon Jul 22 2019 Tom de Vries <tdevries@suse.de>
- Add Wno-error=odr to work around swo#24835
- Add BuildRequires xz-devel
* Wed Jul  3 2019 Tom de Vries <tdevries@suse.de>
- Add BuildRequires valgrind for make check
* Wed Jul  3 2019 Tom de Vries <tdevries@suse.de>
- Move BuildRequires gcc-go and fpc to %%{with testsuite} portion
* Wed Jul  3 2019 Tom de Vries <tdevries@suse.de>
- Copy %%ada_arch from gcc9 and use it to fix 'unresolvable: nothing
  provides gcc-ada' for openSUSE_Leap_42.3_Ports/SLE-12 ppc64le.
* Wed Jul  3 2019 Tom de Vries <tdevries@suse.de>
- Drop ppc64le for fpc
* Wed Jul  3 2019 Tom de Vries <tdevries@suse.de>
- Add missing %%endif
* Wed Jul  3 2019 Tom de Vries <tdevries@suse.de>
- Add BuildRequire fpc for make check
* Wed Jul  3 2019 Tom de Vries <tdevries@suse.de>
- Add comment explaining why guile support has been disabled for
  newer distro versions.
* Tue Jul  2 2019 Tom de Vries <tdevries@suse.de>
- Add BuildRequire gcc-go to get gccgo command for make check
* Tue Jul  2 2019 Tom de Vries <tdevries@suse.de>
- Copy gdbinit from fedora master @ 25caf28.  Add
  gdbinit.without-python, and use it for --without=python.
* Mon Jul  1 2019 Tom de Vries <tdevries@suse.de>
- Remove unused code: gdbtui support
* Mon Jun 24 2019 Tom de Vries <tdevries@suse.de>
- Add comments to "patches to upstream" specifying when they can be
  dropped.
* Thu Jun 20 2019 Tom de Vries <tdevries@suse.de>
- Remove -Wno-implicit-fallthrough, -Wno-error=cast-function-type
  and -Wno-error=stringop-truncation
* Wed Jun 19 2019 Tom de Vries <tdevries@suse.de>
- Remove gdb-fix-buf-overflow.diff, which is a workaround for
  swo#24698, which has been fixed since gdb 7.12.
* Fri Jun 14 2019 Tom de Vries <tdevries@suse.de>
- Fix rpmlint macro-in-comment errors
* Fri Jun 14 2019 Tom de Vries <tdevries@suse.de>
- Fix rpmlint error "deprecated-grep ['egrep']" .
* Fri Jun 14 2019 Tom de Vries <tdevries@suse.de>
- gdb-gcore-bash.patch: Fix rpmlint error env-script-interpreter by
  replacing "/usr/bin/env bash" with "/bin/bash" in gcore.
* Thu Jun 13 2019 Tom de Vries <tdevries@suse.de>
- Rewrite gdbserver.1 workaround for riscv64 to avoid
  %%define _unpackaged_files_terminate_build 0
* Wed Jun  5 2019 Andreas Schwab <schwab@suse.de>
- gdb-suppress-sigttou-when-handling-errors.patch: Suppress SIGTTOU when
  handling errors
- Enable ada tests on ppc64le and riscv64
- Enable multitarget build on riscv64
- Add ia64 and riscv64 to target_list
- Enable -Werror on riscv64 and aarch64
- Don't remove %%{buildroot}
* Wed May 22 2019 Tom de Vries <tdevries@suse.de>
- Remove gdb-gcc9-fix-build-with-latest-GCC-9.0-tree.patch and
  gdb-gcc9-warning-on-elf32-arm.c-elf32_arm_final_link.patch, which are
  already present in 8.3.
* Wed May 22 2019 Martin Liška <mliska@suse.cz>
- Add gdb-gcc9-fix-build-with-latest-GCC-9.0-tree.patch and
  gdb-gcc9-warning-on-elf32-arm.c-elf32_arm_final_link.patch
  in order to fix build with GCC9.
* Tue May 21 2019 Tom de Vries <tdevries@suse.de>
- Replace fedora patch gdb-x86_64-i386-syscall-restart.patch with
  master backport gdb-x86_64-i386-syscall-restart-master.patch
* Fri May 17 2019 Tom de Vries <tdevries@suse.de>
- Work around riscv64 build error: gdbserver.1 is installed, but not
  packaged
* Thu May 16 2019 Tom de Vries <tdevries@suse.de>
- Don't expect gdbserver for riscv64
* Thu May 16 2019 Tom de Vries <tdevries@suse.de>
- Add gdb-fix-riscv-tdep.patch to fix RISC-V build breaker
* Thu May 16 2019 Tom de Vries <tdevries@suse.de>
- Rebase to 8.3 release (as in fedora 30 @ 1e222a3).
  * DWARF index cache: GDB can now automatically save indices of DWARF
    symbols on disk to speed up further loading of the same binaries.
  * Ada task switching is now supported on aarch64-elf targets when
    debugging a program using the Ravenscar Profile.
  * Terminal styling is now available for the CLI and the TUI.
  * Removed support for old demangling styles arm, edg, gnu, hp and
    lucid.
  * Support for new native configuration RISC-V GNU/Linux (riscv*-*-linux*).
- Obsoleted fedora patches dropped:
  * gdb-6.3-ppc64syscall-20040622.patch
  * gdb-6.3-ppc64displaysymbol-20041124.patch
  * gdb-6.3-readnever-20050907.patch
  * gdb-6.5-bz203661-emit-relocs.patch
  * gdb-6.8-sparc64-silence-memcpy-check.patch
  * gdb-6.8-watchpoint-conditionals-test.patch
  * gdb-7.2.50-sparc-add-workaround-to-broken-debug-files.patch
  * gdb-python-gil.patch
  * gdb-rhbz881849-ipv6-1of3.patch
  * gdb-rhbz881849-ipv6-2of3.patch
  * gdb-rhbz881849-ipv6-3of3.patch
  * gdb-rhbz1187581-power8-regs-1of7.patch
  * gdb-rhbz1187581-power8-regs-2of7.patch
  * gdb-rhbz1187581-power8-regs-3of7.patch
  * gdb-rhbz1187581-power8-regs-4of7.patch
  * gdb-rhbz1187581-power8-regs-5of7.patch
  * gdb-rhbz1187581-power8-regs-6of7.patch
  * gdb-rhbz1187581-power8-regs-7of7.patch
  * gdb-rhbz1491128-batch-mode-exit-status-1of2.patch
  * gdb-rhbz1491128-batch-mode-exit-status-2of2.patch
  * gdb-use-pulongest-aarch64-linux-tdep.patch
  * gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-1of5.patch
  * gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-2of5.patch
  * gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-3of5.patch
  * gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-4of5.patch
  * gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-5of5.patch
- Fedora patches added:
  * gdb-rhbz795424-bitpos-arrayview.patch
  * gdb-rhbz1371380-gcore-elf-headers.patch
- Obsoleted patched dropped:
  * gdb-fix-crash-when-reading-core.patch
  * power8-registers.diff
  * gdb-fix-multidictionary.exp-for-gdb-8.2.patch
- Backport from master:
  * gdb-handle-vfork-in-thread-with-follow-fork-mode-child.patch
    [swo#gdb/24454]
- Added patches proposed for master:
  * gdb-fix-heap-use-after-free-in-typename-concat.patch
    [swo#24094]
  * gdb-symtab-fix-symbol-loading-performance-regression.patch
    [swo#24545]
* Wed May 15 2019 Tom de Vries <tdevries@suse.de>
- Add BuildRequires mpfr-devel
* Thu Jan 24 2019 tdevries@suse.com
- Backport upstream fix for assertion failure
  `SYMBOL_LANGUAGE (sym) == DICT_LANGUAGE (dict)->la_language'
  [swo#23712, rh#1560010]
  patches:
  gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-1of5.patch
  gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-2of5.patch
  gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-3of5.patch
  gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-4of5.patch
  gdb-rhbz1560010-fix-assertion-symbol-language-dict-language-5of5.patch
  * Add patches from fedora 29 @ 4513f72
  * Add gdb-fix-multidictionary.exp-for-gdb-8.2.patch to fix
  multidictionary.exp test-case
* Thu Dec  6 2018 matz@suse.com
- Add power8-registers.diff for implementing access to
  more POWER8 registers.  [fate#326120, fate#325178]
* Mon Nov 12 2018 tdevries@suse.com
- Run tests with -fno-PIE/-no-pie and -fPIE/-pie.
* Wed Nov  7 2018 tdevries@suse.com
- Fix crash when reading core [bsc #1109013]
  * Add gdb-fix-crash-when-reading-core.patch
    https://sourceware.org/ml/gdb-cvs/2018-11/msg00022.html
* Tue Sep 11 2018 matz@suse.com
- Rebase to 8.2 release (as in fedora 29 @ c720d998):
  * Contains fix for bnc#1081527, CVE-2018-7208.
  * 'symbol-file' and 'add-symbol-file' accept -o to add relative
    offset to all sections
  * pager accepts 'c' response to disable it for rest of command
  * accept _Alignof and alignof in C resp. C++ expressions
  * new target riscv*-*-elf
  * python API extensions: gdb.Type.align, gdb.execute deals
    with multi-line gdb commands, gdb.convenience_variable and
    gdb.set_convenience_variable to access convenience variables,
  * aarch64: properly support hardware watchpoints on unaligned
    addresses (needs kernel >= 4.10)
- Add gdb-fix-s390-build.diff for a Wformat error on s390.
- Support access to new POWER8 registers [fate#325178, fate#326120]
  Add patches gdb-rhbz1187581-power8-regs-1of7.patch,
  gdb-rhbz1187581-power8-regs-2of7.patch,
  gdb-rhbz1187581-power8-regs-3of7.patch,
  gdb-rhbz1187581-power8-regs-4of7.patch,
  gdb-rhbz1187581-power8-regs-5of7.patch,
  gdb-rhbz1187581-power8-regs-6of7.patch,
  gdb-rhbz1187581-power8-regs-7of7.patch .
- Support ipv6 for gdbserver connections:
  Add patches gdb-rhbz881849-ipv6-1of3.patch,
  gdb-rhbz881849-ipv6-2of3.patch,
  gdb-rhbz881849-ipv6-3of3.patch .
- Update to intel processor trace library 2.0 (from 1.6.1):
  Add v2.0.tar.gz, remove v1.6.1.tar.gz
  Remove obsolete v1.6.1-implicit-fallthrough.patch .
- Remove obsolete patches:
  gdb-fix-python37-breakage.patch,
  gdb-pahole-python2.patch .
- Added patches from Fedora:
  gdb-rhbz1491128-batch-mode-exit-status-1of2.patch,
  gdb-rhbz1491128-batch-mode-exit-status-2of2.patch,
  gdb-rhbz1553104-s390x-arch12-test.patch,
  gdb-use-pulongest-aarch64-linux-tdep.patch .
- Removed obsolete patches from Fedora:
  gdb-6.6-bz235197-fork-detach-info.patch,
  gdb-6.8-attach-signalled-detach-stopped.patch,
  gdb-gdb-add-index-script.patch,
  gdb-ppc64-stwux-tautological-compare.patch,
  gdb-rhbz1540559-gdbaddindex-glibcdebug-regression.patch,
  gdb-stale-frame_info.patch .
- Most other patches rebased.
* Fri Aug 10 2018 tchvatal@suse.com
- Apply patch from fedora to build with python3.7:
  * gdb-fix-python37-breakage.patch
* Tue Mar 27 2018 matz@suse.com
- Add some -Wno-error flags for gcc-8 compatibility.
* Fri Mar  9 2018 matz@suse.com
- Rebase to 8.1 release:
  * Contains fix for bnc#1068950, CVE-2017-16829.
  * ptype/o prints offsets and sizes of members (like pahole)
  * tab-completion improved: quoting function names is not generally
    necessary anymore, completion offers for breakpoint don't include
    data symbol
  * enable/disable breakpoints now accept ranges: 'disable 1.3-5'
  * new commands:
  - set/show cwd: working directory of debuggee
  - set/show compile-gcc: program to use for 'compile' command
  - starti: start program and stop at first instruction
  - TUI single-key commands: 'i' for stepi and 'o' for nexti
  * --readnever option disables any reading of debug info (for dumping)
  * s390: guarded storage register access for z14
  * gcore option -a dumps all memory mapping
  * C++ breakpoints: 'b foo' will now set a breakpoint on all functions
    and methods named 'foo' no matter the scope.  Use -qualified if you
    don't want that
  * python scripting: new events gdb.new_inferior, gdb.inferior_deleted
    and gdb.new_thread; new command rbreak (breakpoint accepting regexps)
  * gdbserver can be passed environment parameters to remote debuggee
- Added patches from Fedora:
  gdb-ppc64-stwux-tautological-compare.patch
  gdb-rhbz1540559-gdbaddindex-glibcdebug-regression.patch
  gdb-vla-intel-fix-print-char-array.patch
- Removed unused gdb-libstdc++-v3-python-7.1.1-20170526.tar.bz2
- Removed obsolete upstream patches:
  gdb-s390x-1b63490.patch
  gdb-s390x-289e23a.patch
  gdb-s390x-8fe09d7.patch
  gdb-s390x-96235dc.patch
  gdb-s390x-ad33963.patch
- Removed obsolete Fedora patches:
  gdb-6.3-rh-dummykfail-20041202.patch
  gdb-6.6-threads-static-test.patch
  gdb-add-index-chmod.patch
  gdb-glibc-vdso-workaround.patch
  gdb-rhbz1420304-s390x-01of35.patch
  gdb-rhbz1420304-s390x-02of35.patch
  gdb-rhbz1420304-s390x-03of35.patch
  gdb-rhbz1420304-s390x-04of35.patch
  gdb-rhbz1420304-s390x-05of35.patch
  gdb-rhbz1420304-s390x-06of35.patch
  gdb-rhbz1420304-s390x-07of35.patch
  gdb-rhbz1420304-s390x-08of35.patch
  gdb-rhbz1420304-s390x-09of35.patch
  gdb-rhbz1420304-s390x-10of35.patch
  gdb-rhbz1420304-s390x-11of35.patch
  gdb-rhbz1420304-s390x-12of35.patch
  gdb-rhbz1420304-s390x-13of35.patch
  gdb-rhbz1420304-s390x-14of35.patch
  gdb-rhbz1420304-s390x-15of35.patch
  gdb-rhbz1420304-s390x-16of35.patch
  gdb-rhbz1420304-s390x-17of35.patch
  gdb-rhbz1420304-s390x-18of35.patch
  gdb-rhbz1420304-s390x-19of35.patch
  gdb-rhbz1420304-s390x-20of35.patch
  gdb-rhbz1420304-s390x-21of35.patch
  gdb-rhbz1420304-s390x-22of35.patch
  gdb-rhbz1420304-s390x-23of35.patch
  gdb-rhbz1420304-s390x-24of35.patch
  gdb-rhbz1420304-s390x-25of35.patch
  gdb-rhbz1420304-s390x-26of35.patch
  gdb-rhbz1420304-s390x-27of35.patch
  gdb-rhbz1420304-s390x-28of35.patch
  gdb-rhbz1420304-s390x-29of35.patch
  gdb-rhbz1420304-s390x-30of35.patch
  gdb-rhbz1420304-s390x-31of35.patch
  gdb-rhbz1420304-s390x-32of35.patch
  gdb-rhbz1420304-s390x-33of35.patch
  gdb-rhbz1420304-s390x-34of35.patch
  gdb-rhbz1420304-s390x-35of35.patch
  gdb-tls-1of2.patch
  gdb-tls-2of2.patch
  gdb-upstream.patch
* Wed Nov 15 2017 schwab@suse.de
- Support --without=testsuite and disable testsuite for qemu-linux-user
  builds
* Wed Oct 25 2017 jmatejek@suse.com
- switch to Python 3 for Tumbleweed 1320 and up
* Mon Oct  9 2017 matz@suse.com
- Remove %%clean section.
* Wed Oct  4 2017 matz@suse.com
- Link gdb against a bundled libipt (processor trace
  library) on x86_64 and i686 for improved tracing support
  on Intel CPUs.  [bnc#985550]
  Adds v1.6.1.tar.gz and patches
  v1.5-libipt-static.patch and v1.6.1-implicit-fallthrough.patch.
* Mon Oct  2 2017 matz@suse.com
- Rebase to 8.0.1 release (fixing PR21886, PR22046)
- Updated libstdc++ pretty printers to
- Replace gdb-libstdc++-v3-python-6.3.1-20170212.tar.bz2 with
  gdb-libstdc++-v3-python-7.1.1-20170526.tar.bz2 .
- Add patches for s390x z14 feates [fate #321514, fate #322272]
  gdb-s390x-1b63490.patch
  gdb-s390x-289e23a.patch
  gdb-s390x-8fe09d7.patch
  gdb-s390x-96235dc.patch
  gdb-s390x-ad33963.patch
- Adjust some patches:
  gdb-ppc-power7-test.patch
  gdb-rhbz795424-bitpos-20of25.patch
  gdb-rhbz795424-bitpos-21of25.patch
  gdb-vla-intel-fortran-vla-strings.patch
- Add some patches from Fedora:
  gdb-rhbz1420304-s390x-01of35.patch
  gdb-rhbz1420304-s390x-02of35.patch
  gdb-rhbz1420304-s390x-03of35.patch
  gdb-rhbz1420304-s390x-04of35.patch
  gdb-rhbz1420304-s390x-05of35.patch
  gdb-rhbz1420304-s390x-06of35.patch
  gdb-rhbz1420304-s390x-07of35.patch
  gdb-rhbz1420304-s390x-08of35.patch
  gdb-rhbz1420304-s390x-09of35.patch
  gdb-rhbz1420304-s390x-10of35.patch
  gdb-rhbz1420304-s390x-11of35.patch
  gdb-rhbz1420304-s390x-12of35.patch
  gdb-rhbz1420304-s390x-13of35.patch
  gdb-rhbz1420304-s390x-14of35.patch
  gdb-rhbz1420304-s390x-15of35.patch
  gdb-rhbz1420304-s390x-16of35.patch
  gdb-rhbz1420304-s390x-17of35.patch
  gdb-rhbz1420304-s390x-18of35.patch
  gdb-rhbz1420304-s390x-19of35.patch
  gdb-rhbz1420304-s390x-20of35.patch
  gdb-rhbz1420304-s390x-21of35.patch
  gdb-rhbz1420304-s390x-22of35.patch
  gdb-rhbz1420304-s390x-23of35.patch
  gdb-rhbz1420304-s390x-24of35.patch
  gdb-rhbz1420304-s390x-25of35.patch
  gdb-rhbz1420304-s390x-26of35.patch
  gdb-rhbz1420304-s390x-27of35.patch
  gdb-rhbz1420304-s390x-28of35.patch
  gdb-rhbz1420304-s390x-29of35.patch
  gdb-rhbz1420304-s390x-30of35.patch
  gdb-rhbz1420304-s390x-31of35.patch
  gdb-rhbz1420304-s390x-32of35.patch
  gdb-rhbz1420304-s390x-33of35.patch
  gdb-rhbz1420304-s390x-34of35.patch
  gdb-rhbz1420304-s390x-35of35.patch
  gdb-upstream.patch
* Wed Sep 13 2017 matz@suse.com
- Disable guile extensions for new distros, the gdb support
  is incompatible with guile 2.2.
* Tue Jun  6 2017 matz@suse.com
- Rebase to gdb 8.0 release: [fate #319573]
  * support for DWARF5 (except its .debug_names)
  * support C++11 rvalue references
  * support PKU register (memory protection keys on future Intel CPUs)
  * python scripting:
  - start, stop and access running btrace
  - rvalue references in gdb.Type
  * record/replay x86_64 rdrand and rdseed
  * removed support for GCJ compiled java programs
  * user commands accept more than 10 arguments
  * "eval" expands user-defined command arguments
  * new options:
    set/show disassembler-options (on arm, ppc s390)
- Removed obsoleted patches:
  gdb-release-werror.patch
* Thu Apr 27 2017 matz@suse.com
- Rebase to gdb 7.99.90 (prerelease of gdb 8) [fate #319573]
- Updated libstdc++ pretty printers to
  gdb-libstdc++-v3-python-6.3.1-20170212.tar.bz2.
- Added patches from fedora:
  gdb-release-werror.patch
  gdb-rhbz1398387-tab-crash-test.patch
- Removed obsoleted patches:
  gdb-6.7-bz426600-DW_TAG_interface_type-test.patch
  gdb-bison-old.patch
  gdb-testsuite-casts.patch
  gdb-testsuite-m-static.patch
  gdb-upstream.patch
  gdb-testsuite-morestack-gold.patch
  gdb-fix-bnc-994537.diff
  gdb-libiberty-demangler-fuzz.diff
* Mon Apr  3 2017 rguenther@suse.com
- Fix rpm condition to allow build on SLE10.
- Do not require glibc-devel-static-32bit on SLE12 which is not available
  there.
* Wed Feb 15 2017 matz@suse.com
- Update to gdb 7.12.1
  * negative repeat count for x examines backwards
  * fortran: support structs/arrays with dynamically types fields
  * support MPX bound checking
  * support for the Rust language
  * 'catch syscall' now can catch groups of related syscalls
  * New (sub)commands:
  - skip {-file,-gfile,-function,-rfunction}: generic skip
    mechanism
  - maint {selftest,info line-table}
  - new-ui: create new user interface for GUI clients
  * (fast) tracepoints on s390x and ppc64le added to gdbserver
  * New target Andes NDS32
- Add rpmlint exception for historic libinproctrace place
- Remove obsolete patches:
  gdb-aarch64-v81-hwbreakpoints.diff
  gdb-bare-DW_TAG_lexical_block-1of2.patch
  gdb-bare-DW_TAG_lexical_block-2of2.patch
  gdb-fortran-stride-intel-1of6.patch
  gdb-fortran-stride-intel-2of6.patch
  gdb-fortran-stride-intel-3of6.patch
  gdb-fortran-stride-intel-4of6.patch
  gdb-fortran-stride-intel-5of6.patch
  gdb-fortran-stride-intel-6of6-nokfail.patch
  gdb-fortran-stride-intel-6of6.patch
  gdb-testsuite-dw2-undefined-ret-addr.patch
  gdb-vla-intel-04of23-fix.patch
  gdb-vla-intel-logical-not.patch
  gdb-vla-intel.patch
- Add patches from Fedora package:
  gdb-6.7-testsuite-stable-results.patch
  gdb-add-index-chmod.patch
  gdb-bison-old.patch
  gdb-container-rh-pkg.patch
  gdb-libexec-add-index.patch
  gdb-linux_perf-bundle.patch
  gdb-physname-pr11734-test.patch
  gdb-physname-pr12273-test.patch
  gdb-rhbz1007614-memleak-infpy_read_memory-test.patch
  gdb-rhbz1084404-ppc64-s390x-wrong-prologue-skip-O2-g-3of3.patch
  gdb-rhbz1149205-catch-syscall-after-fork-test.patch
  gdb-rhbz1156192-recursive-dlopen-test.patch
  gdb-rhbz1186476-internal-error-unqualified-name-re-set-test.patch
  gdb-rhbz1350436-type-printers-error.patch
  gdb-test-ivy-bridge.patch
  gdb-testsuite-casts.patch
  gdb-testsuite-m-static.patch
  gdb-testsuite-morestack-gold.patch
  gdb-tls-1of2.patch
  gdb-tls-2of2.patch
  gdb-upstream.patch
  gdb-vla-intel-fortran-strides.patch
  gdb-vla-intel-fortran-vla-strings.patch
  gdb-vla-intel-tests.patch
* Mon Jan  9 2017 matz@suse.com
- Disable 32bit testing on openSUSE s390x.
* Fri Dec 16 2016 mliska@suse.cz
- Make dependency of gcc-java conditional.
* Sat Dec  3 2016 schwab@suse.de
- Enable ada testing on aarch64 for tumbleweed
* Mon Nov 21 2016 schwab@suse.de
- BuildRequire glibc-devel-static for 12.1 or later, and
  glibc-devel-static-32bit if biarch
* Thu Aug 25 2016 matz@suse.com
- Add gdb-fix-bnc-994537.diff for ppc64le, fixing
  two testcases.  [bnc#994537]
- Add gdb-libiberty-demangler-fuzz.diff for fixing infinite
  recursion in demangler.  [bnc#987637]
* Mon Aug  8 2016 matz@suse.com
- Amend gdb-glibc-vdso-workaround.patch to ignore further
  vdso filenames on ppc64 and s390x.  [bnc#944105]
* Wed Aug  3 2016 matz@suse.com
- Add gdb-aarch64-v81-hwbreakpoints.diff for detecting
  debug capabilities on ARMv8.1/8.2.  [bnc#990697]
* Mon Jun 20 2016 matz@suse.com
- Rebase to gdb 7.11.1: minor bug fixes.
- Remove gdb-gcc6-Wparentheses-warning.patch (applied upstream).
- Add some patches from Fedora F24:
  gdb-bare-DW_TAG_lexical_block-1of2.patch
  gdb-bare-DW_TAG_lexical_block-2of2.patch
  gdb-bz1219747-attach-kills.patch
  gdb-rhbz1261564-aarch64-hw-watchpoint-test.patch
  gdb-rhbz1325795-framefilters-test.patch
  gdb-testsuite-dw2-undefined-ret-addr.patch
* Tue May 24 2016 martin.liska@suse.com
- Add gdb-gcc6-Wparentheses-warning.patch to fix Werrors reported by GCC6.
* Mon Apr 25 2016 rguenther@suse.com
  [diverging changelog entry from SLE tree vs devel:gcc tree:
- Add gdb-7.9-bnc976404.patch to fix thread support on s390x. [bnc #976404]
  [bnc #970589]
- Add gdb-7.9-swo18929.patch to fix crash printing values.  [bnc#971556]
  ]
- Removed gdb-7.9-bnc976404.patch when updating to devel:gcc tree.
- Replaced gdb-7.9-swo18929.patch with gdb-7.10-swo18929.patch as well.
* Thu Apr  7 2016 normand@linux.vnet.ibm.com
-  update gdb-orphanripper.c from last fedora changes of 2013
  http://pkgs.fedoraproject.org/cgit/rpms/gdb.git/log/gdb-orphanripper.c
  may be solution to transient build hung on Rings:1 ppc64le
  tracked by bug boo#974419
* Mon Mar 21 2016 rguenther@suse.com
- Add gdb-7.10-swo18929.patch to fix crash printing values.  [bnc#971556]
  [swo#18929]
* Mon Feb 29 2016 matz@suse.de
- Rebase to gdb version 7.11 as of version in Fedora 24:
  * Per-inferior thread numbers.
  * Breakpoint "explicit locations" (via CLI and GDB/MI).
  * New convenience variables ($_gthread, $_inferior).
  * Record btrace now supports non-stop mode.
  * Various improvements on AArch64 GNU/Linux:
  - Multi-architecture debugging support.
  - displaced stepping.
  - tracepoint support added in GDBserver.
  * In Ada, the overloads selection menu provides the parameter
    types and return types for the matching overloaded subprograms.
  * Various remote protocol improvements, including several
    new packets which can be used to support features such as
    follow-exec-mode, exec catchpoints, syscall catchpoints, etc.
  * Some minor improvements in the Python API for extending GDB.
- Added local patch gdb-fix-buf-overflow.diff.
- Added new patches from Fedora:
    gdb-fedora-libncursesw.patch
    gdb-fortran-stride-intel-1of6.patch
    gdb-fortran-stride-intel-2of6.patch
    gdb-fortran-stride-intel-3of6.patch
    gdb-fortran-stride-intel-4of6.patch
    gdb-fortran-stride-intel-5of6.patch
    gdb-fortran-stride-intel-6of6-nokfail.patch
    gdb-fortran-stride-intel-6of6.patch
    gdb-opcodes-clflushopt-test.patch
    gdb-testsuite-readline63-sigint.patch
- Removed obsolete patches:
    gdb-6.3-bz231832-obstack-2gb.patch
    gdb-probes-based-interface-robust-1of2.patch
    gdb-probes-based-interface-robust-2of2.patch
    gdb-rhbz1260558-ppc64le-skip_trampoline_code.patch
    gdb-rhbz1270564-invalid-dwarf-regno.patch
    gdb-rhel5-compat.patch
- Really disable problematic testcases.
* Mon Jan 18 2016 matz@suse.de
- Disable guile support for SLE10.
* Thu Jan 14 2016 matz@suse.de
- Rebase to gdb version 7.10.1 as of version in Fedora 23:
  * reverse debugging on aarch64
  * new commands or subcommands:
  - info os cpu, set/show serial parity, info dll
  - maint print symbol-cache/symbol-cache-statistics,
    maint flush-symbol-cache
  - record btrace bts, record bts
  - compile print
  - show/set mpx bound
  - tui enable/disable
  - record btrace pt, record pt
  - maint info btrace,
    maint btrace packet-history/clear-packet-history/clear
  * s390 support for vector ABI
  * "set sysroot" improvements related to remote targets
  * better support for debugging containerized programs
    (without "set sysroot")
  * HISTSIZE environment variable is replaced by GDBHISTSIZE
  * python scripting:
  - it's possible to write frame unwinders
  - several new methods in Objfile, Type and Value classes
  - gdb can auto-load scripts contained in special sections
    named '.debug_gdb_scripts'.
  * extensions for the MI interface, new remote packet types
- Removed obsolete patches:
    0001-S390-Add-target-descriptions-for-vector-register-set.patch
    0001-S390-Fix-compiler-invocation-with-compile-command.patch
    0001-S390-Support-new-vector-register-sections.patch
    0002-S390-Add-vector-register-support-to-gdb.patch
    0003-S390-Add-vector-register-support-to-gdbserver.patch
    0004-S390-Vector-register-test-case.patch
    0005-S390-Name-invisible-registers-with-the-empty-string-.patch
    gdb-6.5-bz190810-gdbserver-arch-advice.patch
    gdb-6.6-scheduler_locking-step-sw-watchpoints2.patch
    gdb-6.8-bz457187-largefile-test.patch
    gdb-enable-count-crash.patch
    gdb-libstdc++-v3-python-r155978.tar.bz2
    gdb-no-dg-extract-results-py.patch
    gdb-python3-py_hash_t-32bit.patch
    gdb-python3-testsuite.patch
    gdb-s390-reorder-arch.diff
    gdb-upstream.patch
- Added new patches from Fedora:
    gdb-pahole-python2.patch
    gdb-probes-based-interface-robust-1of2.patch
    gdb-probes-based-interface-robust-2of2.patch
    gdb-rhbz1260558-ppc64le-skip_trampoline_code.patch
    gdb-rhbz1270564-invalid-dwarf-regno.patch
* Fri Aug 14 2015 matz@suse.de
- Add missing patches from binutils for z13 support. [bnc #936050]
* Fri Jul 10 2015 matz@suse.de
- Rebase to gdb version 7.9.1:
  fixes PR python/18299, python/18285.
- Add gdb-s390-reorder-arch.diff [bnc #936050]
- Added patches for fate#318039, s390 z13 support:
  0001-S390-Fix-compiler-invocation-with-compile-command.patch
  0001-S390-Support-new-vector-register-sections.patch
  0001-S390-Add-target-descriptions-for-vector-register-set.patch
  0002-S390-Add-vector-register-support-to-gdb.patch
  0003-S390-Add-vector-register-support-to-gdbserver.patch
  0004-S390-Vector-register-test-case.patch
  0005-S390-Name-invisible-registers-with-the-empty-string-.patch
- Remove now obsolete SLE12-only patches:
  gdb-7.7-bnc896586.patch, gdb-7.7-bnc895831.patch,
  gdb-7.7-bnc891040-1.patch, gdb-7.7-bnc891040-2.patch,
  gdb-7.7-bnc891040-3.patch, gdb-7.7-bnc891040-4.patch,
  gdb-7.7-bnc891040-5.patch
* Thu Jul  2 2015 rguenther@suse.com
- Remove auto-loading non-existent /etc/gdbinit.d/gdb-heap.py
  from /etc/gdbinit
* Mon Jun 29 2015 schwab@suse.de
- Add guile-devel to enable Scheme scripting support
- Run ada tests also on ppc64 and s390
* Tue Mar  3 2015 schwab@suse.de
- Build multi-target also on aarch64
* Fri Feb 27 2015 rguenther@suse.com
- Strip date and runtimes from gdb-testsuite contents.
* Wed Feb 25 2015 rguenther@suse.com
- Use patchlist.pl to merge with gdb-7.9-10.fc22, a rebase to FSF GDB 7.9.
  The GDB 7.8 features are:
  * Python Scripting
  - You can now access frame registers from Python scripts.
  - New attribute 'producer' for gdb.Symtab objects.
  * New Python-based convenience functions:
  - $_caller_is(name [, number_of_frames])
  - $_caller_matches(regexp [, number_of_frames])
  - $_any_caller_is(name [, number_of_frames])
  - $_any_caller_matches(regexp [, number_of_frames])
  * New commands
  - queue-signal signal-name-or-number
    Queue a signal to be delivered to the thread when it is resumed.
  * On resume, GDB now always passes the signal the program had stopped
    for to the thread the signal was sent to, even if the user changed
    threads before resuming.  Previously GDB would often (but not
    always) deliver the signal to the thread that happens to be current
    at resume time.
  * Conversely, the "signal" command now consistently delivers the
    requested signal to the current thread.  GDB now asks for
    confirmation if the program had stopped for a signal and the user
    switched threads meanwhile.
  * "breakpoint always-inserted" modes "off" and "auto" merged.
    Now, when 'breakpoint always-inserted mode' is set to "off", GDB
    won't remove breakpoints from the target until all threads stop,
    even in non-stop mode.  The "auto" mode has been removed, and "off"
    is now the default mode.
  * MI changes
  - The -list-thread-groups command outputs an exit-code field for
    inferiors that have exited.
- removed (upstream) gdb-async-stopped-on-pid-arg-1of2.patch,
  gdb-async-stopped-on-pid-arg-testsuite.patch,
  gdb-python-completer-1of2.patch, gdb-python-completer-2of2.patch
  and gdb-readline-6.3.5.patch
- added gdb-jit-reader-multilib.patch, gdb-no-dg-extract-results-py.patch,
  gdb-python-gil.patch, gdb-python3-py_hash_t-32bit.patch,
  gdb-python3-testsuite.patch and gdb-vla-intel-logical-not.patch
* Mon Dec 15 2014 cshorler@googlemail.com
- Update for GDB 7.8.1
  * removed (already in upstream):
    gdb-babeltrace-configure.patch
    gdb-async-stopped-on-pid-arg-2of2.patch
  * amended (partially in upstream):
    gdb-archer.patch
    gdb-attach-fail-reasons-5of5.patch
    gdb-async-stopped-on-pid-arg-1of2.patch
    gdb-async-stopped-on-pid-arg-testsuite.patch
* Fri Oct 10 2014 hrvoje.senjan@gmail.com
- Added gdb-async-stopped-on-pid-arg-1of2.patch,
  gdb-async-stopped-on-pid-arg-2of2.patch and
  gdb-async-stopped-on-pid-arg-testsuite.patch to resolve
  https://sourceware.org/bugzilla/show_bug.cgi?id=17347
* Wed Aug 13 2014 rguenther@suse.com
- Enable running the testsuite and store results in a gdb-testresults
  package.
- Add gdb-rpmlintrc to filter errors about the buildroot mentioned
  in testresult logs.
* Fri Aug  8 2014 rguenther@suse.com
- Use patchlist.pl to merge with gdb-7.8-16.fc22, a rebase to FSF GDB 7.8.
  The GDB 7.8 features are:
  * Guile scripting support.
  * Python scripting enhancements.
  * New commands:
  * * guile
  * * guile-repl
  * * info auto-load guile-scripts [REGEXP]
  * New options:
  * * maint ada set ignore-descriptive-types (on|off)
  * * maint set target-async (on|off)
  * * set|show auto-load guile-scripts (on|off)
  * * set|show auto-connect-native-target
  * * set|show guile print-stack (none|message|full)
  * * set|show mi-async (on|off)
  * * set|show print symbol-loading (off|brief|full)
  * * set|show record btrace replay-memory-access (read-only|read-write)
  * Remote Protocol:
  * * The qXfer:btrace:read packet supports a new annex 'delta'.
  * GDB/MI:
  * * A new option "-gdb-set mi-async" replaces "-gdb-set target-async".
  * New target configurations:
  * * PowerPC64 GNU/Linux little-endian
  * btrace enhancements:
  * * The btrace record target now supports the 'record goto' command.
  * * The btrace record target supports limited reverse execution and
    replay.
  * ISO C99 variable length automatic arrays support.
  * It is no longer required to "set target-async on" in order to use
    background execution commands (e.g., "c&", "s&", etc.).
  * "catch syscall" now implemented on s390*-linux* targets.
  * The "compare-sections" command now works on all targets.
  * The "target native" command now connects to the native target, and
    can be used to launch native programs, even if "set
    auto-connect-native-target" is set to off.
  * More robust backtraces.  [bnc#891040]
- Obsoletes patch gdb-7.7-bnc877566.patch
- Obsoletes patch gdb-fix-s390-build.patch
- Obsoletes patch gdb-ppc64le.patch
- Drop gdb-ia64-tdep.patch, disable building the IA64 target
- Modifies gdb-6.3-test-pie-20050107.patch,
  gdb-6.5-bz218379-solib-trampoline-lookup-lock-fix.patch,
  gdb-6.6-buildid-locate-core-as-arg.patch,
  gdb-6.6-buildid-locate-rpm.patch, gdb-6.6-buildid-locate.patch,
  gdb-6.6-scheduler_locking-step-is-default.patch,
  gdb-6.6-scheduler_locking-step-sw-watchpoints2.patch,
  gdb-6.8-attach-signalled-detach-stopped.patch,
  gdb-6.8-quit-never-aborts.patch,
  gdb-archer-pie-addons-keep-disabled.patch, gdb-archer-pie-addons.patch,
  gdb-archer.patch, gdb-attach-fail-reasons-5of5.patch,
  gdb-glibc-strstr-workaround.patch, gdb-rhbz795424-bitpos-20of25.patch,
  gdb-rhbz795424-bitpos-21of25.patch, gdb-rhbz795424-bitpos-22of25.patch,
  gdb-rhbz795424-bitpos-23of25.patch, gdb-rhbz795424-bitpos-25of25.patch,
  gdb-upstream.patch
- Adds gdb-archer-vla-tests.patch, gdb-bz533176-fortran-omp-step.patch,
  gdb-bz541866-rwatch-before-run.patch
  gdb-6.6-buildid-locate-misleading-warning-missing-debuginfo-rhbz981154.patch,
  gdb-babeltrace-configure.patch, gdb-btrobust.patch,
  gdb-dts-rhel6-python-compat.patch, gdb-fortran-frame-string.patch,
  gdb-gnat-dwarf-crash-3of3.patch, gdb-python-completer-1of2.patch,
  gdb-python-completer-2of2.patch, gdb-readline-6.3.5.patch,
  gdb-vla-intel-04of23-fix.patch, gdb-vla-intel-stringbt-fix.patch,
  gdb-vla-intel.patch
- Removes gdb-rhel5-gcc44.patch, gdb-6.6-bfd-vdso8k.patch,
  gdb-testsuite-nohostid.patch, gdb-python-stacksmash.patch
* Tue Jul 15 2014 rguenther@suse.com
  (was: Mon Sep 15 07:42:50 UTC 2014 - rguenther@suse.com)
- Backport fix for gdb internal-error on register info on PPC64LE.
  Addds patch gdb-7.7-bnc896586.patch.  [bnc#896586]
* Thu Jul 10 2014 rguenther@suse.com
  (was: Wed Sep 10 07:41:20 UTC 2014 - rguenther@suse.com)
- Backport fix for gdbserver PPC64LE byteorder issue.  [bnc#895831]
  Adds patch gdb-7.7-bnc895831.patch.
* Tue Jul  8 2014 rguenther@suse.com
  (was: Tue Aug 12 08:13:11 UTC 2014 - rguenther@suse.com)
- Backport all frame-related changes from gdb 7.8.  Adds patches
  gdb-7.7-bnc891040-1.patch, gdb-7.7-bnc891040-2.patch,
  gdb-7.7-bnc891040-3.patch, gdb-7.7-bnc891040-4.patch,
  gdb-7.7-bnc891040-5.patch  [bnc#891040]
* Thu Jun 26 2014 rguenther@suse.com
- Add baselibs.conf to sources.
* Thu Jun 26 2014 rguenther@suse.com
- For _with_testsuite require gcc-fortran, not gcc-gfortran.
  [bnc#884399]
* Wed May 14 2014 rguenther@suse.com
- Fix debugging of threaded 31bit inferiors on s390x
  (gdb-7.7-bnc877566.patch).  [bnc#877566]
- Add patchlist.pl and patchname_get.sh as sources.
* Wed Feb 12 2014 matz@suse.de
- Fix build on s390 (gdb-fix-s390-build.patch).
* Mon Feb 10 2014 matz@suse.de
- Use patchlist.pl to merge with gdb-Fedora at
  e86a0cc13a5d91ba95242690237bb77511500897.
- Don't apply patches gdb-rhel5-gcc44.patch,
  gdb-6.6-buildid-locate-rpm-scl.patch,
  gdb-readline62-ask-more-rh.patch,
  gdb-6.8-attach-signalled-detach-stopped.patch,
  gdb-6.8-quit-never-aborts.patch,
  gdb-rhel5-compat.patch; retained to have same structure as fedoras
  package.
- Add gdb-testsuite-nohostid.patch (from fedora).
- Remove gdb-fix-attach-signalled-detach-stopped.patch again
  (as base not applied), gdb-ppc-ptrace.diff (not applied since some time).
* Sun Feb  9 2014 burnus@net-b.de
- Merge from fedoras gdb-7.7-1.fc21, a rebase to FSF GDB 7.7.
  The 7.7 features are:
  * For C++, the 'typeid' operator has been added and
    exception catchpoints can be filtered by type.
  * Python scripting has been extended
  * New commands and new command options
  * New convenice variables/functions
  * Some GDB/MI improvements
  * Remote protocal improvments
  * SystemTap SDT probes support AArch64 GNU/Linux
  * Support for Fission DWP file format version 2
  * 'tsave' command supports CTF (Common Trace Format)
  * New script 'gcore'
- Remove now obsolete gdb-aarch64-hw-break.patch
- Remove merged bits from gdb-ppc64le.patch
- Rediff gdb-6.6-buildid-locate-rpm-suse.patch
- Add gdb-fix-attach-signalled-detach-stopped.patch
* Mon Dec  9 2013 uweigand@de.ibm.com
- gdb-ppc64le.patch: add support for powerpc64le-linux
* Fri Nov 15 2013 rguenther@suse.com
- Allow librpm3 to be used
* Thu Sep 12 2013 schwab@suse.de
- gdb-aarch64-hw-break.patch: apply last change also to gdbserver
* Mon Aug 12 2013 schwab@suse.de
- gdb-aarch64-hw-break.patch: fix setting hardware debug registers after
  fork
* Wed Aug  7 2013 matz@suse.com
- Merge from fedoras gdb-7.6.50-20130731-cvs, of what will become 7.7
  eventually.  This includes 7.6, which gave:
  * new native configurations (e.g. ARM AArch64 GNU/Linux)
  * new targets (e.g. ARM AArch64, Lynx 178 PowerPC, x86_64/Cygwin)
  * support for the "mini debuginfo" section, .gnu_debugdata
  * the C++ ABI now defaults to the GNU v3 ABI
  * more Python scripting improvements
  * some GDB/MI improvements
  * new configure options, new commands, and options
  * new remote packets
  * a new "target record-btrace" has been added while the
    "target record" command has been renamed to "target record-full"
- gdb-ia64-tdep.patch: build fixes
- gdb-ppc-ptrace.diff: Remove patch, not needed on new kernels
* Tue Jul  2 2013 schwab@suse.de
- Enable multi-target support
- gdb-ia64-tdep.patch: build fixes
- Use --build when configuring
- Don't remove %%buildroot in %%install
- Set pkgversion and bugurl
* Sun Mar 17 2013 matz@suse.com
- Update to 7.5.50, mostly for aarch64.
* Mon Dec  3 2012 matz@suse.com
- Merge from gdb-7.5.1-30.fc18.src.rpm.
  7.5.1 gives:
  * An "Attempt to dereference a generic pointer" errors (-var-create).
  * Backtrace problems on x32 (PR backtrace/14646).
  * next/step/finish problems on x32 (PR gdb/14647).
  * A "malformed linespec error: unexpected keyword, [...]" error
    (PR breakpoints/14643).
  * GDB crash while stepping through powerpc (32bits) code.
  * A failed assertion in linux_ptrace_test_ret_to_nx.
  * A "!frame_id_inlined_p (frame_id)" failed assertion.
  * A "No more reverse-execution history." error during reverse
    "next" execution (PR 14548).
  * Incomplete command descriptions in "apropos" output.
  * PR gdb/14494 (a GDB crash difficult to characterize).
  7.5 gives:
  * Go language support.
  * New targets (x32 ABI, microMIPS, Renesas RL78, HP OpenVMS ia64).
  * More Python scripting improvements.
  * SDT (Static Defined Tracing) probes support with SystemTap probes.
  * GDBserver improvements (stdio connections, target-side evaluation
    of breakpoint conditions, remote protocol improvements).
  * Other miscellaneous improvements (ability to stop when a shared
    library is loaded/unloaded, dynamic printf, etc).
  * Reverse debugging on ARM.
* Tue Jun 19 2012 rguenther@suse.com
- Do not provide a custom (safe) auto-load dir.
* Tue Jun 12 2012 rguenther@suse.com
- Merge from gdb-7.4.50.20120603-3.fc18.src.rpm.
  * Wed Jun  6 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120603-3.fc18
  - Disable -lmcheck in the development builds.
  - Fix assertion on some files as glibc-2.15.90-8.fc18 (Doug Evans).
  * Sun Jun  3 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120603-2.fc18
  - Fix Release.
  - Make yum --enablerepo compatible with at least mock-1.1.21-1.fc16 Rawhide cfg.
  * Sun Jun  3 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120602-1.fc18
  - Rebase to FSF GDB 7.4.50.20120602.
  - [testsuite] BuildRequire gcc-go.
  - Drop printing 2D C++ vectors as matrices which no longer worked (BZ 562763).
  - Fix dejagnu-1.5-4.fc17 compatibility for Go (for BZ 635651).
  - Use librpm.so.3 for rpm-4.10.0 in Fedora 18.
  - Revert recent breakage of UNIX objfiles order for symbols lookup.
  * Sat Jun  2 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-48.fc17
  - [ppc] Fix hardware watchpoints on PowerPC (BZ 827600, Edjunior Machado).
  * Mon May 28 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-47.fc17
  - Workaround PR libc/14166 for inferior calls of strstr.
  * Mon May 14 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-46.fc17
  - [RHEL5] Workaround doc build race.
  * Mon May 14 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-45.fc17
  - Rename "set auto-load" patchset variable $ddir to $datadir.
  * Wed May  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-44.fc17
  - Fix in "set auto-load" patchset for SCL scripts inheritance (BZ 815910).
  * Wed Apr 25 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-43.fc17
  - [RHEL5] Workaround kernel for detaching SIGSTOPped processes (BZ 809382).
  * Tue Apr 24 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-42.fc17
  - Update "set auto-load" patchset and the --with-auto-load-safe-path setting.
  - [RHEL] Disable gdb-add-index even on RHEL-6 as RHEL-6.0 had too old elfutils.
  * Wed Apr 18 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-41.fc17
  - [RHEL] Fix --with-auto-load-safe-path systems prior to /usr move.
  * Wed Apr 18 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-40.fc17
  - Security fix for loading untrusted inferiors, see "set auto-load" (BZ 756117).
  * Fri Apr 13 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-39.fc17
  - [RHEL7] Fix/remove readline-devel BuildRequires redundant distro suffic .fc17.
  * Wed Apr  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-38.fc17
  - Workaround crashes from stale frame_info pointer (BZ 804256).
  * Wed Apr  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-37.fc17
  - testsuite: Fix break-interp.exp expections for updated glibc (BZ 752834).
  * Wed Apr  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-36.fc17
  - [RHEL5,RHEL6] Reintroduce fix attaching to stopped processes.
  * Fri Mar 30 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-35.fc17
  - Fix performance regressions with .gdb_index (Tom Tromey, BZ 805274).
  * Fri Mar 30 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-34.fc17
  - Fixup %%{_datadir}/gdb timestamps for multilib conflicts on RHELs.
  * Mon Mar 26 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-33.fc17
  - [vla] Fix regression on no type for subrange from IBM XLF Fortran (BZ 806920).
  * Sat Mar 17 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-32.fc17
  - Fix loading of core files without build-ids but with build-ids in executables.
  * Fri Mar  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-31.fc17
  - Fix an implied regression by the inferior calls fix below (BZ 799531).
  * Fri Mar  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-30.fc17
  - Fix SELinux deny_ptrace .spec build rules (BZ 786878).
  * Tue Mar  6 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-29.fc17
  - Fix inferior calls, particularly uncaught thrown exceptions (BZ 799531).
  - Fix DWARF DIEs CU vs. section relative offsets (Joel Brobecker, me).
  * Tue Mar  6 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-28.fc17
  - Print reasons for failed attach/spawn incl. SELinux deny_ptrace (BZ 786878).
  * Sun Mar  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-27.fc17
  - [rhel5] Fix up the previous commit (BZ 799318).
  * Sun Mar  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-26.fc17
  - [rhel5] Fix up the previous commit (BZ 799318).
  * Sun Mar  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-25.fc17
  - [rhel5] Workaround rpmbuild to make the doc subpkg noarch again (BZ 799318).
  * Fri Mar  2 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-24.fc17
  - [vla] Fix crash for dynamic.exp with gcc-gfortran-4.1.2-51.el5.x86_64.
  - Reintroduce RHEL-5 glibc workaround for bt-clone-stop.exp.
  - testsuite: Update/fix rh634108-solib_address.exp for the upstreamed API.
  * Wed Feb 29 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-23.fc17
  - Add kernel vDSO workaround (`no loadable ...') on RHEL-5 (kernel BZ 765875).
  - Fix skipping of prologues on RHEL-5 gcc-4.1 -O2 -g code (BZ 797889).
  - Fix breakpoint warning during 'next' over exit() (Tom Tromey, BZ 797892).
  * Tue Feb 28 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-22.fc17
  - testsuite: Fix gdb.base/macscp.exp ccache workaround in SCL mode.
  - Adjust the RHEL/F version string automatically (BZ 797651, BZ 797646).
  - Provide gdbtui for RHEL-5 and RHEL-6 as it is removed upstream (BZ 797664).
  * Fri Feb 24 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-21.fc17
  - testsuite: Do not use gcc44/gfortran44 on RHEL-5 if in SCL mode.
  * Wed Feb 22 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-20.fc17
  - Fix libinproctrace.so build on RHEL-5 i386 (disable it on RHEL-5).
  * Wed Feb 22 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-19.fc17
  - Implement SCL (scl-utils-build) macros.
  * Tue Feb 21 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-18.fc17
  - Fix debuginfo gdb-gdb.py build without redhat-rpm-config and on RHEL-5.
  - Provide precompiled variants of gdb-gdb.py.
  * Mon Feb 13 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-17.fc17
  - gstack: Turn off --readnever (suggested by Oliver Henshaw).
  * Fri Feb 10 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-16.fc17
  - [RHELs] Drop simulation of legacy behavior - new GDB should behave as new GDB.
  * Fri Feb 10 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-15.fc17
  - Simplify %%%%setup .spec rule.
  * Fri Feb 10 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-14.fc17
  - Drop --with upstream .spec rules.
  * Fri Feb 10 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-13.fc17
  - Drop --with debug .spec rules.
  * Thu Feb  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-12.fc17
  - Improve performance for C++ symbols expansion (Tom Tromey, BZ 787487).
  - Install also gdb-gdb.py pretty printers.
  * Thu Feb  9 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-11.fc17
  - Fix possible NULL crash in find_charset_names (Tom Tromey, BZ 786091).
  - [ppc*] Fix build failure due to GCC aliasing warning (BZ 786504).
* Tue Jun 12 2012 cfarrell@suse.com
- license update: GPL-3.0+ and GPL-3.0-with-GCC-exception and LGPL-2.1+ and
  LGPL-3.0+
  SPDX format
* Wed May  9 2012 coolo@suse.com
- Fix the minimum to get it through factory-auto
* Tue Apr  3 2012 rguenther@suse.com
- Fixup missed debuginfo handling SUSE specifics.
* Thu Jan 26 2012 rguenther@suse.com
- Merge from gdb-7.4.50.20120120-10.fc17.src.rpm.
  * Sat Jan 21 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120120-10.fc17
  - Rebase to FSF GDB 7.4.50.20120120.
  - Drop the g77 .spec provisioning as it has been fixed in FSF GDB.
  * Thu Jan 19 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-9.fc17
  - Enable smaller %%{_bindir}/gdb in future by no longer using -rdynamic.
  - Make --enablerepo to use '*-debug*' for RHEL compatibility (BZ 781571).
  - On older RHELs make readline bundled again (BZ 701131).
  - Fix build compatibility with RHEL-5 due to false noarch build.
  * Wed Jan 11 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-8.fc17
  - Disable unexpected GDB directories relocatability.
  * Wed Jan 11 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-7.fc17
  - Fix BuildRequires for RHEL compatibility (BZ 701131).
  * Wed Jan 11 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-6.fc17
  - Provide %%%%snap timestamp for: Provides: bundled(librarypackage)
  - Replace %%%%define by %%%%global.
  - Replace Java in Summary with Fortran (only GCC-compiled Java is supported).
  - Unbundle readline-6.2 with a workaround of skipped "ask" (BZ 701131).
  - Work around readline-6.2 incompatibility not asking for --more-- (BZ 701131).
  * Sat Jan  7 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-5.fc17
  - Mark %%{_sysconfdir}/gdbinit as %%%%config(noreplace).
  - Add appropriate: Provides: bundled(librarypackage).
  - Remove excessive explicit Requires: librarypackage.
  * Thu Jan  5 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-4.fc17
  - Fix linking on non-x86* (such as s390*) after libgdb.a removal.
  * Wed Jan  4 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-3.fc17
  - Reinclude gdb-dlopen-stap-probe.patch (missing in Fedora glibc - BZ 752476).
  * Tue Jan  3 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-2.fc17
  - Fix SystemTap support regression on i686 (Sergio Durigan Junior).
  * Tue Jan  3 2012 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.4.50.20120103-1.fc17
  - Rebase to FSF GDB 7.4.50.20120103.
  * Mon Nov 28 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-11.fc17
  - No longer build bundled libstdc++ pretty printers on RHELs >= 7.
  * Sat Nov 5 2011 Sergio Durigan Junior <sergiodj@redhat.com> - 7.3.50.20110722-10.fc16
  - Backport fix for crash in cp_scan_for_anonymous_namespace
    (Aleksandar Ristovski, BZ 750341).
  * Fri Oct 14 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-9.fc16
  - Backport `info os processes' crash fix - for Eclipse (Pedro Alves, BZ 746294).
  * Tue Oct 11 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-8.fc16
  - Fix PIE testsuite run; new lib/future.exp hack and use -fPIC instead of -fPIE.
  * Mon Sep 26 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-7.fc16
  - [vla] Fix VLA arrays displayed in `bt full' (BZ 738482).
  - Fix DW_OP_GNU_implicit_pointer for DWARF32 v3+ on 64-bit arches.
  - Fix internal error on some optimized-out values.
  * Tue Aug 16 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-6.fc16
  - Python command/function auto-loading (Phil Muldoon, BZ 730976).
  - Work around PR libc/13097 "linux-vdso.so.1" warning message.
  - [TUI] Fix stepi on stripped code.
  - Add BuildRequires: systemtap-sdt-devel for archer-sergiodj-stap-patch-split.
  * Wed Aug 10 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-5.fc16
  - Fix dlopen of libpthread.so, patched glibc required (Gary Benson, BZ 669432).
  * Tue Aug  9 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-4.fc16
  - Improve GDB performance on inferior dlopen calls (Gary Benson, BZ 698001).
  - [python] Fix crash when pretty printer fails (Phil Muldoon, BZ 712715).
  - Fix crash on invalid C++ mangled names (BZ 729283).
  * Fri Jul 29 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-3.fc16
  - Fix regression from VLA merge affecting -O0 -g watchpoints.
  * Fri Jul 29 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-2.fc16
  - Include gcc -g3 .debug_macro implementation by Tom Tromey.
  * Sat Jul 23 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3.50.20110722-1.fc16
  - Rebase to FSF GDB 7.3.50.20110722.
  - Improve gcc-4.6 stdarg false prologue end workaround (GDB PR 12435 + GCC PR 47471).
* Wed Oct 12 2011 rguenther@suse.com
- Add patch to use old ptrace interface on powerpc to fix watchpoint
  issues.  [bnc#718313]
* Thu Aug  4 2011 rguenther@novell.com
- Merge from gdb-7.3-41.fc15.src.rpm.  [fate#310741]
  * Tue Jul 26 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.3-41.fc15
  - Rebase to the final FSF GDB 7.3 release.
  - Improve gcc-4.6 stdarg false prologue end workaround (GDB PR 12435 + GCC PR 47471).
  * Sun Jul  3 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110703-40.fc15
  - Rebase to FSF GDB 7.2.90.20110703 (which is a 7.3 pre-release).
  - Adjust the `print errno' patch due to the DW_AT_linkage_name following again.
  * Fri Jun 24 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110525-39.fc15
  - Fix install-info for the gdb-doc subpackage (BZ 715228).
* Thu Jun 16 2011 rguenther@novell.com
- Merge from gdb-7.2.90.20110525-38.fc15.src.rpm.  [fate#310741]
  * Wed May 25 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110525-38.fc15
  - Rebase to FSF GDB 7.2.90.20110525 (which is a 7.3 pre-release).
  - [stap] Fix double free (Sergio Durigan Junior).
  * Tue May  3 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110429-37.fc15
  - Search also for .<seqno> files in /usr/lib/debug/.build-id (BZ 641377).
* Wed May 18 2011 rguenther@novell.com
- Merge from gdb-7.2.90.20110429-36.fc15.src.rpm.
  * Mon May  2 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110429-36.fc15
  - Bundle readline-6.2 with a workaround of skipped "ask" (BZ 701131).
  - Use --without-system-readline, disable Requires and BuildRequires of readline.
  - Drop gdb-6.5-readline-long-line-crash.patch and gdb-readline-6.0-signal.patch.
  * Fri Apr 29 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110429-35.fc15
  - Rebase to FSF GDB 7.2.90.20110429 (which is a 7.3 pre-release).
  - Fix -O2 -g breakpoints internal error + prologue skipping (BZ 612253).
  - Fix case insensitive symbols for Fortran by iFort (BZ 645773).
  - Fix physname-related CU expansion issue for C++ (PR 12708).
  - Fix Python access to inlined frames (BZ 694824).
  * Mon Apr 11 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.90.20110411-34.fc15
  - Rebase to FSF GDB 7.2.90.20110411 (which is a 7.3 pre-release).
  - Include the proper fix for anonymous struct typedefs (Tom Tromey, BZ 672230).
  * Wed Mar 30 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 7.2.50.20110328-33.fc15
  - Cleanup spec file to add sparc|sparcv9|sparc64.
  - Add sparc specific workarounds to toolchain badness:
  - disable mmap in bdf/ via --without-mmap configure option.
  - add patch to not build mmap support on sparc for gdb/.
  - gdb code is NOT at fault, but we need a working gdb while we sort out
    the toolchain and rebuild all packages. this workaround is NOT for upstream.
  * Tue Mar 29 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110328-32.fc15
  - Fix occasional crash on `print errno' with no -pthread and no -g3 (BZ 690908).
* Thu Apr 14 2011 rguenther@novell.com
- Merge from gdb-7.2.50.20110328-31.fc15.src.rpm.
  * Mon Mar 28 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110328-31.fc15
  - Rebase to FSF GDB 7.2.50.20110328 (which is a 7.3 pre-release).
  - Bundle %%%%{libstdcxxpython}.tar.bz2 unconditionally - for rebulds on RHELs.
  * Sun Mar 20 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110320-30.fc15
  - Fix threading internal error on corrupted memory (BZ 677654).
  - Fix i386 rwatch+awatch before run (BZ 688788, on top of BZ 541866).
  * Sun Mar 20 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110320-29.fc15
  - Rebase to FSF GDB 7.2.50.20110320 (which is a 7.3 pre-release).
  - Merge archer-sergiodj-stap, the SystemTap probes breakpoints feature.
  - [stap] Fix -O2 warnings.
  - Fix Ada support crash on uninitialized gdbarch.
  * Sat Mar  5 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110305-28.fc15
  - Rebase to FSF GDB 7.2.50.20110305 (which is a 7.3 pre-release).
  * Fri Feb 25 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110222-27.fc15
  - Include doc also in the PDF form; new BuildRequires: texinfo-tex.
  * Wed Feb 23 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110222-26.fc15
  - Rebase to FSF GDB 7.2.50.20110222 (which is a 7.3 pre-release).
  - Fix attach/core-load of {,un}prelinked i386 libs (bugreport by Michal Toman).
  * Mon Feb 21 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110218-25.fc15
  - Drop %%%%{_datadir}/gdb/syscalls/* for unsupported arches.
  * Fri Feb 18 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110218-24.fc15
  - Rebase to FSF GDB 7.2.50.20110218 (which is a 7.3 pre-release).
  - [vla] Fox Fortran vector slices for allocated arrays (for BZ 609782).
  * Tue Feb 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110213-23.fc15
  - Move the GFDL License to gdb-doc.
  * Tue Feb 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110213-22.fc15
  - Fix gdb-doc Group to be Documentation, also provide it as noarch.
  * Tue Feb 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110213-21.fc15
  - Drop non-user (gdbint) and obsolete (stabs) documentation.
  - Install also HTML files besides the INFO file.
  - Create new subpackage gdb-doc for both INFO and HTML files.
  * Sun Feb 13 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110213-20.fc15
  - Rebase to FSF GDB 7.2.50.20110213 (which is a 7.3 pre-release).
  - Fix occasionall unfound source lines (affecting at least glibc debugging).
  - Fix const/volatile qualifiers of C++ types (PR c++/12328).
  - Be backward compatible for --rebuild with <=fc14 librpm.so.1.
- Revert documentation split.
* Thu Mar  3 2011 rguenther@novell.com
- Merge from gdb-7.2.50.20110206-19.fc15.src.rpm.
  * Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.2.50.20110206-19
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild
  * Sun Feb  6 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110206-18.fc15
  - Fix regressions on C++ names resolving (PR 11734, PR 12273, Keith Seitz).
  * Sun Feb  6 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110206-17.fc15
  - Rebase to FSF GDB 7.2.50.20110206 (which is a 7.3 pre-release).
  * Thu Jan 27 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110125-16.fc15
  - Fix Python new-backtrace command (BZ 672235, Phil Muldoon).
  * Wed Jan 26 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110125-15.fc15
  - Temporary fix of F15 gcc-4.6 child DIEs of DW_TAG_typedef (BZ 672230).
  - Workaround gcc-4.6 stdarg false prologue end (GDB PR 12435 + GCC PR 47471).
  * Tue Jan 25 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110125-14.fc15
  - Rebase to FSF GDB 7.2.50.20110125 (which is a 7.3 pre-release).
  - Fix discontiguous address ranges in .gdb_index - v3->v4 (BZ 672281).
  - Fix DWARF-3+ DW_AT_accessibility default assumption for F15 gcc-4.6.
  * Thu Jan 20 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110117-13.fc15
  - Use librpm.so.2 for rpm-4.9.0 in Fedora 15.
  * Mon Jan 17 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110117-12.fc15
  - Use %%%%{?dist} for sanity checking tools compliance (suggested by Petr Muller).
  * Mon Jan 17 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110117-11.fc15
  - Rebase to FSF GDB 7.2.50.20110117 (which is a 7.3 pre-release).
  - Fix callback-mode readline-6.0 regression for CTRL-C (for RHEL-6.0).
  - Fix occasional NULL dereference of the readline-6.0 workaround (BZ 575516).
  * Sat Jan 15 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110107-10.fc15
  - [delayed-symfile] Test a backtrace regression on CFIs without DIE (BZ 614604).
  - [archer-tromey-delayed-symfile] New test gdb.dwarf2/dw2-aranges.exp.
  - [archer-keiths-expr-cumulative+upstream] Import C++ testcases.
  - testsuite: Fix gdb-test-expr-cumulative-archer.patch compatibility.
  * Fri Jan  7 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110107-9.fc15
  - Remove --with-pythondir as no longer valid.
  - Provide %%{_bindir}gdb-add-index even on RHEL-5.
  - Provide again libstdc++ pretty printers for any RHEL.
  * Fri Jan  7 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110107-8.fc15
  - Rebase to FSF GDB 7.2.50.20110107 (which is a 7.3 pre-release).
  - Import archer-tromey-python (BZ 666177, branch update by Phil Muldoon).
  * Tue Jan  4 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20110104-7.fc15
  - Rebase to FSF GDB 7.2.50.20110104 (which is a 7.3 pre-release).
  - New testcase py-prettyprint.exp:print hint_error (for BZ 611569, BZ 629236).
  - New test gdb.arch/x86_64-pid0-core.exp for kernel PID 0 cores (BZ 611435).
  * Sat Jan  1 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101231-6.fc15
  - Fix --with-system-readline doc build upstream regression.
  * Sat Jan  1 2011 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101231-5.fc15
  - Rebase to FSF GDB 7.2.50.20101231 (which is a 7.3 pre-release).
  - Remove gdb-6.3-bt-past-zero-20051201.patch, gdb-archer-ada.patch and
    gdb-6.3-framepczero-20040927.patch already removed from .spec before.
  - Remove gdb-6.5-dwarf-stack-overflow.patch, upstreamed (Tom Tromey).
  - Remove gdb-6.6-bz225783-gdb-debuginfo-paths.patch, upstreamed (Tom Tromey).
  - Remove gdb-6.6-readline-system.patch, reimplemented upstream (Tom Tromey).
  - Remove gdb-bz642879-elfread-sigint-stale.patch, upstreamed (Jan Kratochvil).
  - Remove gdb-next-over-throw.patch, upstreamed (Tom Tromey).
  * Mon Dec 27 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101117-4.fc15
  - Provide stub %%%%{_sysconfdir}/gdbinit (BZ 651232).
  * Mon Dec 27 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101117-3.fc15
  - Fix ppc* compilation of PRPSINFO in the core files (BZ 662995, for BZ 254229).
  - Fix (disable) non-x86* compilation of libinproctrace.so (for BZ 662995).
  * Thu Nov 18 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101117-2.fc15
  - Drop gdb-6.8-glibc-headers-compat.patch: GNU/Linux irrelevant (Tom Tromey).
  - Drop gdb-6.3-terminal-fix-20050214.patch: The bug is not reproducible.
  - Drop gdb-6.7-kernel-headers-compat.patch: kernel-headers seem to be fixed.
  - Drop gdb-archer-ada.patch: No longer needed for Ada (Keith Seitz).
  - New PR backtrace/12237, drop gdb-6.3-framepczero-20040927.patch
    gdb-6.3-bt-past-zero-20051201.patch as they already had no effect.
  - Drop gdb-6.8-gcc35998-ada-memory-trash.patch as a different fix is upstream.
  - Drop gdb-6.3-inheritance-20050324.patch: the call is redundent (Tom Tromey).
  - Drop gdb-6.3-large-core-20051206.patch: obsoleted by MAX_COPY_BYTES.
  * Thu Nov 18 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2.50.20101117-1.fc15
  - Rebase to FSF GDB 7.2.50.20101117 (which is a 7.3 pre-release).
  * Sun Nov  7 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-25.fc14
  - iFort compat. - case insensitive DWARF not in lowercase (BZ 645773).
  * Thu Oct 14 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-24.fc14
  - Add gdb.spec comments on the *.patch files upstream merge status.
  * Thu Oct 14 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-23.fc14
  - Workaround librpm BZ 643031 due to its unexpected exit() calls (BZ 642879).
  - Fix crash on CTRL-C while reading an ELF symbol file (BZ 642879).
  * Tue Oct 12 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-22.fc14
  - testsuite: Provide missing lib/gdb-python.exp (for BZ 639089).
  * Tue Oct 12 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-21.fc14
  - Fix python stale error state, also fix its save/restore (BZ 639089).
  - Fix inferior exec of new PIE x86_64 (BZ 638979).
  * Tue Oct 12 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-20.fc14
  - Fixup Release for 20.fc14.
  * Tue Oct 12 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-19.fc14
  - Use .gdb_index v3 to fix excessive resources rqmnts (BZ 640634, Tom Tromey).
  * Wed Oct  6 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-18.fc14
  - Fix false warning: non-absolute filename: <the main exec. file> (BZ 640648).
  * Thu Sep 30 2010 Jan Kratochvil <jan.kratochvil@redhat.com> - 7.2-17.fc14
  - New Conflicts: elfutils < 0.149 due to the .gdb_index .debug support.
* Mon Dec  6 2010 rguenther@novell.com
- On SLE10 package libinproctrace in the main gdb package.
* Wed Oct 13 2010 rguenther@novell.com
- Merge from gdb-7.2-16.fc14.src.rpm.
* Mon Sep 13 2010 rguenther@novell.com
- Change python-base from recommends to requires, gdb no longer
  works without some basic python modules.  [bnc#638858]
* Mon Sep  6 2010 rguenther@novell.com
- Merge from gdb-7.2-1.fc14.src.rpm.
* Wed Aug 25 2010 rguenther@novell.com
- Backport fix for gcore not handling GNU_RELRO sections.  [bnc#596646]
* Wed Aug 25 2010 rguenther@novell.com
- Merge from gdb-7.1-33.fc13.src.rpm.
* Fri Aug  6 2010 rguenther@novell.com
- Backport fix for setting of VSX registers.  [bnc#626970]
* Thu Aug  5 2010 rguenther@novell.com
- Merge from gdb-7.1-30.fc13.src.rpm.
* Thu Aug  5 2010 rguenther@novell.com
- For SLE10 do not build a separate gdbserver package.
* Thu Jul 22 2010 rguenther@novell.com
- Merge from gdb-7.1-29.fc13.src.rpm.
* Tue Jun  1 2010 rguenther@novell.com
- Fix build on hppa fix.
* Tue Jun  1 2010 bg@novell.com
- Fix build on hppa.
* Fri May 21 2010 rguenther@novell.com
- Merge from gdb-7.1-20.fc13.src.rpm.
* Thu Apr 22 2010 aj@suse.de
- Add upstream change to fix build with -Werror
* Thu Apr 15 2010 rguenther@novell.com
- Merge from gdb-7.1-12.fc13.src.rpm.
- Re-write history to match SLE11 SP1 changelog
  * Drop some more strange RHEL stuff.
  * Fix build for SLE10.
* Mon Mar 15 2010 rguenther@novell.com
- Fix info documentation registering.  [bnc#588278]
* Thu Feb 11 2010 kukuk@suse.de
- Re-Add baselibs.conf
* Thu Oct 22 2009 rguenther@suse.de
- Merge from gdb-7.0-2.fc12.src.rpm.  [fate#304116]
  [bnc#488132] [bnc#498749]
* Mon Oct 19 2009 rguenther@suse.de
- Recommend python-base.
* Mon Oct 12 2009 rguenther@suse.de
- Fix python dependency.
* Wed Oct  7 2009 crrodriguez@opensuse.org
- fix info files (un)installation.
* Mon Oct  5 2009 rguenther@suse.de
- Merge from gdb-6.8.91.20090930-2.fc12.src.rpm.
* Thu Sep 24 2009 rguenther@suse.de
- Merge from gdb-6.8.91.20090921-1.fc12.src.rpm.
* Mon Sep 14 2009 rguenther@suse.de
- Merge from gdb-6.8.50.20090910-1.fc12.src.rpm.
* Mon Aug 24 2009 rguenther@suse.de
- Fix gdb-6.3-ia64-sigtramp-frame-20050708.patch patch to allow
  ia64 to build again.
* Mon Aug 24 2009 rguenther@suse.de
- Merge from gdb-6.8.50.20090818-4.fc12.src.rpm.
* Mon Aug 17 2009 rguenther@suse.de
- Merge from gdb-6.8.50.20090811-2.fc12.src.rpm.
* Tue Aug 11 2009 rguenther@suse.de
- Remove no longer applied patches.
* Thu Aug  6 2009 rguenther@suse.de
- Fixup the merge.
* Thu Aug  6 2009 rguenther@suse.de
- Merge from gdb-6.8.50.20090803-2.fc12.src.rpm.
* Tue Jul 28 2009 rguenther@suse.de
- Fix crash during debuginfo reading.
* Wed Jul  8 2009 rguenther@suse.de
- Drop fixes done upstream.
* Wed Jun 17 2009 matz@suse.de
- Apply fix for backtraces without unwind info again.  [#390722]
- Disable gdb-6.5-bz218379-ppc-solib-trampoline-fix.patch, it's not
  necessary anymore and breaks the above.
* Wed May 27 2009 rguenther@suse.de
- Merge FC11 update 23.
  - Fix crashes due to (missing) varobj revalidation, for VLA (for brc#377541).
  - Archer update to the snapshot: e2812eadef2c15baeccd003e11fdf3fbc0b90dc2
  - Archer backport: 58dcda94ac5d6398f47382505e9d3d9d866d79bf
    + f3de7bbd655337fe6705aeaafcc970deff3dd5d5
  - Implement Fortran modules namespaces (brc#466118).
* Mon May 18 2009 rguenther@suse.de
- Add patch to fix handling of string DW_AT_const_values.  [bnc#329420]
- Verified
  * Fix printing of 'inf'.  [bnc#466266]
  * Stepping through templates.  [bnc#414230]
  * gcore script.  [fate#303462]
* Thu May 14 2009 rguenther@suse.de
- Change reported version to mention SUSE instead of Fedora.
- Fix handling of bogus global namespace DIEs from GCC 4.1.  [bnc#329420]
- Fix Power7 DFP detection.  [bnc#492331]
* Thu May  7 2009 rguenther@suse.de
- Fix build for SLE10.  [fate#305977]
- Adjust missing debug packages suggested install command.
* Wed Apr 29 2009 rguenther@suse.de
- Adjust package name and release to not contain macros.
* Mon Apr 27 2009 rguenther@suse.de
- Disable rpm support for locating debug info packages.
* Mon Apr 27 2009 rguenther@suse.de
- Switch to Fedora 11 source RPM.
  * includes partially merge from Archer.  [bnc#329420, bnc#497141,
    bnc#492782]
* Tue Mar 10 2009 rguenther@suse.de
- Add VLA support patch from Fedora to fix possible
  dwarf_expr_frame_base NULL checking regression.
- Fix readline incompatibility.
* Mon Mar  2 2009 rguenther@suse.de
- Integrate support for transparently debugging inline functions.
* Mon Feb 16 2009 schwab@suse.de
- Update to head to trunk.
* Tue Feb  3 2009 schwab@suse.de
- Fix merge error.
* Thu Jan 22 2009 schwab@suse.de
- Add updates for Cell combined debugger.
* Tue Jan 20 2009 schwab@suse.de
- Do not call get_frame_arch for NULL frame pointers.
- Remove deprecated_safe_get_selected_frame call from read_var_value.
* Fri Jan 16 2009 bwalle@suse.de
- Recommend Python for GDB to prevent strange error messages to
  be presented to the user in the default case.
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Nov 20 2008 schwab@suse.de
- Update to head of trunk.
- Don't lose running state of the inferior.
- Fix dangling pointers after following fork.
* Sun Nov  9 2008 schwab@suse.de
- Update .debug_line parser patch.
* Mon Nov  3 2008 schwab@suse.de
- Update to head of trunk.
- Fix auxv decoding.
* Mon Nov  3 2008 schwab@suse.de
- Revert broken change from jblunck.
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Oct 28 2008 jblunck@suse.de
- Fix segfault when reading line number program (bnc #439457).
* Mon Oct 27 2008 schwab@suse.de
- Complain about invalid line number program.
* Tue Oct  7 2008 schwab@suse.de
- Fix crash.
* Wed Sep 24 2008 schwab@suse.de
- Update to head of trunk.
- Add POWER7 support.
- Add gcore.
- Add spu-elf to list of targets.
* Fri Sep 12 2008 schwab@suse.de
- Update to head of trunk.
- Add Cell combined debugger patch.
* Thu Sep  4 2008 schwab@suse.de
- Update to head of trunk.
* Fri Aug 15 2008 schwab@suse.de
- Update to head of trunk.
* Fri Aug  8 2008 schwab@suse.de
- Update to head of trunk.
- Enable multi-target support.
* Fri Jul 18 2008 schwab@suse.de
- Update to head of trunk.
* Mon Jul  7 2008 schwab@suse.de
- Update to head of trunk.
* Wed Jun 18 2008 schwab@suse.de
- Update to head of trunk.
* Fri May 23 2008 matz@suse.de
- Try harder to provide backtraces without debuginfo on i386.  [bnc #390722]
* Wed May 21 2008 schwab@suse.de
- Fix assertion failure.
* Fri May  9 2008 schwab@suse.de
- Split off gdbserver.
- Fix watchpoints.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Mar 28 2008 schwab@suse.de
- Update to gdb 6.8.
  * New native configurations
  NetBSD/hppa			hppa*-*netbsd*
  Xtensa GNU/Linux		xtensa*-*-linux*
  * New targets
  NetBSD/hppa			hppa*-*-netbsd*
  Xtensa GNU/Lunux		xtensa*-*-linux*
  * Change in command line behavior -- corefiles vs. process ids.
    When the '-p NUMBER' or '--pid NUMBER' options are used, and
    attaching to process NUMBER fails, GDB no longer attempts to open a
    core file named NUMBER.  Attaching to a program using the -c option
    is no longer supported.  Instead, use the '-p' or '--pid' options.
  * GDB can now be built as a native debugger for debugging Windows x86
  (mingw32) Portable Executable (PE) programs.
  * Pending breakpoints no longer change their number when their address
  is resolved.
  * GDB now supports breakpoints with multiple locations,
  including breakpoints on C++ constructors, inside C++ templates,
  and in inlined functions.
  * GDB's ability to debug optimized code has been improved.  GDB more
  accurately identifies function bodies and lexical blocks that occupy
  more than one contiguous range of addresses.
  * Target descriptions can now describe registers for PowerPC.
  * The GDB remote stub, gdbserver, now supports the AltiVec and SPE
  registers on PowerPC targets.
  * The GDB remote stub, gdbserver, now supports thread debugging on GNU/Linux
  targets even when the libthread_db library is not available.
  * The GDB remote stub, gdbserver, now supports the new file transfer
  commands (remote put, remote get, and remote delete).
  * The GDB remote stub, gdbserver, now supports run and attach in
  extended-remote mode.
  * hppa*64*-*-hpux11* target broken
    The debugger is unable to start a program and fails with the following
    error: "Error trying to get information about dynamic linker".
    The gdb-6.7 release is also affected.
  * GDB now supports the --enable-targets= configure option to allow
  building a single GDB executable that supports multiple remote
  target architectures.
  * GDB now supports debugging C and C++ programs which use the
  Decimal Floating Point extension.  In addition, the PowerPC target
  now has a set of pseudo-registers to inspect decimal float values
  stored in two consecutive float registers.
  * The -break-insert MI command can optionally create pending
  breakpoints now.
  * Improved support for debugging Ada
    Many improvements to the Ada language support have been made.  These
    include:
  - Better support for Ada2005 interface types
  - Improved handling of arrays and slices in general
  - Better support for Taft-amendment types
  - The '{type} ADDRESS' expression is now allowed on the left hand-side
  of an assignment
  - Improved command completion in Ada
  - Several bug fixes
  * New commands
  set print frame-arguments (all|scalars|none)
  show print frame-arguments
    The value of this variable can be changed to control which argument
    values should be printed by the debugger when displaying a frame.
  remote put
  remote get
  remote delete
    Transfer files to and from a remote target, and delete remote files.
  * New MI commands
  - target-file-put
  - target-file-get
  - target-file-delete
    Transfer files to and from a remote target, and delete remote files.
  * New remote packets
  vFile:open:
  vFile:close:
  vFile:pread:
  vFile:pwrite:
  vFile:unlink:
    Open, close, read, write, and delete files on the remote system.
  * GDB on GNU/Linux and HP/UX can now debug through "exec" of a new
  process.
  vAttach
    Attach to an existing process on the remote system, in extended-remote
    mode.
  vRun
    Run a new process on the remote system, in extended-remote mode.
* Wed Mar  5 2008 schwab@suse.de
- Update to head of gdb_6_8-branch.
* Thu Feb 14 2008 schwab@suse.de
- Update to head of trunk.
* Thu Jan 31 2008 schwab@suse.de
- Update to head of trunk.
* Thu Jan 10 2008 schwab@suse.de
- Update to head of trunk.
* Mon Nov 12 2007 schwab@suse.de
- Update to gdb 6.7.1.
  * hppa*64*-*-hpux11* target broken
    The debugger is unable to start a program and fails with the following
    error: "Error trying to get information about dynamic linker".
    The gdb-6.7 release is also affected.
* Fri Oct 19 2007 olh@suse.de
- allow build with old distributions, libexpat-devel is new in 10.3
* Thu Oct 11 2007 schwab@suse.de
- Update to gdb 6.7.
  * Resolved 101 resource leaks, null pointer dereferences, etc. in gdb,
  bfd, libiberty and opcodes, as revealed by static analysis donated by
  Coverity, Inc. (http://scan.coverity.com).
  * When looking up multiply-defined global symbols, GDB will now prefer the
  symbol definition in the current shared library if it was built using the
  - Bsymbolic linker option.
  * When the Text User Interface (TUI) is not configured, GDB will now
  recognize the -tui command-line option and print a message that the TUI
  is not supported.
  * The GDB remote stub, gdbserver, now has lower overhead for high
  frequency signals (e.g. SIGALRM) via the QPassSignals packet.
  * GDB for MIPS targets now autodetects whether a remote target provides
  32-bit or 64-bit register values.
  * Support for C++ member pointers has been improved.
  * GDB now understands XML target descriptions, which specify the
  target's overall architecture.  GDB can read a description from
  a local file or over the remote serial protocol.
  * Vectors of single-byte data use a new integer type which is not
  automatically displayed as character or string data.
  * The /s format now works with the print command.  It displays
  arrays of single-byte integers and pointers to single-byte integers
  as strings.
  * Target descriptions can now describe target-specific registers,
  for architectures which have implemented the support (currently
  only ARM, M68K, and MIPS).
  * GDB and the GDB remote stub, gdbserver, now support the XScale
  iWMMXt coprocessor.
  * The GDB remote stub, gdbserver, has been updated to support
  ARM Windows CE (mingw32ce) debugging, and GDB Windows CE support
  has been rewritten to use the standard GDB remote protocol.
  * GDB can now step into C++ functions which are called through thunks.
  * GDB for the Cell/B.E. SPU now supports overlay debugging.
  * The GDB remote protocol "qOffsets" packet can now honor ELF segment
  layout.  It also supports a TextSeg= and DataSeg= response when only
  segment base addresses (rather than offsets) are available.
  * The /i format now outputs any trailing branch delay slot instructions
  immediately following the last instruction within the count specified.
  * The GDB remote protocol "T" stop reply packet now supports a
  "library" response.  Combined with the new "qXfer:libraries:read"
  packet, this response allows GDB to debug shared libraries on targets
  where the operating system manages the list of loaded libraries (e.g.
  Windows and SymbianOS).
  * The GDB remote stub, gdbserver, now supports dynamic link libraries
  (DLLs) on Windows and Windows CE targets.
  * GDB now supports a faster verification that a .debug file matches its binary
  according to its build-id signature, if the signature is present.
  * New commands
  set remoteflow
  show remoteflow
    Enable or disable hardware flow control (RTS/CTS) on the serial port
    when debugging using remote targets.
  set mem inaccessible-by-default
  show mem inaccessible-by-default
    If the target supplies a memory map, for instance via the remote
    protocol's "qXfer:memory-map:read" packet, setting this variable
    prevents GDB from accessing memory outside the memory map.  This
    is useful for targets with memory mapped registers or which react
    badly to accesses of unmapped address space.
  set breakpoint auto-hw
  show breakpoint auto-hw
    If the target supplies a memory map, for instance via the remote
    protocol's "qXfer:memory-map:read" packet, setting this variable
    lets GDB use hardware breakpoints automatically for memory regions
    where it can not use software breakpoints.  This covers both the
    "break" command and internal breakpoints used for other commands
    including "next" and "finish".
  catch exception
  catch exception unhandled
    Stop the program execution when Ada exceptions are raised.
  catch assert
    Stop the program execution when an Ada assertion failed.
  set sysroot
  show sysroot
    Set an alternate system root for target files.  This is a more
    general version of "set solib-absolute-prefix", which is now
    an alias to "set sysroot".
  info spu
    Provide extended SPU facility status information.  This set of
    commands is available only when debugging the Cell/B.E. SPU
    architecture.
  * New native configurations
  OpenBSD/sh			sh*-*openbsd*
  set tdesc filename
  unset tdesc filename
  show tdesc filename
    Use the specified local file as an XML target description, and do
    not query the target for its built-in description.
  * New targets
  OpenBSD/sh			sh*-*-openbsd*
  MIPS64 GNU/Linux (gdbserver)	mips64-linux-gnu
  Toshiba Media Processor		mep-elf
  * New remote packets
  QPassSignals:
    Ignore the specified signals; pass them directly to the debugged program
    without stopping other threads or reporting them to GDB.
  qXfer:features:read:
    Read an XML target description from the target, which describes its
    features.
  qXfer:spu:read:
  qXfer:spu:write:
    Read or write contents of an spufs file on the target system.  These
    packets are available only on the Cell/B.E. SPU architecture.
  qXfer:libraries:read:
    Report the loaded shared libraries.  Combined with new "T" packet
    response, this packet allows GDB to debug shared libraries on
    targets where the operating system manages the list of loaded
    libraries (e.g. Windows and SymbianOS).
  * Removed targets
  Support for these obsolete configurations has been removed.
  alpha*-*-osf1*
  alpha*-*-osf2*
  d10v-*-*
  hppa*-*-hiux*
  i[34567]86-ncr-*
  i[34567]86-*-dgux*
  i[34567]86-*-lynxos*
  i[34567]86-*-netware*
  i[34567]86-*-sco3.2v5*
  i[34567]86-*-sco3.2v4*
  i[34567]86-*-sco*
  i[34567]86-*-sysv4.2*
  i[34567]86-*-sysv4*
  i[34567]86-*-sysv5*
  i[34567]86-*-unixware2*
  i[34567]86-*-unixware*
  i[34567]86-*-sysv*
  i[34567]86-*-isc*
  m68*-cisco*-*
  m68*-tandem-*
  mips*-*-pe
  rs6000-*-lynxos*
  sh*-*-pe
  * Other removed features
  target abug
  target cpu32bug
  target est
  target rom68k
  Various m68k-only ROM monitors.
  target hms
  target e7000
  target sh3
  target sh3e
  Various Renesas ROM monitors and debugging interfaces for SH and
  H8/300.
  target ocd
  Support for a Macraigor serial interface to on-chip debugging.
  GDB does not directly support the newer parallel or USB
  interfaces.
  DWARF 1 support
  A debug information format.  The predecessor to DWARF 2 and
  DWARF 3, which are still supported.
  Support for the HP aCC compiler on HP-UX/PA-RISC
  SOM-encapsulated symbolic debugging information, automatic
  invocation of pxdb, and the aCC custom C++ ABI.  This does not
  affect HP-UX for Itanium or GCC for HP-UX/PA-RISC.  Code compiled
  with aCC can still be debugged on an assembly level.
  MIPS ".pdr" sections
  A MIPS-specific format used to describe stack frame layout
  in debugging information.
  Scheme support
  GDB could work with an older version of Guile to debug
  the interpreter and Scheme programs running in it.
  set mips stack-arg-size
  set mips saved-gpreg-size
  Use "set mips abi" to control parameter passing for MIPS.
* Mon Oct  1 2007 schwab@suse.de
- Update to head of gdb_6_7-branch.
* Mon Sep 24 2007 schwab@suse.de
- Fix internal error [#309928].
* Thu Jul 26 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jul 13 2007 schwab@suse.de
- Update to head of trunk.
* Sun Jun 24 2007 schwab@suse.de
- Fix annotations for commands prompt.
* Thu Jun 21 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jun  8 2007 schwab@suse.de
- Update to head of trunk.
* Fri May 11 2007 schwab@suse.de
- Update to head of trunk.
* Fri Apr 13 2007 schwab@suse.de
- Avoid crash on object with no text section [#176306].
* Wed Apr 11 2007 schwab@suse.de
- Handle non-threaded processes in gstack [#262694].
* Sun Apr  1 2007 schwab@suse.de
- Properly decode CR register number.
* Thu Mar 29 2007 schwab@suse.de
- Update solib-extract-address patch.
* Tue Mar 20 2007 schwab@suse.de
- Update single stepping patch again [#154486].
* Fri Mar 16 2007 schwab@suse.de
- Update single stepping patch [#154486].
* Thu Mar 15 2007 schwab@suse.de
- Fix altivec vector return location [#250004].
* Mon Mar 12 2007 schwab@suse.de
- Update ppc DWARF patch to also handle broken debug info from old
  compilers.
* Thu Mar  8 2007 schwab@suse.de
- Deal with stepping over sequence of atomic insns [#154486].
* Wed Mar  7 2007 schwab@suse.de
- Improve last change.
* Tue Mar  6 2007 schwab@suse.de
- Better handling of ppc64 function descriptor symbols.
* Mon Mar  5 2007 schwab@suse.de
- Remove obsolete patch.
- Fix show endian.
* Thu Jan 11 2007 schwab@suse.de
- Fix unchecked use of PC_REGNUM.
* Wed Dec 20 2006 schwab@suse.de
- Update to gdb 6.6.
  * New targets
  Xtensa				xtensa-elf
  Cell Broadband Engine SPU	spu-elf
  * GDB can now be configured as a cross-debugger targeting native Windows
  (mingw32) or Cygwin.  It can communicate with a remote debugging stub
  running on a Windows system over TCP/IP to debug Windows programs.
  * The GDB remote stub, gdbserver, has been updated to support Windows and
  Cygwin debugging.  Both single-threaded and multi-threaded programs are
  supported.
  * The "set trust-readonly-sections" command works again.  This command was
  broken in GDB 6.3, 6.4, and 6.5.
  * Support for GNU/Linux Thread Local Storage (TLS, per-thread variables) no
  longer requires symbolic debug information (e.g. DWARF-2).
  * New commands
  set substitute-path
  unset substitute-path
  show substitute-path
    Manage a list of substitution rules that GDB uses to rewrite the name
    of the directories where the sources are located. This can be useful
    for instance when the sources were moved to a different location
    between compilation and debugging.
  set trace-commands
  show trace-commands
    Print each CLI command as it is executed.  Each command is prefixed with
    a number of `+' symbols representing the nesting depth.
    The source command now has a `-v' option to enable the same feature.
  * REMOVED features
  The ARM Demon monitor support (RDP protocol, "target rdp").
  Kernel Object Display, an embedded debugging feature which only worked with
  an obsolete version of Cisco IOS.
  The 'set download-write-size' and 'show download-write-size' commands.
  * New remote packets
  qSupported:
    Tell a stub about GDB client features, and request remote target features.
    The first feature implemented is PacketSize, which allows the target to
    specify the size of packets it can handle - to minimize the number of
    packets required and improve performance when connected to a remote
    target.
  qXfer:auxv:read:
    Fetch an OS auxilliary vector from the remote stub.  This packet is a
    more efficient replacement for qPart:auxv:read.
  * Removed remote packets
  qPart:auxv:read:
    This packet has been replaced by qXfer:auxv:read.  Only GDB 6.4 and 6.5
    used it, and only gdbserver implemented it.
* Sat Dec  2 2006 schwab@suse.de
- Update to gdb 6.5.90.
* Fri Oct 27 2006 schwab@suse.de
- Rename detach-fork to detach fork.
* Tue Oct 24 2006 schwab@suse.de
- Better fix for function descriptor handling on ppc64.
* Fri Aug 25 2006 schwab@suse.de
- Minimal support for .gnu.hash.
* Thu Aug 24 2006 schwab@suse.de
- Fix off-by-one in add_symbol_file_command [#200831].
* Fri Aug 11 2006 schwab@suse.de
- Correctly extend addresses read from link map.
* Sun Jul 16 2006 schwab@suse.de
- Fix function decriptor handing on ppc64.
* Wed Jun 21 2006 schwab@suse.de
- Update to final gdb 6.5.
* Sat Jun  3 2006 schwab@suse.de
- Update to gdb 6.5 RC 1.
* Wed May 31 2006 schwab@suse.de
- Set long double size to 16 [#180103].
* Mon May 22 2006 schwab@suse.de
- Update to gdb 6.4.90 snapshot 20060522.
* Sun Apr 23 2006 schwab@suse.de
- Add patch to avoid losing compilation directory.
- Fix a parallel build problem.
* Tue Apr  4 2006 schwab@suse.de
- Relocate PIEs.
* Sun Mar 26 2006 schwab@suse.de
- Handle .eh_frame register encoding that is different from .dwarf_frame.
- Remove obsolete patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 schwab@suse.de
- Add fix for PIC prologue analyzer on powerpc.
* Wed Dec 14 2005 schwab@suse.de
- Add fix for observer notify queue after attach.
* Fri Dec  2 2005 schwab@suse.de
- Update to gdb 6.4.
* Tue Nov 22 2005 schwab@suse.de
- Update to gdb 6.3.90.
* Fri Nov  4 2005 schwab@suse.de
- Update to gdb-6.3.50 snapshot 20051103.
* Mon Oct  3 2005 schwab@suse.de
- Update to gdb 6.3.50 snapshot 20051003.
* Mon Sep 19 2005 schwab@suse.de
- Fix warnings.
* Sun Aug 21 2005 schwab@suse.de
- Add DWARF CFI unwinder on ppc.
* Mon Jun 20 2005 schwab@suse.de
- Require libunwind-devel on ia64.
* Thu Jun  9 2005 schwab@suse.de
- Add patch for ia64 vDSO support and unwinding through signals and
  syscalls [#60766].
* Mon Apr 11 2005 schwab@suse.de
- Fix backtrace through vsyscall [#63483].
* Sun Apr 10 2005 schwab@suse.de
- Add patch to fix bugs in rs6000/powerpc register set functions.
- Fix a testsuite bug.
* Sun Mar  6 2005 schwab@suse.de
- Add patch to suppress fork attach/detach messages.
* Wed Mar  2 2005 schwab@suse.de
- Add patch to fix following vfork from a secondary thread.
* Mon Feb 28 2005 schwab@suse.de
- Don't ignore DW_TAG_member [#66406].
* Tue Feb  1 2005 schwab@suse.de
- Find separate debug symbol files in /usr/lib/debug by default.
* Thu Jan 27 2005 schwab@suse.de
- Add patch to handle back-to-back and nested signals.
* Thu Jan 27 2005 schwab@suse.de
- Add patch to implement reggroups for ppc.
* Wed Jan 26 2005 schwab@suse.de
- Add patch to implement PPC GNU/Linux sigtramp frame code.
* Wed Jan 12 2005 schwab@suse.de
- Don't error out when encountering an unavailable value.
* Fri Dec  3 2004 schwab@suse.de
- Downgrade errors to warnings during backtrace [#48484].
- Undocument --readnever since it may not be supported by future releases.
- Fix patches from last change.
* Fri Dec  3 2004 kukuk@suse.de
- Add --readnever option as workaround for [#48485]
* Sun Nov 14 2004 schwab@suse.de
- Add libunwind-devel to neededforbuild.
* Sat Nov 13 2004 schwab@suse.de
- Fix missing dependencies.
* Wed Nov 10 2004 schwab@suse.de
- Version 6.2.91 renamed to 6.3.
* Mon Nov  8 2004 schwab@suse.de
- Update to gdb 6.2.91 (6.3 release candidate).
* Mon Nov  8 2004 schwab@suse.de
- Revert last change.
- Fix typo.
* Mon Nov  8 2004 uli@suse.de
- fixed to build on s390*
* Mon Oct 25 2004 schwab@suse.de
- Fix building gdbserver on x86-64.
* Mon Oct 25 2004 schwab@suse.de
- Update to gdb 6.2.90.
- Use libunwind on ia64.
* Thu Sep  9 2004 schwab@suse.de
- Update to gdb 6.2.1.
* Wed Aug 25 2004 schwab@suse.de
- Fix deadlock in child_wait [#42796].
* Tue Aug 24 2004 schwab@suse.de
- Import latest changes from 6.2 branch.
* Fri Jul 30 2004 schwab@suse.de
- Update to gdb 6.2.
* Thu Jul 29 2004 schwab@suse.de
- Update to gdb 6.1.92.
* Mon Jul 26 2004 schwab@suse.de
- Fix handling of relative filenames in DWARF2 .debug_line.
* Mon Jul 19 2004 schwab@suse.de
- Update to gdb 6.1.91.
* Thu Jun 24 2004 schwab@suse.de
- Better handling of dying threads.
* Fri Jun 18 2004 schwab@suse.de
- Update to gdb 6.1.1.
* Tue May 25 2004 schwab@suse.de
- Fix handling of short lived threads [#40841].
* Sat May  1 2004 schwab@suse.de
- Restore removed hunk.
* Fri Apr 30 2004 meissner@suse.de
- applied 3 patches to fix problems on ppc64. #39394
* Sat Apr 17 2004 schwab@suse.de
- Pacify autobuild.
* Mon Apr  5 2004 schwab@suse.de
- Version 6.0.92 has been renamed to 6.1.
* Sat Apr  3 2004 schwab@suse.de
- Update to gdb 6.0.92 (6.1 release candidate).
* Tue Mar 30 2004 schwab@suse.de
- Fix invalid use of va_list.
* Mon Mar 29 2004 schwab@suse.de
- Update to gdb 6.0.91.
* Mon Mar 29 2004 schwab@suse.de
- Update to current CVS.
* Fri Mar 19 2004 schwab@suse.de
- Fix last change: don't disable testsuite.
* Wed Mar 17 2004 mludvig@suse.cz
- Added opcodes for VIA PadLock instructions.
* Tue Mar  2 2004 schwab@suse.de
- Update to gdb 6.0.90.
- Run testsuite.
* Thu Jan  8 2004 schwab@suse.de
- Fix gate area range.
* Wed Dec 10 2003 schwab@suse.de
- Support DW_TAG_subrange_type.
- Backport recent ia64 improvements from mainline.
* Tue Oct 21 2003 mludvig@
- Add support for debugging both i386 and amd64 apps by a single
  amd64 GDB binary.
* Mon Oct 20 2003 mludvig@suse.cz
- Correctly interpret symbol tables for debugging kernel modules
  (gdb6-symtab-minimal.diff)
- Fixed support for GCC variable tracking (gdb6-vartrack.diff)
- Fixed support for Fortran arrays (gdb6-fortranarray.diff)
* Tue Oct  7 2003 schwab@suse.de
- Hack to build on sparc.
* Mon Oct  6 2003 schwab@suse.de
- Update to gdb 6.0.
* Fri Oct  3 2003 kukuk@suse.de
- Remove unused tetex from neededforbuild
* Mon Sep 29 2003 schwab@suse.de
- Update to gdb 5.3.93 pre-release.
* Wed Sep 17 2003 schwab@suse.de
- Remove debugging hooks.
* Wed Sep 17 2003 schwab@suse.de
- Ignore more insns during i386 prologue decoding [#30288].
- Fix hash table mixup in bfd_simple interface.
* Tue Sep 16 2003 schwab@suse.de
- Update to gdb 5.3.92 pre-release.
  * Fixes bug 31033.
* Wed Sep  3 2003 schwab@suse.de
- Update to gdb 5.3.91 pre-release.
* Tue Aug 19 2003 schwab@suse.de
- Update to gdb 5.3.90 2003-08-19 cvs snapshot.
* Mon Jun 23 2003 kukuk@suse.de
- Fix compiling on SPARC
* Tue Jun 10 2003 schwab@suse.de
- Don't package mmalloc.info, since libmmalloc isn't included either.
* Thu May 15 2003 schwab@suse.de
- Remove unwanted files.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Apr 11 2003 mludvig@suse.cz
- Fix read_2u() function in dwarf2cfi.c
* Thu Apr 10 2003 mludvig@suse.cz
- Add 'info cfi <address>' command.
- Fix off-by-4 bug in the CFI parser.
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Mar 27 2003 schwab@suse.de
- Fix specfile.
* Thu Mar  6 2003 aj@suse.de
- Fix neededforbuild.
* Wed Feb 26 2003 mludvig@suse.cz
- Added loclist support
- Fixed eh_frame parsing problems
- Updated for proposed x86-64 ABI change
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Tue Feb  4 2003 schwab@suse.de
- Enable TUI.
* Sun Jan 26 2003 olh@suse.de
- add inital native ppc64 support
* Thu Jan  9 2003 mludvig@suse.cz
- Fixed compilation problem with last gdb-asmbtrace.diff.
  No new feature.
* Tue Jan  7 2003 mludvig@suse.cz
- Several Dwarf2 and x86-64 specific changes
  * Added ability to do backtrace from some functions
    without debug info (patch gdb-asmbtrace.diff)
  * Fixed crash on re-run of a debugged program.
  * Added some more verbosity to dwarf2cfi engine.
* Thu Dec 12 2002 schwab@suse.de
- Update to gdb 5.3.
  * GNU/Linux shared library multi-threaded performance improved.
  * ``gdbserver'' now supports multi-threaded applications on some targets
  * GDB now supports C/C++ preprocessor macros.
* Fri Oct 11 2002 aj@suse.de
- Handle gcc code generated by gcc -f-elimante-dwarf2-dups -g.
* Thu Sep 26 2002 schwab@suse.de
- Avoid installing libbfd, libopcodes, libiberty and libmmalloc [#20199].
* Wed Sep 18 2002 sf@suse.de
- added patch from mludvig to remove framepointer on x86_64
* Wed Sep  4 2002 kukuk@suse.de
- Add Patch for reading SPARC core files
* Tue Sep  3 2002 schwab@suse.de
- Remove tetex from neededforbuild.
* Wed Jul 24 2002 schwab@suse.de
- Update to gdb 5.2.1.
* Thu Jul 18 2002 mludvig@suse.de
- Fix PLT recognisation.
* Mon Jul  8 2002 schwab@suse.de
- Add fix for memory leak.
* Tue Jul  2 2002 mludvig@suse.cz
- removed my previous patches
- added a huge one suse-521-x8664.diff
* Thu Jun  6 2002 sf@suse.de
- added fpregset.diff (from mludvig@suse.de)
- added dwarf2cfi.diff (from mludvig@suse.de)
* Wed May 15 2002 sf@suse.de
- added some dwarf2-patches for x86_64
  (from mludvig@suse.de)
* Thu May  9 2002 schwab@suse.de
- Fix breakpoints on MLX bundle.
* Mon May  6 2002 schwab@suse.de
- Sparc doesn't have gdbserver either.
* Sun May  5 2002 schwab@suse.de
- Update to gdb 5.2.
- Gdbserver now available for all but alpha.
* Fri Jan 25 2002 schwab@suse.de
- Update to gdb 5.1.1.
* Thu Nov 22 2001 schwab@suse.de
- Update to gdb 5.1.
- Build and install gdbserver on i386 and ia64.
* Sat Aug 18 2001 schwab@suse.de
- Update to gdb snapthot 20010316.
* Fri May 18 2001 schwab@suse.de
- Include ia64 warning patches (from nadvornik@suse.cz).
* Thu Apr 12 2001 schwab@suse.de
- Remove declaration of tilde_expand, now in readline header.
* Sat Mar 31 2001 schwab@suse.de
- Fix hardware watchpoints on ia64.
* Fri Mar 30 2001 schwab@suse.de
- Fix crash on info architecture (#6865).
* Wed Mar 28 2001 schwab@suse.de
- Use installed readline library.
* Tue Mar  6 2001 schwab@suse.de
- Remove some ia64 hacks.
* Tue Dec 12 2000 schwab@suse.de
- Improve handling of breakpoints in shared libraries.
* Fri Nov 17 2000 kukuk@suse.de
- Update to working gdb snapshot
* Wed Sep 27 2000 fober@suse.de
- s390: added s390-sigregs-SuSE.patch
* Thu Sep 14 2000 fober@suse.de
- s390: incorporate new ibm patches for gdb 5.0
* Wed Sep  6 2000 fober@suse.de
- s390: incorporate ibm patches for gdb 5.0
* Fri Jun 30 2000 kukuk@suse.de
- Add gdb-5.0
* Tue Apr  4 2000 bk@suse.de
- s390 team added s390 support
* Tue Mar 21 2000 schwab@suse.de
- Fix core dump reading (#2586).
* Fri Feb  4 2000 kukuk@suse.de
- Add patches for PPC
- Move /usr/info -> /usr/share/info
* Mon Dec  6 1999 kukuk@suse.de
- Remove gdb 4.17
- Add gdb 4.18 fixes for SPARC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Sep  3 1999 kukuk@suse.de
- Use RPM values for CFLAGS and configure
* Tue Aug 24 1999 uli@suse.de
- added -fsigned-char to CFLAGS (PPC)
* Mon Aug 23 1999 kukuk@suse.de
- Add gdb 4.18 thread patch from RH
* Mon Jul 19 1999 florian@suse.de
- add gdb-4.17.0.12 as /usr/bin/gdb-4.17
* Wed Jul  7 1999 kukuk@suse.de
- update to 4.18 using diff from jurix
* Mon Feb 22 1999 ro@suse.de
- update to 4.17.0.11 using diff from jurix
* Thu Jan 21 1999 ro@suse.de
- update to 4.17.0.8
* Thu Oct  1 1998 ro@suse.de
- update to 4.17.0.4 using jurix-diff
* Tue Sep 15 1998 ro@suse.de
- hacked for GLIBC: include sys/ucontext and sys/ptrace where needed
- catch strup redeclarations
- cleaned up patch-sequence
* Tue Oct 28 1997 florian@suse.de
- fix <sys/procfs.h> in libc to correctly support core-files
- add bug-fix to read symbols from dynamic symbol tables
- apply all patches from debian gdb-4.16-11
* Thu Jan  2 1997 florian@suse.de
  Neue Version 4.16.
  gdb kompiliert nur mit libc 5.4.7 richtig. Mit 5.2.18 kann gdb
  keine core-files lesen.
  Ich waere dafuer, einfach das Binary von libc 5.4.7 zu benutzen.
  Wird schon funktionieren...
